"use strict";

var _bootstrapStyled = require("bootstrap-styled");

var _reducer = _interopRequireWildcard(require("../reducer"));

var _actions = require("../actions");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('themeReducer', function () {
  var state;
  var theme;
  var themes;
  var expectedResult;
  beforeEach(function () {
    theme = {
      _name: 'test_theme',
      '$color-primary': 'red'
    };
    themes = _defineProperty({
      'bootstrap-styled': _bootstrapStyled.theme
    }, theme._name, theme);
    state = _reducer.initialState;
    expectedResult = undefined; // we force reinstall bootstrap in store just in case we delete it

    (0, _reducer.default)(state, (0, _actions.storeTheme)(_bootstrapStyled.theme));
  });
  it('should return the initial state', function () {
    expectedResult = state;
    expect((0, _reducer.default)(undefined, {})).toEqual(expectedResult);
  });
  it('should handle the changeTheme action correctly using a theme', function () {
    expectedResult = {
      theme: theme,
      themes: themes
    };
    expect((0, _reducer.default)(_objectSpread({}, state, {
      themes: _defineProperty({
        'bootstrap-styled': _bootstrapStyled.theme
      }, theme._name, theme)
    }), (0, _actions.changeTheme)(theme))).toEqual(expectedResult); // eslint-disable-line no-underscore-dangle
  });
  it('should handle the changeTheme action correctly using a name', function () {
    expectedResult = {
      theme: theme,
      themes: themes
    };
    expect((0, _reducer.default)(_objectSpread({}, state, {
      themes: _defineProperty({
        'bootstrap-styled': _bootstrapStyled.theme
      }, theme._name, theme)
    }), (0, _actions.changeTheme)(theme._name))).toEqual(expectedResult); // eslint-disable-line no-underscore-dangle
  });
  it('should handle the changeTheme action with wrong name without changing the main theme', function () {
    expectedResult = {
      theme: _bootstrapStyled.theme,
      themes: themes
    };
    expect((0, _reducer.default)(_objectSpread({}, state, {
      themes: _defineProperty({
        'bootstrap-styled': _bootstrapStyled.theme
      }, theme._name, theme)
    }), (0, _actions.changeTheme)('fakename'))).toEqual(expectedResult); // eslint-disable-line no-underscore-dangle
  });
  it('should handle the deleteTheme action correctly', function () {
    expectedResult = {
      theme: _bootstrapStyled.theme,
      themes: {}
    };
    expect((0, _reducer.default)(state, (0, _actions.deleteTheme)(_bootstrapStyled.theme))).toEqual(expectedResult);
  });
  it('should handle the storeTheme action correctly', function () {
    expectedResult = {
      theme: _bootstrapStyled.theme,
      themes: _defineProperty({}, theme._name, theme)
    };
    expect((0, _reducer.default)(state, (0, _actions.storeTheme)(theme))).toEqual(expectedResult);
  });
  it('should handle deleteThemes action correctly', function () {
    expectedResult = {
      theme: _bootstrapStyled.theme,
      themes: {}
    };
    expect((0, _reducer.default)(state, (0, _actions.deleteThemes)())).toEqual(expectedResult);
  });
});