import React from 'react';
import { compose } from 'redux';
import { connect } from 'react-redux';
import styledComponents from 'styled-components';

function defaultEqualityCheck(a, b) {
  return a === b;
}
function areArgumentsShallowlyEqual(equalityCheck, prev, next) {
  if (prev === null || next === null || prev.length !== next.length) {
    return false;
  }
  var length = prev.length;
  for (var i = 0; i < length; i++) {
    if (!equalityCheck(prev[i], next[i])) {
      return false;
    }
  }
  return true;
}
function defaultMemoize(func) {
  var equalityCheck = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultEqualityCheck;
  var lastArgs = null;
  var lastResult = null;
  return function () {
    if (!areArgumentsShallowlyEqual(equalityCheck, lastArgs, arguments)) {
      lastResult = func.apply(null, arguments);
    }
    lastArgs = arguments;
    return lastResult;
  };
}
function getDependencies(funcs) {
  var dependencies = Array.isArray(funcs[0]) ? funcs[0] : funcs;
  if (!dependencies.every(function (dep) {
    return typeof dep === 'function';
  })) {
    var dependencyTypes = dependencies.map(function (dep) {
      return typeof dep;
    }).join(', ');
    throw new Error('Selector creators expect all input-selectors to be functions, ' + ('instead received the following types: [' + dependencyTypes + ']'));
  }
  return dependencies;
}
function createSelectorCreator(memoize) {
  for (var _len = arguments.length, memoizeOptions = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    memoizeOptions[_key - 1] = arguments[_key];
  }
  return function () {
    for (var _len2 = arguments.length, funcs = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      funcs[_key2] = arguments[_key2];
    }
    var recomputations = 0;
    var resultFunc = funcs.pop();
    var dependencies = getDependencies(funcs);
    var memoizedResultFunc = memoize.apply(undefined, [function () {
      recomputations++;
      return resultFunc.apply(null, arguments);
    }].concat(memoizeOptions));
    var selector = memoize(function () {
      var params = [];
      var length = dependencies.length;
      for (var i = 0; i < length; i++) {
        params.push(dependencies[i].apply(null, arguments));
      }
      return memoizedResultFunc.apply(null, params);
    });
    selector.resultFunc = resultFunc;
    selector.dependencies = dependencies;
    selector.recomputations = function () {
      return recomputations;
    };
    selector.resetRecomputations = function () {
      return recomputations = 0;
    };
    return selector;
  };
}
var createSelector = createSelectorCreator(defaultMemoize);
function createStructuredSelector(selectors) {
  var selectorCreator = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : createSelector;
  if (typeof selectors !== 'object') {
    throw new Error('createStructuredSelector expects first argument to be an object ' + ('where each property is a selector, instead received a ' + typeof selectors));
  }
  var objectKeys = Object.keys(selectors);
  return selectorCreator(objectKeys.map(function (key) {
    return selectors[key];
  }), function () {
    for (var _len3 = arguments.length, values = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      values[_key3] = arguments[_key3];
    }
    return values.reduce(function (composition, value, index) {
      composition[objectKeys[index]] = value;
      return composition;
    }, {});
  });
}

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x.default : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

/*
object-assign
(c) Sindre Sorhus
@license MIT
*/
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;
function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}
	return Object(val);
}
function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}
		var test1 = new String('abc');
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}
		return true;
	} catch (err) {
		return false;
	}
}
var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;
	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);
		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}
		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}
	return to;
};

var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';
var ReactPropTypesSecret_1 = ReactPropTypesSecret;

var printWarning = function() {};
{
  var ReactPropTypesSecret$1 = ReactPropTypesSecret_1;
  var loggedTypeFailures = {};
  printWarning = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      throw new Error(message);
    } catch (x) {}
  };
}
function checkPropTypes(typeSpecs, values, location, componentName, getStack) {
  {
    for (var typeSpecName in typeSpecs) {
      if (typeSpecs.hasOwnProperty(typeSpecName)) {
        var error;
        try {
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            var err = Error(
              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +
              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'
            );
            err.name = 'Invariant Violation';
            throw err;
          }
          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret$1);
        } catch (ex) {
          error = ex;
        }
        if (error && !(error instanceof Error)) {
          printWarning(
            (componentName || 'React class') + ': type specification of ' +
            location + ' `' + typeSpecName + '` is invalid; the type checker ' +
            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +
            'You may have forgotten to pass an argument to the type checker ' +
            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +
            'shape all require an argument).'
          );
        }
        if (error instanceof Error && !(error.message in loggedTypeFailures)) {
          loggedTypeFailures[error.message] = true;
          var stack = getStack ? getStack() : '';
          printWarning(
            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')
          );
        }
      }
    }
  }
}
var checkPropTypes_1 = checkPropTypes;

var printWarning$1 = function() {};
{
  printWarning$1 = function(text) {
    var message = 'Warning: ' + text;
    if (typeof console !== 'undefined') {
      console.error(message);
    }
    try {
      throw new Error(message);
    } catch (x) {}
  };
}
function emptyFunctionThatReturnsNull() {
  return null;
}
var factoryWithTypeCheckers = function(isValidElement, throwOnDirectAccess) {
  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;
  var FAUX_ITERATOR_SYMBOL = '@@iterator';
  function getIteratorFn(maybeIterable) {
    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);
    if (typeof iteratorFn === 'function') {
      return iteratorFn;
    }
  }
  var ANONYMOUS = '<<anonymous>>';
  var ReactPropTypes = {
    array: createPrimitiveTypeChecker('array'),
    bool: createPrimitiveTypeChecker('boolean'),
    func: createPrimitiveTypeChecker('function'),
    number: createPrimitiveTypeChecker('number'),
    object: createPrimitiveTypeChecker('object'),
    string: createPrimitiveTypeChecker('string'),
    symbol: createPrimitiveTypeChecker('symbol'),
    any: createAnyTypeChecker(),
    arrayOf: createArrayOfTypeChecker,
    element: createElementTypeChecker(),
    instanceOf: createInstanceTypeChecker,
    node: createNodeChecker(),
    objectOf: createObjectOfTypeChecker,
    oneOf: createEnumTypeChecker,
    oneOfType: createUnionTypeChecker,
    shape: createShapeTypeChecker,
    exact: createStrictShapeTypeChecker,
  };
  function is(x, y) {
    if (x === y) {
      return x !== 0 || 1 / x === 1 / y;
    } else {
      return x !== x && y !== y;
    }
  }
  function PropTypeError(message) {
    this.message = message;
    this.stack = '';
  }
  PropTypeError.prototype = Error.prototype;
  function createChainableTypeChecker(validate) {
    {
      var manualPropTypeCallCache = {};
      var manualPropTypeWarningCount = 0;
    }
    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {
      componentName = componentName || ANONYMOUS;
      propFullName = propFullName || propName;
      if (secret !== ReactPropTypesSecret_1) {
        if (throwOnDirectAccess) {
          var err = new Error(
            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
            'Use `PropTypes.checkPropTypes()` to call them. ' +
            'Read more at http://fb.me/use-check-prop-types'
          );
          err.name = 'Invariant Violation';
          throw err;
        } else if (typeof console !== 'undefined') {
          var cacheKey = componentName + ':' + propName;
          if (
            !manualPropTypeCallCache[cacheKey] &&
            manualPropTypeWarningCount < 3
          ) {
            printWarning$1(
              'You are manually calling a React.PropTypes validation ' +
              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +
              'and will throw in the standalone `prop-types` package. ' +
              'You may be seeing this warning due to a third-party PropTypes ' +
              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'
            );
            manualPropTypeCallCache[cacheKey] = true;
            manualPropTypeWarningCount++;
          }
        }
      }
      if (props[propName] == null) {
        if (isRequired) {
          if (props[propName] === null) {
            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));
          }
          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));
        }
        return null;
      } else {
        return validate(props, propName, componentName, location, propFullName);
      }
    }
    var chainedCheckType = checkType.bind(null, false);
    chainedCheckType.isRequired = checkType.bind(null, true);
    return chainedCheckType;
  }
  function createPrimitiveTypeChecker(expectedType) {
    function validate(props, propName, componentName, location, propFullName, secret) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== expectedType) {
        var preciseType = getPreciseType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createAnyTypeChecker() {
    return createChainableTypeChecker(emptyFunctionThatReturnsNull);
  }
  function createArrayOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');
      }
      var propValue = props[propName];
      if (!Array.isArray(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));
      }
      for (var i = 0; i < propValue.length; i++) {
        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret_1);
        if (error instanceof Error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createElementTypeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      if (!isValidElement(propValue)) {
        var propType = getPropType(propValue);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createInstanceTypeChecker(expectedClass) {
    function validate(props, propName, componentName, location, propFullName) {
      if (!(props[propName] instanceof expectedClass)) {
        var expectedClassName = expectedClass.name || ANONYMOUS;
        var actualClassName = getClassName(props[propName]);
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createEnumTypeChecker(expectedValues) {
    if (!Array.isArray(expectedValues)) {
      printWarning$1('Invalid argument supplied to oneOf, expected an instance of array.');
      return emptyFunctionThatReturnsNull;
    }
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      for (var i = 0; i < expectedValues.length; i++) {
        if (is(propValue, expectedValues[i])) {
          return null;
        }
      }
      var valuesString = JSON.stringify(expectedValues);
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + propValue + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));
    }
    return createChainableTypeChecker(validate);
  }
  function createObjectOfTypeChecker(typeChecker) {
    function validate(props, propName, componentName, location, propFullName) {
      if (typeof typeChecker !== 'function') {
        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');
      }
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));
      }
      for (var key in propValue) {
        if (propValue.hasOwnProperty(key)) {
          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
          if (error instanceof Error) {
            return error;
          }
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createUnionTypeChecker(arrayOfTypeCheckers) {
    if (!Array.isArray(arrayOfTypeCheckers)) {
      printWarning$1('Invalid argument supplied to oneOfType, expected an instance of array.');
      return emptyFunctionThatReturnsNull;
    }
    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
      var checker = arrayOfTypeCheckers[i];
      if (typeof checker !== 'function') {
        printWarning$1(
          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +
          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'
        );
        return emptyFunctionThatReturnsNull;
      }
    }
    function validate(props, propName, componentName, location, propFullName) {
      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {
        var checker = arrayOfTypeCheckers[i];
        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret_1) == null) {
          return null;
        }
      }
      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));
    }
    return createChainableTypeChecker(validate);
  }
  function createNodeChecker() {
    function validate(props, propName, componentName, location, propFullName) {
      if (!isNode(props[propName])) {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      for (var key in shapeTypes) {
        var checker = shapeTypes[key];
        if (!checker) {
          continue;
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function createStrictShapeTypeChecker(shapeTypes) {
    function validate(props, propName, componentName, location, propFullName) {
      var propValue = props[propName];
      var propType = getPropType(propValue);
      if (propType !== 'object') {
        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));
      }
      var allKeys = objectAssign({}, props[propName], shapeTypes);
      for (var key in allKeys) {
        var checker = shapeTypes[key];
        if (!checker) {
          return new PropTypeError(
            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +
            '\nBad object: ' + JSON.stringify(props[propName], null, '  ') +
            '\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')
          );
        }
        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret_1);
        if (error) {
          return error;
        }
      }
      return null;
    }
    return createChainableTypeChecker(validate);
  }
  function isNode(propValue) {
    switch (typeof propValue) {
      case 'number':
      case 'string':
      case 'undefined':
        return true;
      case 'boolean':
        return !propValue;
      case 'object':
        if (Array.isArray(propValue)) {
          return propValue.every(isNode);
        }
        if (propValue === null || isValidElement(propValue)) {
          return true;
        }
        var iteratorFn = getIteratorFn(propValue);
        if (iteratorFn) {
          var iterator = iteratorFn.call(propValue);
          var step;
          if (iteratorFn !== propValue.entries) {
            while (!(step = iterator.next()).done) {
              if (!isNode(step.value)) {
                return false;
              }
            }
          } else {
            while (!(step = iterator.next()).done) {
              var entry = step.value;
              if (entry) {
                if (!isNode(entry[1])) {
                  return false;
                }
              }
            }
          }
        } else {
          return false;
        }
        return true;
      default:
        return false;
    }
  }
  function isSymbol(propType, propValue) {
    if (propType === 'symbol') {
      return true;
    }
    if (propValue['@@toStringTag'] === 'Symbol') {
      return true;
    }
    if (typeof Symbol === 'function' && propValue instanceof Symbol) {
      return true;
    }
    return false;
  }
  function getPropType(propValue) {
    var propType = typeof propValue;
    if (Array.isArray(propValue)) {
      return 'array';
    }
    if (propValue instanceof RegExp) {
      return 'object';
    }
    if (isSymbol(propType, propValue)) {
      return 'symbol';
    }
    return propType;
  }
  function getPreciseType(propValue) {
    if (typeof propValue === 'undefined' || propValue === null) {
      return '' + propValue;
    }
    var propType = getPropType(propValue);
    if (propType === 'object') {
      if (propValue instanceof Date) {
        return 'date';
      } else if (propValue instanceof RegExp) {
        return 'regexp';
      }
    }
    return propType;
  }
  function getPostfixForTypeWarning(value) {
    var type = getPreciseType(value);
    switch (type) {
      case 'array':
      case 'object':
        return 'an ' + type;
      case 'boolean':
      case 'date':
      case 'regexp':
        return 'a ' + type;
      default:
        return type;
    }
  }
  function getClassName(propValue) {
    if (!propValue.constructor || !propValue.constructor.name) {
      return ANONYMOUS;
    }
    return propValue.constructor.name;
  }
  ReactPropTypes.checkPropTypes = checkPropTypes_1;
  ReactPropTypes.PropTypes = ReactPropTypes;
  return ReactPropTypes;
};

var propTypes = createCommonjsModule(function (module) {
{
  var REACT_ELEMENT_TYPE = (typeof Symbol === 'function' &&
    Symbol.for &&
    Symbol.for('react.element')) ||
    0xeac7;
  var isValidElement = function(object) {
    return typeof object === 'object' &&
      object !== null &&
      object.$$typeof === REACT_ELEMENT_TYPE;
  };
  var throwOnDirectAccess = true;
  module.exports = factoryWithTypeCheckers(isValidElement, throwOnDirectAccess);
}
});

var r=function(r,t){if(!(r instanceof t))throw new TypeError("Cannot call a class as a function")};var t=function(r,t,e){return t in r?Object.defineProperty(r,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):r[t]=e,r};function e(r,t){return r(t={exports:{}},t.exports),t.exports}var o={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]},n=function(r){return !(!r||"string"==typeof r)&&(r instanceof Array||Array.isArray(r)||r.length>=0&&(r.splice instanceof Function||Object.getOwnPropertyDescriptor(r,r.length-1)&&"String"!==r.constructor.name))},a=e(function(r){var t=Array.prototype.concat,e=Array.prototype.slice,o=r.exports=function(r){for(var o=[],a=0,i=r.length;a<i;a++){var c=r[a];n(c)?o=t.call(o,e.call(c)):o.push(c);}return o};o.wrap=function(r){return function(){return r(o(arguments))}};}),i=e(function(r){var t={};for(var e in o)o.hasOwnProperty(e)&&(t[o[e]]=e);var n=r.exports={to:{},get:{}};function i(r,t,e){return Math.min(Math.max(t,r),e)}function c(r){var t=r.toString(16).toUpperCase();return t.length<2?"0"+t:t}n.get=function(r){var t,e;switch(r.substring(0,3).toLowerCase()){case"hsl":t=n.get.hsl(r),e="hsl";break;case"hwb":t=n.get.hwb(r),e="hwb";break;default:t=n.get.rgb(r),e="rgb";}return t?{model:e,value:t}:null},n.get.rgb=function(r){if(!r)return null;var t,e,n,a=[0,0,0,1];if(t=r.match(/^#([a-f0-9]{6})([a-f0-9]{2})?$/i)){for(n=t[2],t=t[1],e=0;e<3;e++){var c=2*e;a[e]=parseInt(t.slice(c,c+2),16);}n&&(a[3]=Math.round(parseInt(n,16)/255*100)/100);}else if(t=r.match(/^#([a-f0-9]{3,4})$/i)){for(n=(t=t[1])[3],e=0;e<3;e++)a[e]=parseInt(t[e]+t[e],16);n&&(a[3]=Math.round(parseInt(n+n,16)/255*100)/100);}else if(t=r.match(/^rgba?\(\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/)){for(e=0;e<3;e++)a[e]=parseInt(t[e+1],0);t[4]&&(a[3]=parseFloat(t[4]));}else{if(!(t=r.match(/^rgba?\(\s*([+-]?[\d\.]+)\%\s*,\s*([+-]?[\d\.]+)\%\s*,\s*([+-]?[\d\.]+)\%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/)))return (t=r.match(/(\D+)/))?"transparent"===t[1]?[0,0,0,0]:(a=o[t[1]])?(a[3]=1,a):null:null;for(e=0;e<3;e++)a[e]=Math.round(2.55*parseFloat(t[e+1]));t[4]&&(a[3]=parseFloat(t[4]));}for(e=0;e<3;e++)a[e]=i(a[e],0,255);return a[3]=i(a[3],0,1),a},n.get.hsl=function(r){if(!r)return null;var t=r.match(/^hsla?\(\s*([+-]?(?:\d*\.)?\d+)(?:deg)?\s*,\s*([+-]?[\d\.]+)%\s*,\s*([+-]?[\d\.]+)%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/);if(t){var e=parseFloat(t[4]);return [(parseFloat(t[1])+360)%360,i(parseFloat(t[2]),0,100),i(parseFloat(t[3]),0,100),i(isNaN(e)?1:e,0,1)]}return null},n.get.hwb=function(r){if(!r)return null;var t=r.match(/^hwb\(\s*([+-]?\d*[\.]?\d+)(?:deg)?\s*,\s*([+-]?[\d\.]+)%\s*,\s*([+-]?[\d\.]+)%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/);if(t){var e=parseFloat(t[4]);return [(parseFloat(t[1])%360+360)%360,i(parseFloat(t[2]),0,100),i(parseFloat(t[3]),0,100),i(isNaN(e)?1:e,0,1)]}return null},n.to.hex=function(){var r=a(arguments);return "#"+c(r[0])+c(r[1])+c(r[2])+(r[3]<1?c(Math.round(255*r[3])):"")},n.to.rgb=function(){var r=a(arguments);return r.length<4||1===r[3]?"rgb("+Math.round(r[0])+", "+Math.round(r[1])+", "+Math.round(r[2])+")":"rgba("+Math.round(r[0])+", "+Math.round(r[1])+", "+Math.round(r[2])+", "+r[3]+")"},n.to.rgb.percent=function(){var r=a(arguments),t=Math.round(r[0]/255*100),e=Math.round(r[1]/255*100),o=Math.round(r[2]/255*100);return r.length<4||1===r[3]?"rgb("+t+"%, "+e+"%, "+o+"%)":"rgba("+t+"%, "+e+"%, "+o+"%, "+r[3]+")"},n.to.hsl=function(){var r=a(arguments);return r.length<4||1===r[3]?"hsl("+r[0]+", "+r[1]+"%, "+r[2]+"%)":"hsla("+r[0]+", "+r[1]+"%, "+r[2]+"%, "+r[3]+")"},n.to.hwb=function(){var r=a(arguments),t="";return r.length>=4&&1!==r[3]&&(t=", "+r[3]),"hwb("+r[0]+", "+r[1]+"%, "+r[2]+"%"+t+")"},n.to.keyword=function(r){return t[r.slice(0,3)]};}),c=(i.to,i.get,e(function(r){var t={};for(var e in o)o.hasOwnProperty(e)&&(t[o[e]]=e);var n=r.exports={rgb:{channels:3,labels:"rgb"},hsl:{channels:3,labels:"hsl"},hsv:{channels:3,labels:"hsv"},hwb:{channels:3,labels:"hwb"},cmyk:{channels:4,labels:"cmyk"},xyz:{channels:3,labels:"xyz"},lab:{channels:3,labels:"lab"},lch:{channels:3,labels:"lch"},hex:{channels:1,labels:["hex"]},keyword:{channels:1,labels:["keyword"]},ansi16:{channels:1,labels:["ansi16"]},ansi256:{channels:1,labels:["ansi256"]},hcg:{channels:3,labels:["h","c","g"]},apple:{channels:3,labels:["r16","g16","b16"]},gray:{channels:1,labels:["gray"]}};for(var a in n)if(n.hasOwnProperty(a)){if(!("channels"in n[a]))throw new Error("missing channels property: "+a);if(!("labels"in n[a]))throw new Error("missing channel labels property: "+a);if(n[a].labels.length!==n[a].channels)throw new Error("channel and label counts mismatch: "+a);var i=n[a].channels,c=n[a].labels;delete n[a].channels,delete n[a].labels,Object.defineProperty(n[a],"channels",{value:i}),Object.defineProperty(n[a],"labels",{value:c});}n.rgb.hsl=function(r){var t,e,o=r[0]/255,n=r[1]/255,a=r[2]/255,i=Math.min(o,n,a),c=Math.max(o,n,a),l=c-i;return c===i?t=0:o===c?t=(n-a)/l:n===c?t=2+(a-o)/l:a===c&&(t=4+(o-n)/l),(t=Math.min(60*t,360))<0&&(t+=360),e=(i+c)/2,[t,100*(c===i?0:e<=.5?l/(c+i):l/(2-c-i)),100*e]},n.rgb.hsv=function(r){var t,e,o,n,a,i=r[0]/255,c=r[1]/255,l=r[2]/255,s=Math.max(i,c,l),d=s-Math.min(i,c,l),u=function(r){return (s-r)/6/d+.5};return 0===d?n=a=0:(a=d/s,t=u(i),e=u(c),o=u(l),i===s?n=o-e:c===s?n=1/3+t-o:l===s&&(n=2/3+e-t),n<0?n+=1:n>1&&(n-=1)),[360*n,100*a,100*s]},n.rgb.hwb=function(r){var t=r[0],e=r[1],o=r[2];return [n.rgb.hsl(r)[0],1/255*Math.min(t,Math.min(e,o))*100,100*(o=1-1/255*Math.max(t,Math.max(e,o)))]},n.rgb.cmyk=function(r){var t,e=r[0]/255,o=r[1]/255,n=r[2]/255;return [100*((1-e-(t=Math.min(1-e,1-o,1-n)))/(1-t)||0),100*((1-o-t)/(1-t)||0),100*((1-n-t)/(1-t)||0),100*t]},n.rgb.keyword=function(r){var e=t[r];if(e)return e;var n,a,i,c=1/0;for(var l in o)if(o.hasOwnProperty(l)){var s=(a=r,i=o[l],Math.pow(a[0]-i[0],2)+Math.pow(a[1]-i[1],2)+Math.pow(a[2]-i[2],2));s<c&&(c=s,n=l);}return n},n.keyword.rgb=function(r){return o[r]},n.rgb.xyz=function(r){var t=r[0]/255,e=r[1]/255,o=r[2]/255;return [100*(.4124*(t=t>.04045?Math.pow((t+.055)/1.055,2.4):t/12.92)+.3576*(e=e>.04045?Math.pow((e+.055)/1.055,2.4):e/12.92)+.1805*(o=o>.04045?Math.pow((o+.055)/1.055,2.4):o/12.92)),100*(.2126*t+.7152*e+.0722*o),100*(.0193*t+.1192*e+.9505*o)]},n.rgb.lab=function(r){var t=n.rgb.xyz(r),e=t[0],o=t[1],a=t[2];return o/=100,a/=108.883,e=(e/=95.047)>.008856?Math.pow(e,1/3):7.787*e+16/116,[116*(o=o>.008856?Math.pow(o,1/3):7.787*o+16/116)-16,500*(e-o),200*(o-(a=a>.008856?Math.pow(a,1/3):7.787*a+16/116))]},n.hsl.rgb=function(r){var t,e,o,n,a,i=r[0]/360,c=r[1]/100,l=r[2]/100;if(0===c)return [a=255*l,a,a];t=2*l-(e=l<.5?l*(1+c):l+c-l*c),n=[0,0,0];for(var s=0;s<3;s++)(o=i+1/3*-(s-1))<0&&o++,o>1&&o--,a=6*o<1?t+6*(e-t)*o:2*o<1?e:3*o<2?t+(e-t)*(2/3-o)*6:t,n[s]=255*a;return n},n.hsl.hsv=function(r){var t=r[0],e=r[1]/100,o=r[2]/100,n=e,a=Math.max(o,.01);return e*=(o*=2)<=1?o:2-o,n*=a<=1?a:2-a,[t,100*(0===o?2*n/(a+n):2*e/(o+e)),(o+e)/2*100]},n.hsv.rgb=function(r){var t=r[0]/60,e=r[1]/100,o=r[2]/100,n=Math.floor(t)%6,a=t-Math.floor(t),i=255*o*(1-e),c=255*o*(1-e*a),l=255*o*(1-e*(1-a));switch(o*=255,n){case 0:return [o,l,i];case 1:return [c,o,i];case 2:return [i,o,l];case 3:return [i,c,o];case 4:return [l,i,o];case 5:return [o,i,c]}},n.hsv.hsl=function(r){var t,e,o,n=r[0],a=r[1]/100,i=r[2]/100,c=Math.max(i,.01);return o=(2-a)*i,e=a*c,[n,100*(e=(e/=(t=(2-a)*c)<=1?t:2-t)||0),100*(o/=2)]},n.hwb.rgb=function(r){var t,e,o,n,a,i,c,l=r[0]/360,s=r[1]/100,d=r[2]/100,u=s+d;switch(u>1&&(s/=u,d/=u),o=6*l-(t=Math.floor(6*l)),0!=(1&t)&&(o=1-o),n=s+o*((e=1-d)-s),t){default:case 6:case 0:a=e,i=n,c=s;break;case 1:a=n,i=e,c=s;break;case 2:a=s,i=e,c=n;break;case 3:a=s,i=n,c=e;break;case 4:a=n,i=s,c=e;break;case 5:a=e,i=s,c=n;}return [255*a,255*i,255*c]},n.cmyk.rgb=function(r){var t=r[0]/100,e=r[1]/100,o=r[2]/100,n=r[3]/100;return [255*(1-Math.min(1,t*(1-n)+n)),255*(1-Math.min(1,e*(1-n)+n)),255*(1-Math.min(1,o*(1-n)+n))]},n.xyz.rgb=function(r){var t,e,o,n=r[0]/100,a=r[1]/100,i=r[2]/100;return e=-.9689*n+1.8758*a+.0415*i,o=.0557*n+-.204*a+1.057*i,t=(t=3.2406*n+-1.5372*a+-.4986*i)>.0031308?1.055*Math.pow(t,1/2.4)-.055:12.92*t,e=e>.0031308?1.055*Math.pow(e,1/2.4)-.055:12.92*e,o=o>.0031308?1.055*Math.pow(o,1/2.4)-.055:12.92*o,[255*(t=Math.min(Math.max(0,t),1)),255*(e=Math.min(Math.max(0,e),1)),255*(o=Math.min(Math.max(0,o),1))]},n.xyz.lab=function(r){var t=r[0],e=r[1],o=r[2];return e/=100,o/=108.883,t=(t/=95.047)>.008856?Math.pow(t,1/3):7.787*t+16/116,[116*(e=e>.008856?Math.pow(e,1/3):7.787*e+16/116)-16,500*(t-e),200*(e-(o=o>.008856?Math.pow(o,1/3):7.787*o+16/116))]},n.lab.xyz=function(r){var t,e,o,n=r[0];t=r[1]/500+(e=(n+16)/116),o=e-r[2]/200;var a=Math.pow(e,3),i=Math.pow(t,3),c=Math.pow(o,3);return e=a>.008856?a:(e-16/116)/7.787,t=i>.008856?i:(t-16/116)/7.787,o=c>.008856?c:(o-16/116)/7.787,[t*=95.047,e*=100,o*=108.883]},n.lab.lch=function(r){var t,e=r[0],o=r[1],n=r[2];return (t=360*Math.atan2(n,o)/2/Math.PI)<0&&(t+=360),[e,Math.sqrt(o*o+n*n),t]},n.lch.lab=function(r){var t,e=r[0],o=r[1];return t=r[2]/360*2*Math.PI,[e,o*Math.cos(t),o*Math.sin(t)]},n.rgb.ansi16=function(r){var t=r[0],e=r[1],o=r[2],a=1 in arguments?arguments[1]:n.rgb.hsv(r)[2];if(0===(a=Math.round(a/50)))return 30;var i=30+(Math.round(o/255)<<2|Math.round(e/255)<<1|Math.round(t/255));return 2===a&&(i+=60),i},n.hsv.ansi16=function(r){return n.rgb.ansi16(n.hsv.rgb(r),r[2])},n.rgb.ansi256=function(r){var t=r[0],e=r[1],o=r[2];return t===e&&e===o?t<8?16:t>248?231:Math.round((t-8)/247*24)+232:16+36*Math.round(t/255*5)+6*Math.round(e/255*5)+Math.round(o/255*5)},n.ansi16.rgb=function(r){var t=r%10;if(0===t||7===t)return r>50&&(t+=3.5),[t=t/10.5*255,t,t];var e=.5*(1+~~(r>50));return [(1&t)*e*255,(t>>1&1)*e*255,(t>>2&1)*e*255]},n.ansi256.rgb=function(r){if(r>=232){var t=10*(r-232)+8;return [t,t,t]}var e;return r-=16,[Math.floor(r/36)/5*255,Math.floor((e=r%36)/6)/5*255,e%6/5*255]},n.rgb.hex=function(r){var t=(((255&Math.round(r[0]))<<16)+((255&Math.round(r[1]))<<8)+(255&Math.round(r[2]))).toString(16).toUpperCase();return "000000".substring(t.length)+t},n.hex.rgb=function(r){var t=r.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);if(!t)return [0,0,0];var e=t[0];3===t[0].length&&(e=e.split("").map(function(r){return r+r}).join(""));var o=parseInt(e,16);return [o>>16&255,o>>8&255,255&o]},n.rgb.hcg=function(r){var t,e=r[0]/255,o=r[1]/255,n=r[2]/255,a=Math.max(Math.max(e,o),n),i=Math.min(Math.min(e,o),n),c=a-i;return t=c<=0?0:a===e?(o-n)/c%6:a===o?2+(n-e)/c:4+(e-o)/c+4,t/=6,[360*(t%=1),100*c,100*(c<1?i/(1-c):0)]},n.hsl.hcg=function(r){var t,e=r[1]/100,o=r[2]/100,n=0;return (t=o<.5?2*e*o:2*e*(1-o))<1&&(n=(o-.5*t)/(1-t)),[r[0],100*t,100*n]},n.hsv.hcg=function(r){var t=r[1]/100,e=r[2]/100,o=t*e,n=0;return o<1&&(n=(e-o)/(1-o)),[r[0],100*o,100*n]},n.hcg.rgb=function(r){var t=r[0]/360,e=r[1]/100,o=r[2]/100;if(0===e)return [255*o,255*o,255*o];var n,a=[0,0,0],i=t%1*6,c=i%1,l=1-c;switch(Math.floor(i)){case 0:a[0]=1,a[1]=c,a[2]=0;break;case 1:a[0]=l,a[1]=1,a[2]=0;break;case 2:a[0]=0,a[1]=1,a[2]=c;break;case 3:a[0]=0,a[1]=l,a[2]=1;break;case 4:a[0]=c,a[1]=0,a[2]=1;break;default:a[0]=1,a[1]=0,a[2]=l;}return n=(1-e)*o,[255*(e*a[0]+n),255*(e*a[1]+n),255*(e*a[2]+n)]},n.hcg.hsv=function(r){var t=r[1]/100,e=t+r[2]/100*(1-t),o=0;return e>0&&(o=t/e),[r[0],100*o,100*e]},n.hcg.hsl=function(r){var t=r[1]/100,e=r[2]/100*(1-t)+.5*t,o=0;return e>0&&e<.5?o=t/(2*e):e>=.5&&e<1&&(o=t/(2*(1-e))),[r[0],100*o,100*e]},n.hcg.hwb=function(r){var t=r[1]/100,e=t+r[2]/100*(1-t);return [r[0],100*(e-t),100*(1-e)]},n.hwb.hcg=function(r){var t=r[1]/100,e=1-r[2]/100,o=e-t,n=0;return o<1&&(n=(e-o)/(1-o)),[r[0],100*o,100*n]},n.apple.rgb=function(r){return [r[0]/65535*255,r[1]/65535*255,r[2]/65535*255]},n.rgb.apple=function(r){return [r[0]/255*65535,r[1]/255*65535,r[2]/255*65535]},n.gray.rgb=function(r){return [r[0]/100*255,r[0]/100*255,r[0]/100*255]},n.gray.hsl=n.gray.hsv=function(r){return [0,0,r[0]]},n.gray.hwb=function(r){return [0,100,r[0]]},n.gray.cmyk=function(r){return [0,0,0,r[0]]},n.gray.lab=function(r){return [r[0],0,0]},n.gray.hex=function(r){var t=255&Math.round(r[0]/100*255),e=((t<<16)+(t<<8)+t).toString(16).toUpperCase();return "000000".substring(e.length)+e},n.rgb.gray=function(r){return [(r[0]+r[1]+r[2])/3/255*100]};}));c.rgb,c.hsl,c.hsv,c.hwb,c.cmyk,c.xyz,c.lab,c.lch,c.hex,c.keyword,c.ansi16,c.ansi256,c.hcg,c.apple,c.gray;function l(r){var t=function(){for(var r={},t=Object.keys(c),e=t.length,o=0;o<e;o++)r[t[o]]={distance:-1,parent:null};return r}(),e=[r];for(t[r].distance=0;e.length;)for(var o=e.pop(),n=Object.keys(c[o]),a=n.length,i=0;i<a;i++){var l=n[i],s=t[l];-1===s.distance&&(s.distance=t[o].distance+1,s.parent=o,e.unshift(l));}return t}function s(r,t){return function(e){return t(r(e))}}function d(r,t){for(var e=[t[r].parent,r],o=c[t[r].parent][r],n=t[r].parent;t[n].parent;)e.unshift(t[n].parent),o=s(c[t[n].parent][n],o),n=t[n].parent;return o.conversion=e,o}var u={};Object.keys(c).forEach(function(r){u[r]={},Object.defineProperty(u[r],"channels",{value:c[r].channels}),Object.defineProperty(u[r],"labels",{value:c[r].labels});var t=function(r){for(var t=l(r),e={},o=Object.keys(t),n=o.length,a=0;a<n;a++){var i=o[a];null!==t[i].parent&&(e[i]=d(i,t));}return e}(r);Object.keys(t).forEach(function(e){var o=t[e];u[r][e]=function(r){var t=function(t){if(null==t)return t;arguments.length>1&&(t=Array.prototype.slice.call(arguments));var e=r(t);if("object"==typeof e)for(var o=e.length,n=0;n<o;n++)e[n]=Math.round(e[n]);return e};return "conversion"in r&&(t.conversion=r.conversion),t}(o),u[r][e].raw=function(r){var t=function(t){return null==t?t:(arguments.length>1&&(t=Array.prototype.slice.call(arguments)),r(t))};return "conversion"in r&&(t.conversion=r.conversion),t}(o);});});var g=u,$=[].slice,b=["keyword","gray","hex"],h={};Object.keys(g).forEach(function(r){h[$.call(g[r].labels).sort().join("")]=r;});var p={};function f(r,t){if(!(this instanceof f))return new f(r,t);if(t&&t in b&&(t=null),t&&!(t in g))throw new Error("Unknown model: "+t);var e,o;if(void 0===r)this.model="rgb",this.color=[0,0,0],this.valpha=1;else if(r instanceof f)this.model=r.model,this.color=r.color.slice(),this.valpha=r.valpha;else if("string"==typeof r){var n=i.get(r);if(null===n)throw new Error("Unable to parse color from string: "+r);this.model=n.model,o=g[this.model].channels,this.color=n.value.slice(0,o),this.valpha="number"==typeof n.value[o]?n.value[o]:1;}else if(r.length){this.model=t||"rgb",o=g[this.model].channels;var a=$.call(r,0,o);this.color=y(a,o),this.valpha="number"==typeof r[o]?r[o]:1;}else if("number"==typeof r)r&=16777215,this.model="rgb",this.color=[r>>16&255,r>>8&255,255&r],this.valpha=1;else{this.valpha=1;var c=Object.keys(r);"alpha"in r&&(c.splice(c.indexOf("alpha"),1),this.valpha="number"==typeof r.alpha?r.alpha:0);var l=c.sort().join("");if(!(l in h))throw new Error("Unable to parse color from object: "+JSON.stringify(r));this.model=h[l];var s=g[this.model].labels,d=[];for(e=0;e<s.length;e++)d.push(r[s[e]]);this.color=y(d);}if(p[this.model])for(o=g[this.model].channels,e=0;e<o;e++){var u=p[this.model][e];u&&(this.color[e]=u(this.color[e]));}this.valpha=Math.max(0,Math.min(1,this.valpha)),Object.freeze&&Object.freeze(this);}function m(r){return function(t){return function(r,t){return Number(r.toFixed(t))}(t,r)}}function v(r,t,e){return (r=Array.isArray(r)?r:[r]).forEach(function(r){(p[r]||(p[r]=[]))[t]=e;}),r=r[0],function(o){var n;return arguments.length?(e&&(o=e(o)),(n=this[r]()).color[t]=o,n):(n=this[r]().color[t],e&&(n=e(n)),n)}}function w(r){return function(t){return Math.max(0,Math.min(r,t))}}function y(r,t){for(var e=0;e<t;e++)"number"!=typeof r[e]&&(r[e]=0);return r}f.prototype={toString:function(){return this.string()},toJSON:function(){return this[this.model]()},string:function(r){var t=this.model in i.to?this:this.rgb(),e=1===(t=t.round("number"==typeof r?r:1)).valpha?t.color:t.color.concat(this.valpha);return i.to[t.model](e)},percentString:function(r){var t=this.rgb().round("number"==typeof r?r:1),e=1===t.valpha?t.color:t.color.concat(this.valpha);return i.to.rgb.percent(e)},array:function(){return 1===this.valpha?this.color.slice():this.color.concat(this.valpha)},object:function(){for(var r={},t=g[this.model].channels,e=g[this.model].labels,o=0;o<t;o++)r[e[o]]=this.color[o];return 1!==this.valpha&&(r.alpha=this.valpha),r},unitArray:function(){var r=this.rgb().color;return r[0]/=255,r[1]/=255,r[2]/=255,1!==this.valpha&&r.push(this.valpha),r},unitObject:function(){var r=this.rgb().object();return r.r/=255,r.g/=255,r.b/=255,1!==this.valpha&&(r.alpha=this.valpha),r},round:function(r){return r=Math.max(r||0,0),new f(this.color.map(m(r)).concat(this.valpha),this.model)},alpha:function(r){return arguments.length?new f(this.color.concat(Math.max(0,Math.min(1,r))),this.model):this.valpha},red:v("rgb",0,w(255)),green:v("rgb",1,w(255)),blue:v("rgb",2,w(255)),hue:v(["hsl","hsv","hsl","hwb","hcg"],0,function(r){return (r%360+360)%360}),saturationl:v("hsl",1,w(100)),lightness:v("hsl",2,w(100)),saturationv:v("hsv",1,w(100)),value:v("hsv",2,w(100)),chroma:v("hcg",1,w(100)),gray:v("hcg",2,w(100)),white:v("hwb",1,w(100)),wblack:v("hwb",2,w(100)),cyan:v("cmyk",0,w(100)),magenta:v("cmyk",1,w(100)),yellow:v("cmyk",2,w(100)),black:v("cmyk",3,w(100)),x:v("xyz",0,w(100)),y:v("xyz",1,w(100)),z:v("xyz",2,w(100)),l:v("lab",0,w(100)),a:v("lab",1),b:v("lab",2),keyword:function(r){return arguments.length?new f(r):g[this.model].keyword(this.color)},hex:function(r){return arguments.length?new f(r):i.to.hex(this.rgb().round().color)},rgbNumber:function(){var r=this.rgb().color;return (255&r[0])<<16|(255&r[1])<<8|255&r[2]},luminosity:function(){for(var r=this.rgb().color,t=[],e=0;e<r.length;e++){var o=r[e]/255;t[e]=o<=.03928?o/12.92:Math.pow((o+.055)/1.055,2.4);}return .2126*t[0]+.7152*t[1]+.0722*t[2]},contrast:function(r){var t=this.luminosity(),e=r.luminosity();return t>e?(t+.05)/(e+.05):(e+.05)/(t+.05)},level:function(r){var t=this.contrast(r);return t>=7.1?"AAA":t>=4.5?"AA":""},isDark:function(){var r=this.rgb().color;return (299*r[0]+587*r[1]+114*r[2])/1e3<128},isLight:function(){return !this.isDark()},negate:function(){for(var r=this.rgb(),t=0;t<3;t++)r.color[t]=255-r.color[t];return r},lighten:function(r){var t=this.hsl();return t.color[2]+=t.color[2]*r,t},darken:function(r){var t=this.hsl();return t.color[2]-=t.color[2]*r,t},saturate:function(r){var t=this.hsl();return t.color[1]+=t.color[1]*r,t},desaturate:function(r){var t=this.hsl();return t.color[1]-=t.color[1]*r,t},whiten:function(r){var t=this.hwb();return t.color[1]+=t.color[1]*r,t},blacken:function(r){var t=this.hwb();return t.color[2]+=t.color[2]*r,t},grayscale:function(){var r=this.rgb().color,t=.3*r[0]+.59*r[1]+.11*r[2];return f.rgb(t,t,t)},fade:function(r){return this.alpha(this.valpha-this.valpha*r)},opaquer:function(r){return this.alpha(this.valpha+this.valpha*r)},rotate:function(r){var t=this.hsl(),e=t.color[0];return e=(e=(e+r)%360)<0?360+e:e,t.color[0]=e,t},mix:function(r,t){var e=r.rgb(),o=this.rgb(),n=void 0===t?.5:t,a=2*n-1,i=e.alpha()-o.alpha(),c=((a*i==-1?a:(a+i)/(1+a*i))+1)/2,l=1-c;return f.rgb(c*e.red()+l*o.red(),c*e.green()+l*o.green(),c*e.blue()+l*o.blue(),e.alpha()*n+o.alpha()*(1-n))}},Object.keys(g).forEach(function(r){if(-1===b.indexOf(r)){var t=g[r].channels;f.prototype[r]=function(){if(this.model===r)return new f(this);if(arguments.length)return new f(arguments,r);var e="number"==typeof arguments[t]?t:this.valpha;return new f(function(r){return Array.isArray(r)?r:[r]}(g[this.model][r].raw(this.color)).concat(e),r)},f[r]=function(e){return "number"==typeof e&&(e=y($.call(arguments),t)),new f(e,r)};}});var x=f,k=function e(o){var n=this;r(this,e),t(this,"hsl",function(){return n}),t(this,"isLight",function(){return !1}),t(this,"isDark",function(){return !1}),t(this,"negate",function(){return n}),t(this,"lighten",function(){return n}),t(this,"darken",function(){return n}),t(this,"alpha",function(){return n}),t(this,"saturate",function(){return n}),t(this,"desaturate",function(){return n}),t(this,"grayscale",function(){return n}),t(this,"whiten",function(){return n}),t(this,"blacken",function(){return n}),t(this,"fade",function(){return n}),t(this,"opaquer",function(){return n}),t(this,"rotate",function(){return n}),t(this,"contrast",function(){return 10}),t(this,"luminosity",function(){return .5}),t(this,"mix",function(){return n}),t(this,"blue",function(){return n.toString()}),t(this,"green",function(){return n.toString()}),t(this,"red",function(){return n.toString()}),t(this,"hex",function(){return n.toString()}),t(this,"rgbNumber",function(){return n.toString()}),t(this,"rgb",function(){return n.toString()}),t(this,"toString",function(){return n.color}),this.color=o;};function z(r){return "string"==typeof r&&-1!==r.indexOf("linear-gradient")?new k(r):x(r)}var M="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function _(r){return r&&r.__esModule&&Object.prototype.hasOwnProperty.call(r,"default")?r.default:r}function j(r,t){return r(t={exports:{}},t.exports),t.exports}var S=_(j(function(r,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var e=new function r(){var t=this;!function(r,t){if(!(r instanceof t))throw new TypeError("Cannot call a class as a function")}(this,r),this.UNIT={EM:"em",REM:"rem",PX:"px",PERCENT:"%"},this.math={addition:function(r,t){var e=this.detectUnit(r)||this.detectUnit(t);return this.rmUnit(r)+this.rmUnit(t)+e}.bind(this),subtract:function(r,t){var e=this.detectUnit(r)||this.detectUnit(t);return this.rmUnit(r)-this.rmUnit(t)+e}.bind(this),multiply:function(r,t){var e=this.detectUnit(r)||this.detectUnit(t);return this.rmUnit(r)*this.rmUnit(t)+e}.bind(this),divide:function(r,t){var e=this.detectUnit(r)||this.detectUnit(t);return this.rmUnit(r)/this.rmUnit(t)+e}.bind(this)},this.detectUnit=function(r){var e,o=r.toString();if(o.match(t.UNIT.PX))e=t.UNIT.PX;else if(o.match(t.UNIT.REM))e=t.UNIT.REM;else if(o.match(t.UNIT.EM))e=t.UNIT.EM;else{if(!o.match(t.UNIT.PERCENT)){if(isNaN(r))throw new Error("detectUnit can't find unit for ".concat(r));return null}e=t.UNIT.PERCENT;}return e},this.rmUnit=function(r,e){var o=r.toString(),n=e||t.detectUnit(o),a=o.replace(n,"");return parseFloat(a)},this.toPercent=function(r){var e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:100,o=arguments.length>2&&void 0!==arguments[2]?arguments[2]:2;return "".concat(Math.floor(r/e*100*Math.pow(10,o))/Math.pow(10,o)).concat(t.UNIT.PERCENT)};};t.default=e,r.exports=t.default;}));function E(r,t){return !1===r?r:r||t}function O(r,t){var e,o,n=!0;return Object.keys(r).forEach(function(a){var i,c,l=r[a];null==o||(i=S.rmUnit(o),c=S.rmUnit(l),isNaN(i+c)?(console.warn("Potentially invalid value for ".concat(t,": This map must be in ascending order, but key '").concat(a,"' has value ").concat(l," whose unit makes it incomparable to ").concat(o,", the value of the previous key '").concat(e,"' !")),n=!1):S.rmUnit(o)>=S.rmUnit(l)&&(console.warn("Invalid value for ".concat(t,": This map must be in ascending order, but key '").concat(a,"' has value ").concat(l," which isn't greater than ").concat(o,", the value of the previous key '").concat(e,"' !")),n=!1)),e=a,o=l;}),n}var U=/#[0-9a-fA-F]{3,6}|rgb ?\([ 0-9.%,]+?\)/g,C=S.detectUnit,A=S.rmUnit;function P(){var r,t,e,o,n=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},a={},i=n;return a._name=i._name||"bootstrap-styled",a.$white=i.$white||"#fff",a.$black=i.$black||"#000",a.$red=i.$red||"#d9534f",a.$orange=i.$orange||"#f0ad4e",a.$yellow=i.$yellow||"#ffd500",a.$green=i.$green||"#5cb85c",a.$blue=i.$blue||"#0275d8",a.$teal=i.$teal||"#5bc0de",a.$pink=i.$pink||"#ff5b77",a.$purple=i.$purple||"#613d7c",a["$gray-dark"]=i["$gray-dark"]||"#292b2c",a.$gray=i.$gray||"#464a4c",a["$gray-light"]=i["$gray-light"]||"#636c72",a["$gray-lighter"]=i["$gray-lighter"]||"#eceeef",a["$gray-lightest"]=i["$gray-lightest"]||"#f7f7f9",a["$brand-primary"]=i["$brand-primary"]||a.$blue,a["$brand-success"]=i["$brand-success"]||a.$green,a["$brand-info"]=i["$brand-info"]||a.$teal,a["$brand-warning"]=i["$brand-warning"]||a.$orange,a["$brand-danger"]=i["$brand-danger"]||a.$red,a["$brand-inverse"]=i["$brand-inverse"]||a["$gray-dark"],a["$enable-rounded"]=E(i["$enable-rounded"],!0),a["$enable-shadows"]=E(i["$enable-shadows"],!1),a["$enable-gradients"]=E(i["$enable-gradients"],!1),a["$enable-transitions"]=E(i["$enable-transitions"],!0),a["$enable-hover-media-query"]=E(i["$enable-hover-media-query"],!1),a["$enable-grid-classes"]=E(i["$enable-grid-classes"],!0),a["$enable-print-styles"]=E(i["$enable-print-styles"],!0),a.$spacer=i.$spacer||"1rem",r=C(a.$spacer),a["$spacer-halved"]=i["$spacer-halved"]||A(a.$spacer,r)/2+r,a["$spacer-x"]=i["$spacer-x"]||a.$spacer,a["$spacer-y"]=i["$spacer-y"]||a.$spacer,a.$spacers=i.$spacers||{0:{x:0,y:0},1:{x:.25*A(a["$spacer-x"])+r,y:.25*A(a["$spacer-y"])+r},2:{x:.5*A(a["$spacer-x"])+r,y:.5*A(a["$spacer-y"])+r},3:{x:a["$spacer-x"],y:a["$spacer-y"]},4:{x:1.5*A(a["$spacer-x"])+r,y:1.5*A(a["$spacer-y"])+r},5:{x:3*A(a["$spacer-x"])+r,y:3*A(a["$spacer-y"])+r}},a["$border-width"]=i["$border-width"]||"1px",a.$sizes=i.$sizes||{25:"25%",50:"50%",75:"75%",100:"100%"},a["$body-bg"]=i["$body-bg"]||a.$white,a["$body-color"]=i["$body-color"]||a["$gray-dark"],a["$link-color"]=i["$link-color"]||a["$brand-primary"],a["$link-decoration"]=i["$link-decoration"]||"none",a["$link-hover-color"]=i["$link-hover-color"]||z(a["$link-color"]).darken(.35).toString(),a["$link-hover-decoration"]=i["$link-hover-decoration"]||"underline",a["$grid-breakpoints"]=i["$grid-breakpoints"]||{xs:"0",sm:"576px",md:"768px",lg:"992px",xl:"1200px",xxl:"1452px"},O(a["$grid-breakpoints"],"$grid-breakpoints"),t=a["$grid-breakpoints"],e=Object.keys(t).map(function(r){return t[r]}),o=S.rmUnit(e[0]),0!==o&&(console.warn("First breakpoint in $grid-breakpoints must start at 0, but starts at ".concat(o,".")),!1),a["$container-max-widths"]=i["$container-max-widths"]||{sm:"540px",md:"720px",lg:"960px",xl:"1140px"},O(a["$container-max-widths"],"$container-max-widths"),a["$grid-columns"]=i["$grid-columns"]||"12",a["$grid-gutter-width"]=i["$grid-gutter-width"]||"30px",a["$font-family-sans-serif"]=i["$font-family-sans-serif"]||'-apple-system, system-ui, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif',a["$font-family-monospace"]=i["$font-family-monospace"]||'Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace',a["$font-family-base"]=i["$font-family-base"]||a["$font-family-sans-serif"],a["$font-size-base"]=i["$font-size-base"]||"1rem",a["$font-size-lg"]=i["$font-size-lg"]||"1.25rem",a["$font-size-sm"]=i["$font-size-sm"]||".875rem",a["$font-size-xs"]=i["$font-size-xs"]||".75rem",a["$font-weight-normal"]=i["$font-weight-normal"]||"normal",a["$font-weight-bold"]=i["$font-weight-bold"]||"bold",a["$font-weight-base"]=i["$font-weight-base"]||a["$font-weight-normal"],a["$line-height-base"]=i["$line-height-base"]||"1.5",a["$font-size-h1"]=i["$font-size-h1"]||"2.5rem",a["$font-size-h2"]=i["$font-size-h2"]||"2rem",a["$font-size-h3"]=i["$font-size-h3"]||"1.75rem",a["$font-size-h4"]=i["$font-size-h4"]||"1.5rem",a["$font-size-h5"]=i["$font-size-h5"]||"1.25rem",a["$font-size-h6"]=i["$font-size-h6"]||"1rem",r=C(a.$spacer),a["$headings-margin-bottom"]=i["$headings-margin-bottom"]||A(a.$spacer,r)/2+r,a["$headings-font-family"]=i["$headings-font-family"]||"inherit",a["$headings-font-weight"]=i["$headings-font-weight"]||"500",a["$headings-line-height"]=i["$headings-line-height"]||"1.1",a["$headings-color"]=i["$headings-color"]||"inherit",a["$display1-size"]=i["$display1-size"]||"6rem",a["$display2-size"]=i["$display2-size"]||"5.5rem",a["$display3-size"]=i["$display3-size"]||"4.5rem",a["$display4-size"]=i["$display4-size"]||"3.5rem",a["$display1-weight"]=i["$display1-weight"]||"300",a["$display2-weight"]=i["$display2-weight"]||"300",a["$display3-weight"]=i["$display3-weight"]||"300",a["$display4-weight"]=i["$display4-weight"]||"300",a["$display-line-height"]=i["$display-line-height"]||a["$headings-line-height"],a["$lead-font-size"]=i["$lead-font-size"]||"1.25rem",a["$lead-font-weight"]=i["$lead-font-weight"]||"300",a["$small-font-size"]=i["$small-font-size"]||"80%",a["$text-muted"]=i["$text-muted"]||a["$gray-light"],a["$blockquote-small-color"]=i["$blockquote-small-color"]||a["$gray-light"],r=C(a["$font-size-base"]),a["$blockquote-font-size"]=i["$blockquote-font-size"]||1.25*A(a["$font-size-base"],r)+r,a["$blockquote-border-color"]=i["$blockquote-border-color"]||a["$gray-lighter"],a["$blockquote-border-width"]=i["$blockquote-border-width"]||".25rem",a["$hr-border-color"]=i["$hr-border-color"]||z(a.$black).alpha(.1).toString(),a["$hr-border-width"]=i["$hr-border-width"]||a["$border-width"],a["$mark-padding"]=i["$mark-padding"]||".2em",a["$dt-font-weight"]=i["$dt-font-weight"]||a["$font-weight-bold"],a["$list-inline-padding"]=i["$list-inline-padding"]||"5px",a["$line-height-lg"]=i["$line-height-lg"]||"1.6",a["$line-height-sm"]=i["$line-height-sm"]||"1.3",a["$border-radius"]=i["$border-radius"]||".25rem",a["$border-radius-lg"]=i["$border-radius-lg"]||".3rem",a["$border-radius-sm"]=i["$border-radius-sm"]||".2rem",a["$component-active-color"]=i["$component-active-color"]||a.$white,a["$component-active-bg"]=i["$component-active-bg"]||a["$brand-primary"],a["$caret-width"]=i["$caret-width"]||".3em",a["$transition-base"]=i["$transition-base"]||"all .2s ease-in-out",a["$transition-fade"]=i["$transition-fade"]||"opacity .15s linear",a["$transition-collapse"]=i["$transition-collapse"]||"height .35s ease",a["$table-cell-padding"]=i["$table-cell-padding"]||".75rem",a["$table-sm-cell-padding"]=i["$table-sm-cell-padding"]||".3rem",a["$table-bg"]=i["$table-bg"]||"transparent",a["$table-inverse-bg"]=i["$table-inverse-bg"]||a["$gray-dark"],a["$table-inverse-bg-accent"]=i["$table-inverse-bg-accent"]||z(a.$white).alpha(.05).toString(),a["$table-inverse-bg-hover"]=i["$table-inverse-bg-hover"]||z(a.$white).alpha(.075).toString(),a["$table-inverse-color"]=i["$table-inverse-color"]||a["$body-bg"],a["$table-inverse-border"]=i["$table-inverse-border"]||z(a["$gray-dark"]).lighten(.075).toString(),a["$table-bg-accent"]=i["$table-bg-accent"]||z(a.$black).alpha(.05).toString(),a["$table-bg-hover"]=i["$table-bg-hover"]||z(a.$black).alpha(.075).toString(),a["$table-bg-active"]=i["$table-bg-active"]||a["$table-bg-hover"],a["$table-head-bg"]=i["$table-head-bg"]||a["$gray-lighter"],a["$table-head-color"]=i["$table-head-color"]||a.$gray,a["$table-border-width"]=i["$table-border-width"]||a["$border-width"],a["$table-border-color"]=i["$table-border-color"]||a["$gray-lighter"],a["$btn-padding-x"]=i["$btn-padding-x"]||"1rem",a["$btn-padding-y"]=i["$btn-padding-y"]||".5rem",a["$btn-line-height"]=i["$btn-line-height"]||"1.25",a["$btn-font-weight"]=i["$btn-font-weight"]||a["$font-weight-normal"],a["$btn-box-shadow"]=i["$btn-box-shadow"]||"inset 0 1px 0 ".concat(z(a.$white).alpha(.15).toString(),", 0 1px 1px ").concat(z(a.$black).alpha(.075).toString()),a["$btn-focus-box-shadow"]=i["$btn-focus-box-shadow"]||"0 0 0 2px ".concat(z(a["$brand-primary"]).alpha(.25).toString()),a["$btn-disabled-opacity"]=i["$btn-disabled-opacity"]||".65",a["$btn-active-box-shadow"]=i["$btn-active-box-shadow"]||"inset 0 3px 5px ".concat(z(a.$black).alpha(.125).toString()),a["$btn-primary-color"]=i["$btn-primary-color"]||a.$white,a["$btn-primary-bg"]=i["$btn-primary-bg"]||a["$brand-primary"],a["$btn-secondary-color"]=i["$btn-secondary-color"]||a["$gray-dark"],a["$btn-secondary-bg"]=i["$btn-secondary-bg"]||a.$white,a["$btn-info-color"]=i["$btn-info-color"]||a.$white,a["$btn-info-bg"]=i["$btn-info-bg"]||a["$brand-info"],a["$btn-success-color"]=i["$btn-success-color"]||a.$white,a["$btn-success-bg"]=i["$btn-success-bg"]||a["$brand-success"],a["$btn-warning-color"]=i["$btn-warning-color"]||a.$white,a["$btn-warning-bg"]=i["$btn-warning-bg"]||a["$brand-warning"],a["$btn-danger-color"]=i["$btn-danger-color"]||a.$white,a["$btn-danger-bg"]=i["$btn-danger-bg"]||a["$brand-danger"],["primary","secondary","info","success","warning","danger"].forEach(function(r){a["$btn-".concat(r,"-bg")].includes("linear-gradient")?a["$btn-".concat(r,"-border")]=a["$btn-".concat(r,"-bg")].match(U)[1]:"secondary"===r?a["$btn-secondary-border"]=i["$btn-secondary-border"]||"#ccc":a["$btn-".concat(r,"-border")]=i["$btn-".concat(r,"-border")]||a["$btn-".concat(r,"-bg")];}),a["$btn-link-disabled-color"]=i["$btn-link-disabled-color"]||a["$gray-light"],a["$btn-padding-x-sm"]=i["$btn-padding-x-sm"]||".5rem",a["$btn-padding-y-sm"]=i["$btn-padding-y-sm"]||".25rem",a["$btn-padding-x-lg"]=i["$btn-padding-x-lg"]||"1.5rem",a["$btn-padding-y-lg"]=i["$btn-padding-y-lg"]||".75rem",a["$btn-block-spacing-y"]=i["$btn-block-spacing-y"]||".5rem",a["$btn-border-radius"]=i["$btn-border-radius"]||a["$border-radius"],a["$btn-border-radius-lg"]=i["$btn-border-radius-lg"]||a["$border-radius-lg"],a["$btn-border-radius-sm"]=i["$btn-border-radius-sm"]||a["$border-radius-sm"],a["$btn-transition"]=i["$btn-transition"]||a["$transition-base"],a["$input-padding-x"]=i["$input-padding-x"]||".75rem",a["$input-padding-y"]=i["$input-padding-y"]||".5rem",a["$input-line-height"]=i["$input-line-height"]||"1.25",a["$input-bg"]=i["$input-bg"]||a.$white,a["$input-bg-disabled"]=i["$input-bg-disabled"]||a["$gray-lighter"],a["$input-color"]=i["$input-color"]||a.$gray,a["$input-border-color"]=i["$input-border-color"]||z(a.$black).alpha(.15).toString(),a["$input-btn-border-width"]=i["$input-btn-border-width"]||a["$border-width"],a["$input-box-shadow"]=i["$input-box-shadow"]||"inset 0 1px 1px ".concat(z(a.$black).alpha(.075).toString()),a["$input-border-radius"]=i["$input-border-radius"]||a["$border-radius"],a["$input-border-radius-lg"]=i["$input-border-radius-lg"]||a["$border-radius-lg"],a["$input-border-radius-sm"]=i["$input-border-radius-sm"]||a["$border-radius-sm"],a["$input-bg-focus"]=i["$input-bg-focus"]||a["$input-bg"],a["$input-border-focus"]=i["$input-border-focus"]||z(a["$brand-primary"]).lighten(.25).toString(),a["$input-box-shadow-focus"]=i["$input-box-shadow-focus"]||"".concat(a["$input-box-shadow"],", 0 0 8px rgba(").concat(a["$input-border-focus"],",.6)"),a["$input-color-focus"]=i["$input-color-focus"]||a["$input-color"],a["$input-color-placeholder"]=i["$input-color-placeholder"]||a["$gray-light"],a["$input-padding-x-sm"]=i["$input-padding-x-sm"]||".5rem",a["$input-padding-y-sm"]=i["$input-padding-y-sm"]||".25rem",a["$input-padding-x-lg"]=i["$input-padding-x-lg"]||"1.5rem",a["$input-padding-y-lg"]=i["$input-padding-y-lg"]||".75rem",r=C(a["$font-size-base"]),a["$input-height"]=i["$input-height"]||A(a["$font-size-base"],r)*a["$line-height-base"]+2*A(a["$input-padding-y"],r)+r,a["$input-height-sm"]=i["$input-height-sm"]||A(a["$font-size-sm"],r)*a["$line-height-sm"]+2*A(a["$input-padding-y-sm"],r)+r,a["$input-height-lg"]=i["$input-height-lg"]||A(a["$font-size-lg"],r)*a["$line-height-lg"]+2*A(a["$input-padding-y-lg"],r)+r,a["$input-transition"]=i["$input-transition"]||"border-color ease-in-out .15s, box-shadow ease-in-out .15s",a["$label-margin-bottom"]=i["$label-margin-bottom"]||".5rem",a["$form-text-margin-top"]=i["$form-text-margin-top"]||".25rem",a["$form-feedback-margin-top"]=i["$form-feedback-margin-top"]||a["$form-text-margin-top"],a["$form-check-margin-bottom"]=i["$form-check-margin-bottom"]||".5rem",a["$form-check-input-gutter"]=i["$form-check-input-gutter"]||"1.25rem",a["$form-check-input-margin-y"]=i["$form-check-input-margin-y"]||".25rem",a["$form-check-input-margin-x"]=i["$form-check-input-margin-x"]||".25rem",a["$form-check-inline-margin-x"]=i["$form-check-inline-margin-x"]||".75rem",a["$form-group-margin-bottom"]=i["$form-group-margin-bottom"]||a["$spacer-y"],a["$input-group-addon-bg"]=i["$input-group-addon-bg"]||a["$gray-lighter"],a["$input-group-addon-border-color"]=i["$input-group-addon-border-color"]||a["$input-border-color"],a["$cursor-disabled"]=i["$cursor-disabled"]||"not-allowed",a["$custom-control-gutter"]=i["$custom-control-gutter"]||"1.5rem",a["$custom-control-spacer-x"]=i["$custom-control-spacer-x"]||"1rem",a["$custom-control-spacer-y"]=i["$custom-control-spacer-y"]||".25rem",a["$custom-control-indicator-size"]=i["$custom-control-indicator-size"]||"1rem",a["$custom-control-indicator-bg"]=i["$custom-control-indicator-bg"]||"#ddd",a["$custom-control-indicator-bg-size"]=i["$custom-control-indicator-bg-size"]||"50% 50%",a["$custom-control-indicator-box-shadow"]=i["$custom-control-indicator-box-shadow"]||"inset 0 .25rem .25rem ".concat(z(a.$black).alpha(.1).toString()),a["$custom-control-disabled-cursor"]=i["$custom-control-disabled-cursor"]||a["$cursor-disabled"],a["$custom-control-disabled-indicator-bg"]=i["$custom-control-disabled-indicator-bg"]||a["$gray-lighter"],a["$custom-control-disabled-description-color"]=i["$custom-control-disabled-description-color"]||a["$gray-light"],a["$custom-control-checked-indicator-color"]=i["$custom-control-checked-indicator-color"]||a.$white,a["$custom-control-checked-indicator-bg"]=i["$custom-control-checked-indicator-bg"]||a["$brand-primary"],a["$custom-control-checked-indicator-box-shadow"]=i["$custom-control-checked-indicator-box-shadow"]||"none",a["$custom-control-focus-indicator-box-shadow"]=i["$custom-control-focus-indicator-box-shadow"]||"0 0 0 1px ".concat(a["$body-bg"],", 0 0 0 3px ").concat(a["$brand-primary"]),a["$custom-control-active-indicator-color"]=i["$custom-control-active-indicator-color"]||a.$white,a["$custom-control-active-indicator-bg"]=i["$custom-control-active-indicator-bg"]||z(a["$brand-primary"]).lighten(.35).toString(),a["$custom-control-active-indicator-box-shadow"]=i["$custom-control-active-indicator-box-shadow"]||"none",a["$custom-checkbox-radius"]=i["$custom-checkbox-radius"]||a["$border-radius"],a["$custom-checkbox-checked-icon"]=i["$custom-checkbox-checked-icon"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"%3E%3Cpath fill="'.concat(a["$custom-control-checked-indicator-color"],'" d="M6.564.75l-3.59 3.612-1.538-1.55L0 4.26 2.974 7.25 8 2.193z"/%3E%3C/svg%3E\')'),a["$custom-checkbox-indeterminate-bg"]=i["$custom-checkbox-indeterminate-bg"]||a["$brand-primary"],a["$custom-checkbox-indeterminate-indicator-color"]=i["$custom-checkbox-indeterminate-indicator-color"]||a["$custom-control-checked-indicator-color"],a["$custom-checkbox-indeterminate-icon"]=i["$custom-checkbox-indeterminate-icon"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 4 4"%3E%3Cpath stroke="'.concat(a["$custom-checkbox-indeterminate-indicator-color"],'" d="M0 2h4"/%3E%3C/svg%3E\')'),a["$custom-checkbox-indeterminate-box-shadow"]=i["$custom-checkbox-indeterminate-box-shadow"]||"none",a["$custom-radio-radius"]=i["$custom-radio-radius"]||"50%",a["$custom-radio-checked-icon"]=i["$custom-radio-checked-icon"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="-4 -4 8 8"%3E%3Ccircle r="3" fill="'.concat(a["$custom-control-checked-indicator-color"],"\"/%3E%3C/svg%3E')"),a["$custom-select-padding-x"]=i["$custom-select-padding-x"]||".75rem ",a["$custom-select-padding-y"]=i["$custom-select-padding-y"]||".375rem",a["$custom-select-indicator-padding"]=i["$custom-select-indicator-padding"]||"1rem",a["$custom-select-line-height"]=i["$custom-select-line-height"]||a["$input-line-height"],a["$custom-select-color"]=i["$custom-select-color"]||a["$input-color"],a["$custom-select-disabled-color"]=i["$custom-select-disabled-color"]||a["$gray-light"],a["$custom-select-bg"]=i["$custom-select-bg"]||a.$white,a["$custom-select-disabled-bg"]=i["$custom-select-disabled-bg"]||a["$gray-lighter"],a["$custom-select-bg-size"]=i["$custom-select-bg-size"]||"8px 10px",a["$custom-select-indicator-color"]=i["$custom-select-indicator-color"]||"#333",a["$custom-select-indicator"]=i["$custom-select-indicator"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 4 5"%3E%3Cpath fill="'.concat(a["$custom-select-indicator-color"],'" d="M2 0L0 2h4zm0 5L0 3h4z"/%3E%3C/svg%3E\')'),a["$custom-select-border-width"]=i["$custom-select-border-width"]||a["$input-btn-border-width"],a["$custom-select-border-color"]=i["$custom-select-border-color"]||a["$input-border-color"],a["$custom-select-border-radius"]=i["$custom-select-border-radius"]||a["$border-radius"],a["$custom-select-focus-border-color"]=i["$custom-select-focus-border-color"]||z(a["$brand-primary"]).lighten(.25).toString(),a["$custom-select-focus-box-shadow"]=i["$custom-select-focus-box-shadow"]||"inset 0 1px 2px ".concat(z(a.$black).alpha(.75).toString(),", 0 0 5px rgba(").concat(a["$custom-select-focus-border-color"],", .5)"),a["$custom-select-sm-font-size"]=i["$custom-select-sm-font-size"]||"75%",a["$custom-file-height"]=i["$custom-file-height"]||"2.5rem",a["$custom-file-width"]=i["$custom-file-width"]||"14rem",a["$custom-file-focus-box-shadow"]=i["$custom-file-focus-box-shadow"]||"0 0 0 .075rem ".concat(a.$white,", 0 0 0 .2rem ").concat(a["$brand-primary"]),a["$custom-file-padding-x"]=i["$custom-file-padding-x"]||".5rem",a["$custom-file-padding-y"]=i["$custom-file-padding-y"]||"1rem",a["$custom-file-line-height"]=i["$custom-file-line-height"]||"1.5",a["$custom-file-color"]=i["$custom-file-color"]||a.$gray,a["$custom-file-bg"]=i["$custom-file-bg"]||a.$white,a["$custom-file-border-width"]=i["$custom-file-border-width"]||a["$border-width"],a["$custom-file-border-color"]=i["$custom-file-border-color"]||a["$input-border-color"],a["$custom-file-border-radius"]=i["$custom-file-border-radius"]||a["$border-radius"],a["$custom-file-box-shadow"]=i["$custom-file-box-shadow"]||"inset 0 .2rem .4rem ".concat(z(a.$black).alpha(.05).toString()),a["$custom-file-button-color"]=i["$custom-file-button-color"]||a["$custom-file-color"],a["$custom-file-button-bg"]=i["$custom-file-button-bg"]||a["$gray-lighter"],a["$custom-file-text"]=i["$custom-file-text"]||{placeholder:{en:"Choose file..."},"button-label":{en:"Browse"}},a["$form-icon-success-color"]=i["$form-icon-success-color"]||a["$brand-success"],a["$form-icon-success"]=i["$form-icon-success"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"%3E%3Cpath fill="'.concat(a["$form-icon-success-color"],'" d="M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z"/%3E%3C/svg%3E\')'),a["$form-icon-warning-color"]=i["$form-icon-warning-color"]||a["$brand-warning"],a["$form-icon-warning"]=i["$form-icon-warning"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8"%3E%3Cpath fill="'.concat(a["$form-icon-warning-color"],'" d="M4.4 5.324h-.8v-2.46h.8zm0 1.42h-.8V5.89h.8zM3.76.63L.04 7.075c-.115.2.016.425.26.426h7.397c.242 0 .372-.226.258-.426C6.726 4.924 5.47 2.79 4.253.63c-.113-.174-.39-.174-.494 0z"/%3E%3C/svg%3E\')'),a["$form-icon-danger-color"]=i["$form-icon-danger-color"]||a["$brand-danger"],a["$form-icon-danger"]=i["$form-icon-danger"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg xmlns="http://www.w3.org/2000/svg" fill="'.concat(a["$form-icon-danger-color"],'" viewBox="-2 -2 7 7"%3E%3Cpath stroke="%23d9534f" d="M0 0l3 3m0-3L0 3"/%3E%3Ccircle r=".5"/%3E%3Ccircle cx="3" r=".5"/%3E%3Ccircle cy="3" r=".5"/%3E%3Ccircle cx="3" cy="3" r=".5"/%3E%3C/svg%3E\')'),a["$dropdown-min-width"]=i["$dropdown-min-width"]||"10rem",a["$dropdown-padding-y"]=i["$dropdown-padding-y"]||".5rem",a["$dropdown-margin-top"]=i["$dropdown-margin-top"]||".125rem",a["$dropdown-bg"]=i["$dropdown-bg"]||a.$white,a["$dropdown-border-color"]=i["$dropdown-border-color"]||z(a.$black).alpha(.15).toString(),a["$dropdown-border-width"]=i["$dropdown-border-width"]||a["$border-width"],a["$dropdown-divider-bg"]=i["$dropdown-divider-bg"]||a["$gray-lighter"],a["$dropdown-box-shadow"]=i["$dropdown-box-shadow"]||"0 .5rem 1rem rgba(".concat(a.$black,",.175)"),a["$dropdown-link-color"]=i["$dropdown-link-color"]||a["$gray-dark"],a["$dropdown-link-hover-color"]=i["$dropdown-link-hover-color"]||z(a["$gray-dark"]).darken(.05).toString(),a["$dropdown-link-hover-bg"]=i["$dropdown-link-hover-bg"]||a["$gray-lightest"],a["$dropdown-link-active-color"]=i["$dropdown-link-active-color"]||a["$component-active-color"],a["$dropdown-link-active-bg"]=i["$dropdown-link-active-bg"]||a["$component-active-bg"],a["$dropdown-link-disabled-color"]=i["$dropdown-link-disabled-color"]||a["$gray-light"],a["$dropdown-item-padding-x"]=i["$dropdown-item-padding-x"]||"1.5rem",a["$dropdown-header-color"]=i["$dropdown-header-color"]||a["$gray-light"],a["$zindex-dropdown-backdrop"]=i["$zindex-dropdown-backdrop"]||"990",a["$zindex-dropdown"]=i["$zindex-dropdown"]||"1000",a["$zindex-modal-backdrop"]=i["$zindex-modal-backdrop"]||"2040",a["$zindex-modal"]=i["$zindex-modal"]||"2050",a["$zindex-popover"]=i["$zindex-popover"]||"1060",a["$zindex-tooltip"]=i["$zindex-tooltip"]||"1070",a["$zindex-navbar"]=i["$zindex-navbar"]||"1000",a["$zindex-navbar-fixed"]=i["$zindex-navbar-fixed"]||"1030",a["$zindex-navbar-sticky"]=i["$zindex-navbar-sticky"]||"1030",a["$navbar-padding-x"]=i["$navbar-padding-x"]||a.$spacer,a["$navbar-padding-y"]=i["$navbar-padding-y"]||a["$spacer-halved"],a["$navbar-brand-padding-y"]=i["$navbar-brand-padding-y"]||".25rem",a["$navbar-divider-padding-y"]=i["$navbar-divider-padding-y"]||".425rem",a["$navbar-toggler-padding-x"]=i["$navbar-toggler-padding-x"]||".75rem",a["$navbar-toggler-padding-y"]=i["$navbar-toggler-padding-y"]||".25rem",a["$navbar-toggler-font-size"]=i["$navbar-toggler-font-size"]||a["$font-size-lg"],a["$navbar-toggler-border-radius"]=i["$navbar-toggler-border-radius"]||a["$btn-border-radius"],a["$navbar-inverse-color"]=i["$navbar-inverse-color"]||z(a.$white).alpha(.5).toString(),a["$navbar-inverse-hover-color"]=i["$navbar-inverse-hover-color"]||z(a.$white).alpha(.75).toString(),a["$navbar-inverse-active-color"]=i["$navbar-inverse-active-color"]||z(a.$white).alpha(1).toString(),a["$navbar-inverse-disabled-color"]=i["$navbar-inverse-disabled-color"]||z(a.$white).alpha(.25).toString(),a["$navbar-inverse-toggler-bg"]=i["$navbar-inverse-toggler-bg"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg viewBox="0 0 30 30" xmlns="http://www.w3.org/2000/svg"%3E%3Cpath stroke="'.concat(a["$navbar-inverse-color"],'" stroke-width="2" stroke-linecap="round" stroke-miterlimit="10" d="M4 7h22M4 15h22M4 23h22"/%3E%3C/svg%3E\')'),a["$navbar-inverse-toggler-border"]=i["$navbar-inverse-toggler-border"]||z(a.$white).alpha(.1).toString(),a["$navbar-light-color"]=i["$navbar-light-color"]||z(a.$black).alpha(.5).toString(),a["$navbar-light-hover-color"]=i["$navbar-light-hover-color"]||z(a.$black).alpha(.7).toString(),a["$navbar-light-active-color"]=i["$navbar-light-active-color"]||z(a.$black).alpha(.9).toString(),a["$navbar-light-disabled-color"]=i["$navbar-light-disabled-color"]||z(a.$black).alpha(.3).toString(),a["$navbar-light-toggler-bg"]=i["$navbar-light-toggler-bg"]||'url(\'data:image/svg+xml;charset=utf8,%3Csvg viewBox="0 0 30 30" xmlns="http://www.w3.org/2000/svg"%3E%3Cpath stroke="'.concat(a["$navbar-light-color"],'" stroke-width="2" stroke-linecap="round" stroke-miterlimit="10" d="M4 7h22M4 15h22M4 23h22"/%3E%3C/svg%3E\')'),a["$navbar-light-toggler-border"]=i["$navbar-light-toggler-border"]||z(a.$black).alpha(.1).toString(),a["$nav-link-padding"]=i["$nav-link-padding"]||".5em 1em",a["$nav-disabled-link-color"]=i["$nav-disabled-link-color"]||a["$gray-light"],a["$nav-tabs-border-color"]=i["$nav-tabs-border-color"]||"#ddd",a["$nav-tabs-border-width"]=i["$nav-tabs-border-width"]||a["$border-width"],a["$nav-tabs-border-radius"]=i["$nav-tabs-border-radius"]||a["$border-radius"],a["$nav-tabs-link-hover-border-color"]=i["$nav-tabs-link-hover-border-color"]||a["$gray-lighter"],a["$nav-tabs-active-link-hover-color"]=i["$nav-tabs-active-link-hover-color"]||a.$gray,a["$nav-tabs-active-link-hover-bg"]=i["$nav-tabs-active-link-hover-bg"]||a["$body-bg"],a["$nav-tabs-active-link-hover-border-color"]=i["$nav-tabs-active-link-hover-border-color"]||"#ddd",a["$nav-pills-border-radius"]=i["$nav-pills-border-radius"]||a["$border-radius"],a["$nav-pills-active-link-color"]=i["$nav-pills-active-link-color"]||a["$component-active-color"],a["$nav-pills-active-link-bg"]=i["$nav-pills-active-link-bg"]||a["$component-active-bg"],a["$pagination-padding-x"]=i["$pagination-padding-x"]||".75rem",a["$pagination-padding-y"]=i["$pagination-padding-y"]||".5rem",a["$pagination-padding-x-sm"]=i["$pagination-padding-x-sm"]||".5rem",a["$pagination-padding-y-sm"]=i["$pagination-padding-y-sm"]||".25rem",a["$pagination-padding-x-lg"]=i["$pagination-padding-x-lg"]||"1.5rem",a["$pagination-padding-y-lg"]=i["$pagination-padding-y-lg"]||".75rem",a["$pagination-line-height"]=i["$pagination-line-height"]||"1.25",a["$pagination-color"]=i["$pagination-color"]||a["$link-color"],a["$pagination-bg"]=i["$pagination-bg"]||a.$white,a["$pagination-border-width"]=i["$pagination-border-width"]||a["$border-width"],a["$pagination-border-color"]=i["$pagination-border-color"]||"#ddd",a["$pagination-hover-color"]=i["$pagination-hover-color"]||a["$link-hover-color"],a["$pagination-hover-bg"]=i["$pagination-hover-bg"]||a["$gray-lighter"],a["$pagination-hover-border"]=i["$pagination-hover-border"]||"#ddd",a["$pagination-active-color"]=i["$pagination-active-color"]||a.$white,a["$pagination-active-bg"]=i["$pagination-active-bg"]||a["$brand-primary"],a["$pagination-active-border"]=i["$pagination-active-border"]||a["$brand-primary"],a["$pagination-disabled-color"]=i["$pagination-disabled-color"]||a["$gray-light"],a["$pagination-disabled-bg"]=i["$pagination-disabled-bg"]||a.$white,a["$pagination-disabled-border"]=i["$pagination-disabled-border"]||"#ddd",a["$jumbotron-padding"]=i["$jumbotron-padding"]||"2rem",a["$jumbotron-bg"]=i["$jumbotron-bg"]||a["$gray-lighter"],a["$state-success-text"]=i["$state-success-text"]||"#3c763d",a["$state-success-bg"]=i["$state-success-bg"]||"#dff0d8",a["$state-success-border"]=i["$state-success-border"]||z(a["$state-success-bg"]).darken(.05).toString(),a["$state-info-text"]=i["$state-info-text"]||"#31708f",a["$state-info-bg"]=i["$state-info-bg"]||"#d9edf7",a["$state-info-border"]=i["$state-info-border"]||z(a["$state-info-bg"]).darken(.07).toString(),a["$state-warning-text"]=i["$state-warning-text"]||"#8a6d3b",a["$state-warning-bg"]=i["$state-warning-bg"]||"#fcf8e3",a["$state-warning-border"]=i["$state-warning-border"]||z(a["$state-warning-bg"]).darken(.05).toString(),a["$mark-bg"]=i["$mark-bg"]||a["$state-warning-bg"],a["$state-danger-text"]=i["$state-danger-text"]||"#a94442",a["$state-danger-bg"]=i["$state-danger-bg"]||"#f2dede",a["$state-danger-border"]=i["$state-danger-border"]||z(a["$state-danger-bg"]).darken(.05).toString(),a["$card-spacer-x"]=i["$card-spacer-x"]||"1.25rem",a["$card-spacer-y"]=i["$card-spacer-y"]||".75rem",a["$card-border-width"]=i["$card-border-width"]||"1px",a["$card-border-radius"]=i["$card-border-radius"]||a["$border-radius"],a["$card-border-color"]=i["$card-border-color"]||z(a.$black).alpha(.125).toString(),a["$card-border-radius-inner"]=i["$card-border-radius-inner"]||"calc(".concat(a["$card-border-radius"]," - ").concat(a["$card-border-width"],")"),a["$card-cap-bg"]=i["$card-cap-bg"]||a["$gray-lightest"],a["$card-bg"]=i["$card-bg"]||a.$white,a["$card-link-hover-color"]=i["$card-link-hover-color"]||a.$white,a["$card-img-overlay-padding"]=i["$card-img-overlay-padding"]||"1.25rem",r=C(a["$grid-gutter-width"]),a["$card-group-margin"]=i["$card-group-margin"]||A(a["$grid-gutter-width"],r)/2+r,a["$card-deck-margin"]=i["$card-deck-margin"]||a["$card-group-margin"],a["$card-columns-count-md"]=i["$card-columns-count-md"]||"2",a["$card-columns-gap-md"]=i["$card-columns-gap-md"]||"1rem",a["$card-columns-margin-md"]=i["$card-columns-margin-md"]||a["$card-spacer-y"],a["$card-columns-count-lg"]=i["$card-columns-count-lg"]||"2",a["$card-columns-gap-lg"]=i["$card-columns-gap-lg"]||"1.15rem",a["$card-columns-margin-lg"]=i["$card-columns-margin-lg"]||a["$card-spacer-y"],a["$card-columns-count-xl"]=i["$card-columns-count-xl"]||"3",a["$card-columns-gap-xl"]=i["$card-columns-gap-xl"]||"1.25rem",a["$card-columns-margin-xl"]=i["$card-columns-margin-xl"]||a["$card-spacer-y"],a["$card-columns-count-xxl"]=i["$card-columns-count-xxl"]||"4",a["$card-columns-gap-xxl"]=i["$card-columns-gap-xxl"]||"1.25rem",a["$card-columns-margin-xxl"]=i["$card-columns-margin-xxl"]||a["$card-spacer-y"],a["$tooltip-max-width"]=i["$tooltip-max-width"]||"200px",a["$tooltip-color"]=i["$tooltip-color"]||a.$white,a["$tooltip-bg"]=i["$tooltip-bg"]||a.$black,a["$tooltip-opacity"]=i["$tooltip-opacity"]||".9",a["$tooltip-padding-y"]=i["$tooltip-padding-y"]||"3px",a["$tooltip-padding-x"]=i["$tooltip-padding-x"]||"8px",a["$tooltip-margin"]=i["$tooltip-margin"]||"3px",a["$tooltip-arrow-width"]=i["$tooltip-arrow-width"]||"5px",a["$tooltip-arrow-color"]=i["$tooltip-arrow-color"]||a["$tooltip-bg"],a["$popover-inner-padding"]=i["$popover-inner-padding"]||"1px",a["$popover-bg"]=i["$popover-bg"]||a.$white,a["$popover-max-width"]=i["$popover-max-width"]||"276px",a["$popover-border-width"]=i["$popover-border-width"]||a["$border-width"],a["$popover-border-color"]=i["$popover-border-color"]||z(a.$black).alpha(.2).toString(),a["$popover-box-shadow"]=i["$popover-box-shadow"]||"0 5px 10px ".concat(z(a.$black).alpha(.2).toString()),a["$popover-title-bg"]=i["$popover-title-bg"]||z(a["$popover-bg"]).darken(.03).toString(),a["$popover-title-padding-x"]=i["$popover-title-padding-x"]||"14px",a["$popover-title-padding-y"]=i["$popover-title-padding-y"]||"8px",a["$popover-content-padding-x"]=i["$popover-content-padding-x"]||"14px",a["$popover-content-padding-y"]=i["$popover-content-padding-y"]||"9px",a["$popover-arrow-width"]=i["$popover-arrow-width"]||"10px",a["$popover-arrow-color"]=i["$popover-arrow-color"]||a["$popover-bg"],r=C(a["$popover-arrow-width"]),a["$popover-arrow-outer-width"]=i["$popover-arrow-outer-width"]||A(a["$popover-arrow-width"],r)+1+r,a["$popover-arrow-outer-color"]=i["$popover-arrow-outer-color"]||z(a["$popover-border-color"]).fade(.5).toString(),a["$badge-default-bg"]=i["$badge-default-bg"]||a["$gray-light"],a["$badge-primary-bg"]=i["$badge-primary-bg"]||a["$brand-primary"],a["$badge-success-bg"]=i["$badge-success-bg"]||a["$brand-success"],a["$badge-info-bg"]=i["$badge-info-bg"]||a["$brand-info"],a["$badge-warning-bg"]=i["$badge-warning-bg"]||a["$brand-warning"],a["$badge-danger-bg"]=i["$badge-danger-bg"]||a["$brand-danger"],a["$badge-color"]=i["$badge-color"]||a.$white,a["$badge-link-hover-color"]=i["$badge-link-hover-color"]||a.$white,a["$badge-font-size"]=i["$badge-font-size"]||"75%",a["$badge-font-weight"]=i["$badge-font-weight"]||a["$font-weight-bold"],a["$badge-padding-x"]=i["$badge-padding-x"]||".4em",a["$badge-padding-y"]=i["$badge-padding-y"]||".25em",a["$badge-pill-padding-x"]=i["$badge-pill-padding-x"]||".6em",a["$badge-pill-border-radius"]=i["$badge-pill-border-radius"]||"10rem",a["$modal-inner-padding"]=i["$modal-inner-padding"]||"15px",a["$modal-dialog-margin"]=i["$modal-dialog-margin"]||"10px",a["$modal-dialog-sm-up-margin-y"]=i["$modal-dialog-sm-up-margin-y"]||"30px",a["$modal-title-line-height"]=i["$modal-title-line-height"]||a["$line-height-base"],a["$modal-content-bg"]=i["$modal-content-bg"]||a.$white,a["$modal-content-border-color"]=i["$modal-content-border-color"]||z(a.$black).alpha(.2).toString(),a["$modal-content-border-width"]=i["$modal-content-border-width"]||a["$border-width"],a["$modal-content-xs-box-shadow"]=i["$modal-content-xs-box-shadow"]||"0 3px 9px ".concat(z(a.$black).alpha(.5).toString()),a["$modal-content-sm-up-box-shadow"]=i["$modal-content-sm-up-box-shadow"]||"0 5px 15px ".concat(z(a.$black).alpha(.5).toString()),a["$modal-backdrop-bg"]=i["$modal-backdrop-bg"]||a.$black,a["$modal-backdrop-opacity"]=i["$modal-backdrop-opacity"]||".5",a["$modal-header-border-color"]=i["$modal-header-border-color"]||a["$gray-lighter"],a["$modal-footer-border-color"]=i["$modal-footer-border-color"]||a["$modal-header-border-color"],a["$modal-header-border-width"]=i["$modal-header-border-width"]||a["$modal-content-border-width"],a["$modal-footer-border-width"]=i["$modal-footer-border-width"]||a["$modal-header-border-width"],a["$modal-header-padding"]=i["$modal-header-padding"]||"15px",a["$modal-lg"]=i["$modal-lg"]||"800px",a["$modal-md"]=i["$modal-md"]||"500px",a["$modal-sm"]=i["$modal-sm"]||"300px",a["$modal-transition"]=i["$modal-transition"]||"transform .3s ease-out",a["$alert-padding-x"]=i["$alert-padding-x"]||"1.25rem",a["$alert-padding-y"]=i["$alert-padding-y"]||".75rem",a["$alert-margin-bottom"]=i["$alert-margin-bottom"]||a["$spacer-y"],a["$alert-border-radius"]=i["$alert-border-radius"]||a["$border-radius"],a["$alert-link-font-weight"]=i["$alert-link-font-weight"]||a["$font-weight-bold"],a["$alert-border-width"]=i["$alert-border-width"]||a["$border-width"],a["$alert-success-bg"]=i["$alert-success-bg"]||a["$state-success-bg"],a["$alert-success-text"]=i["$alert-success-text"]||a["$state-success-text"],a["$alert-success-border"]=i["$alert-success-border"]||a["$state-success-border"],a["$alert-info-bg"]=i["$alert-info-bg"]||a["$state-info-bg"],a["$alert-info-text"]=i["$alert-info-text"]||a["$state-info-text"],a["$alert-info-border"]=i["$alert-info-border"]||a["$state-info-border"],a["$alert-warning-bg"]=i["$alert-warning-bg"]||a["$state-warning-bg"],a["$alert-warning-text"]=i["$alert-warning-text"]||a["$state-warning-text"],a["$alert-warning-border"]=i["$alert-warning-border"]||a["$state-warning-border"],a["$alert-danger-bg"]=i["$alert-danger-bg"]||a["$state-danger-bg"],a["$alert-danger-text"]=i["$alert-danger-text"]||a["$state-danger-text"],a["$alert-danger-border"]=i["$alert-danger-border"]||a["$state-danger-border"],a["$progress-height"]=i["$progress-height"]||"1rem",a["$progress-font-size"]=i["$progress-font-size"]||".75rem",a["$progress-bg"]=i["$progress-bg"]||a["$gray-lighter"],a["$progress-border-radius"]=i["$progress-border-radius"]||a["$border-radius"],a["$progress-box-shadow"]=i["$progress-box-shadow"]||"inset 0 .1rem .1rem ".concat(z(a.$black).alpha(.1).toString()),a["$progress-bar-color"]=i["$progress-bar-color"]||a.$white,a["$progress-bar-bg"]=i["$progress-bar-bg"]||a["$brand-primary"],a["$progress-bar-animation-timing"]=i["$progress-bar-animation-timing"]||"1s linear infinite",a["$list-group-color"]=i["$list-group-color"]||a["$body-color"],a["$list-group-bg"]=i["$list-group-bg"]||a.$white,a["$list-group-border-color"]=i["$list-group-border-color"]||z(a.$black).alpha(.125).toString(),a["$list-group-border-width"]=i["$list-group-border-width"]||a["$border-width"],a["$list-group-border-radius"]=i["$list-group-border-radius"]||a["$border-radius"],a["$list-group-item-padding-x"]=i["$list-group-item-padding-x"]||"1.25rem",a["$list-group-item-padding-y"]=i["$list-group-item-padding-y"]||".75rem",a["$list-group-hover-bg"]=i["$list-group-hover-bg"]||a["$gray-lightest"],a["$list-group-active-color"]=i["$list-group-active-color"]||a["$component-active-color"],a["$list-group-active-bg"]=i["$list-group-active-bg"]||a["$component-active-bg"],a["$list-group-active-border"]=i["$list-group-active-border"]||a["$list-group-active-bg"],a["$list-group-disabled-color"]=i["$list-group-disabled-color"]||a["$gray-light"],a["$list-group-disabled-bg"]=i["$list-group-disabled-bg"]||a["$list-group-bg"],a["$list-group-link-color"]=i["$list-group-link-color"]||a.$gray,a["$list-group-link-hover-color"]=i["$list-group-link-hover-color"]||a["$list-group-link-color"],a["$list-group-link-active-color"]=i["$list-group-link-active-color"]||a["$list-group-color"],a["$list-group-link-active-bg"]=i["$list-group-link-active-bg"]||a["$gray-lighter"],a["$thumbnail-padding"]=i["$thumbnail-padding"]||".25rem",a["$thumbnail-bg"]=i["$thumbnail-bg"]||a["$body-bg"],a["$thumbnail-border-width"]=i["$thumbnail-border-width"]||a["$border-width"],a["$thumbnail-border-color"]=i["$thumbnail-border-color"]||"#ddd",a["$thumbnail-border-radius"]=i["$thumbnail-border-radius"]||a["$border-radius"],a["$thumbnail-box-shadow"]=i["$thumbnail-box-shadow"]||"0 1px 2px ".concat(z(a.$black).alpha(.75).toString()),a["$thumbnail-transition"]=i["$thumbnail-transition"]||"all .2s ease-in-out",a["$figure-caption-font-size"]=i["$figure-caption-font-size"]||"90%",a["$figure-caption-color"]=i["$figure-caption-color"]||a["$gray-light"],a["$breadcrumb-padding-y"]=i["$breadcrumb-padding-y"]||".75rem",a["$breadcrumb-padding-x"]=i["$breadcrumb-padding-x"]||"1rem",a["$breadcrumb-item-padding"]=i["$breadcrumb-item-padding"]||".5rem",a["$breadcrumb-bg"]=i["$breadcrumb-bg"]||a["$gray-lighter"],a["$breadcrumb-divider-color"]=i["$breadcrumb-divider-color"]||a["$gray-light"],a["$breadcrumb-active-color"]=i["$breadcrumb-active-color"]||a["$gray-light"],a["$breadcrumb-divider"]=i["$breadcrumb-divider"]||'"/"',a["$close-font-size"]=i["$close-font-size"]||1.5*A(a["$font-size-base"])+C(a["$font-size-base"]),a["$close-font-weight"]=i["$close-font-weight"]||a["$font-weight-bold"],a["$close-color"]=i["$close-color"]||a.$black,a["$close-text-shadow"]=i["$close-text-shadow"]||"0 1px 0 ".concat(a.$white),a["$code-font-size"]=i["$code-font-size"]||"90%",a["$code-padding-x"]=i["$code-padding-x"]||".4rem",a["$code-padding-y"]=i["$code-padding-y"]||".2rem",a["$code-color"]=i["$code-color"]||"#bd4147",a["$code-bg"]=i["$code-bg"]||a["$gray-lightest"],a["$kbd-color"]=i["$kbd-color"]||a.$white,a["$kbd-bg"]=i["$kbd-bg"]||a["$gray-dark"],a["$kbd-box-shadow"]=i["$kbd-box-shadow"]||"inset 0 -.1rem 0 ".concat(z(a.$black).alpha(.25).toString()),a["$nested-kbd-font-weight"]=i["$nested-kbd-font-weight"]||a["$font-weight-bold"],a["$pre-color"]=i["$pre-color"]||a["$gray-dark"],a["$pre-scrollable-max-height"]=i["$pre-scrollable-max-height"]||"340px",Object.assign({},i,a)}var N=P,F=P();function I(r,t,e){return t in r?Object.defineProperty(r,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):r[t]=e,r}var T=j(function(r,t){var e=200,o="__lodash_hash_undefined__",n=800,a=16,i=9007199254740991,c="[object Arguments]",l="[object AsyncFunction]",s="[object Function]",d="[object GeneratorFunction]",u="[object Null]",g="[object Object]",$="[object Proxy]",b="[object Undefined]",h=/^\[object .+?Constructor\]$/,p=/^(?:0|[1-9]\d*)$/,f={};f["[object Float32Array]"]=f["[object Float64Array]"]=f["[object Int8Array]"]=f["[object Int16Array]"]=f["[object Int32Array]"]=f["[object Uint8Array]"]=f["[object Uint8ClampedArray]"]=f["[object Uint16Array]"]=f["[object Uint32Array]"]=!0,f[c]=f["[object Array]"]=f["[object ArrayBuffer]"]=f["[object Boolean]"]=f["[object DataView]"]=f["[object Date]"]=f["[object Error]"]=f[s]=f["[object Map]"]=f["[object Number]"]=f[g]=f["[object RegExp]"]=f["[object Set]"]=f["[object String]"]=f["[object WeakMap]"]=!1;var m="object"==typeof M&&M&&M.Object===Object&&M,v="object"==typeof self&&self&&self.Object===Object&&self,w=m||v||Function("return this")(),y=t&&!t.nodeType&&t,x=y&&r&&!r.nodeType&&r,k=x&&x.exports===y,z=k&&m.process,_=function(){try{return z&&z.binding&&z.binding("util")}catch(r){}}(),j=_&&_.isTypedArray;function S(r,t){return "__proto__"==t?void 0:r[t]}var E,O,U,C=Array.prototype,A=Function.prototype,P=Object.prototype,N=w["__core-js_shared__"],F=A.toString,I=P.hasOwnProperty,T=(E=/[^.]+$/.exec(N&&N.keys&&N.keys.IE_PROTO||""))?"Symbol(src)_1."+E:"",B=P.toString,q=F.call(Object),L=RegExp("^"+F.call(I).replace(/[\\^$.*+?()[\]{}|]/g,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),R=k?w.Buffer:void 0,D=w.Symbol,G=w.Uint8Array,H=R?R.allocUnsafe:void 0,V=(O=Object.getPrototypeOf,U=Object,function(r){return O(U(r))}),X=Object.create,J=P.propertyIsEnumerable,W=C.splice,Y=D?D.toStringTag:void 0,K=function(){try{var r=xr(Object,"defineProperty");return r({},"",{}),r}catch(r){}}(),Q=R?R.isBuffer:void 0,Z=Math.max,rr=Date.now,tr=xr(w,"Map"),er=xr(Object,"create"),or=function(){function r(){}return function(t){if(!Ar(t))return {};if(X)return X(t);r.prototype=t;var e=new r;return r.prototype=void 0,e}}();function nr(r){var t=-1,e=null==r?0:r.length;for(this.clear();++t<e;){var o=r[t];this.set(o[0],o[1]);}}function ar(r){var t=-1,e=null==r?0:r.length;for(this.clear();++t<e;){var o=r[t];this.set(o[0],o[1]);}}function ir(r){var t=-1,e=null==r?0:r.length;for(this.clear();++t<e;){var o=r[t];this.set(o[0],o[1]);}}function cr(r){var t=this.__data__=new ar(r);this.size=t.size;}function lr(r,t){var e=Sr(r),o=!e&&jr(r),n=!e&&!o&&Or(r),a=!e&&!o&&!n&&Nr(r),i=e||o||n||a,c=i?function(r,t){for(var e=-1,o=Array(r);++e<r;)o[e]=t(e);return o}(r.length,String):[],l=c.length;for(var s in r)!t&&!I.call(r,s)||i&&("length"==s||n&&("offset"==s||"parent"==s)||a&&("buffer"==s||"byteLength"==s||"byteOffset"==s)||kr(s,l))||c.push(s);return c}function sr(r,t,e){(void 0===e||_r(r[t],e))&&(void 0!==e||t in r)||gr(r,t,e);}function dr(r,t,e){var o=r[t];I.call(r,t)&&_r(o,e)&&(void 0!==e||t in r)||gr(r,t,e);}function ur(r,t){for(var e=r.length;e--;)if(_r(r[e][0],t))return e;return -1}function gr(r,t,e){"__proto__"==t&&K?K(r,t,{configurable:!0,enumerable:!0,value:e,writable:!0}):r[t]=e;}nr.prototype.clear=function(){this.__data__=er?er(null):{},this.size=0;},nr.prototype.delete=function(r){var t=this.has(r)&&delete this.__data__[r];return this.size-=t?1:0,t},nr.prototype.get=function(r){var t=this.__data__;if(er){var e=t[r];return e===o?void 0:e}return I.call(t,r)?t[r]:void 0},nr.prototype.has=function(r){var t=this.__data__;return er?void 0!==t[r]:I.call(t,r)},nr.prototype.set=function(r,t){var e=this.__data__;return this.size+=this.has(r)?0:1,e[r]=er&&void 0===t?o:t,this},ar.prototype.clear=function(){this.__data__=[],this.size=0;},ar.prototype.delete=function(r){var t=this.__data__,e=ur(t,r);return !(e<0||(e==t.length-1?t.pop():W.call(t,e,1),--this.size,0))},ar.prototype.get=function(r){var t=this.__data__,e=ur(t,r);return e<0?void 0:t[e][1]},ar.prototype.has=function(r){return ur(this.__data__,r)>-1},ar.prototype.set=function(r,t){var e=this.__data__,o=ur(e,r);return o<0?(++this.size,e.push([r,t])):e[o][1]=t,this},ir.prototype.clear=function(){this.size=0,this.__data__={hash:new nr,map:new(tr||ar),string:new nr};},ir.prototype.delete=function(r){var t=yr(this,r).delete(r);return this.size-=t?1:0,t},ir.prototype.get=function(r){return yr(this,r).get(r)},ir.prototype.has=function(r){return yr(this,r).has(r)},ir.prototype.set=function(r,t){var e=yr(this,r),o=e.size;return e.set(r,t),this.size+=e.size==o?0:1,this},cr.prototype.clear=function(){this.__data__=new ar,this.size=0;},cr.prototype.delete=function(r){var t=this.__data__,e=t.delete(r);return this.size=t.size,e},cr.prototype.get=function(r){return this.__data__.get(r)},cr.prototype.has=function(r){return this.__data__.has(r)},cr.prototype.set=function(r,t){var o=this.__data__;if(o instanceof ar){var n=o.__data__;if(!tr||n.length<e-1)return n.push([r,t]),this.size=++o.size,this;o=this.__data__=new ir(n);}return o.set(r,t),this.size=o.size,this};var br=function(r,t,e){for(var o=-1,n=Object(r),a=e(r),i=a.length;i--;){var c=a[++o];if(!1===t(n[c],c,n))break}return r};function hr(r){return null==r?void 0===r?b:u:Y&&Y in Object(r)?function(r){var t=I.call(r,Y),e=r[Y];try{r[Y]=void 0;var o=!0;}catch(r){}var n=B.call(r);o&&(t?r[Y]=e:delete r[Y]);return n}(r):function(r){return B.call(r)}(r)}function pr(r){return Pr(r)&&hr(r)==c}function fr(r){return !(!Ar(r)||(t=r,T&&T in t))&&(Ur(r)?L:h).test(function(r){if(null!=r){try{return F.call(r)}catch(r){}try{return r+""}catch(r){}}return ""}(r));var t;}function mr(r){if(!Ar(r))return function(r){var t=[];if(null!=r)for(var e in Object(r))t.push(e);return t}(r);var t=zr(r),e=[];for(var o in r)("constructor"!=o||!t&&I.call(r,o))&&e.push(o);return e}function vr(r,t,e,o,n){r!==t&&br(t,function(a,i){if(Ar(a))n||(n=new cr),function(r,t,e,o,n,a,i){var c=S(r,e),l=S(t,e),s=i.get(l);if(s)return void sr(r,e,s);var d=a?a(c,l,e+"",r,t,i):void 0,u=void 0===d;if(u){var $=Sr(l),b=!$&&Or(l),h=!$&&!b&&Nr(l);d=l,$||b||h?Sr(c)?d=c:Pr(w=c)&&Er(w)?d=function(r,t){var e=-1,o=r.length;t||(t=Array(o));for(;++e<o;)t[e]=r[e];return t}(c):b?(u=!1,d=function(r,t){if(t)return r.slice();var e=r.length,o=H?H(e):new r.constructor(e);return r.copy(o),o}(l,!0)):h?(u=!1,p=l,f=(m=p.buffer,v=new m.constructor(m.byteLength),new G(v).set(new G(m)),v),d=new p.constructor(f,p.byteOffset,p.length)):d=[]:function(r){if(!Pr(r)||hr(r)!=g)return !1;var t=V(r);if(null===t)return !0;var e=I.call(t,"constructor")&&t.constructor;return "function"==typeof e&&e instanceof e&&F.call(e)==q}(l)||jr(l)?(d=c,jr(c)?d=function(r){return function(r,t,e,o){var n=!e;e||(e={});var a=-1,i=t.length;for(;++a<i;){var c=t[a],l=o?o(e[c],r[c],c,e,r):void 0;void 0===l&&(l=r[c]),n?gr(e,c,l):dr(e,c,l);}return e}(r,Fr(r))}(c):(!Ar(c)||o&&Ur(c))&&(d=function(r){return "function"!=typeof r.constructor||zr(r)?{}:or(V(r))}(l))):u=!1;}var p,f,m,v;var w;u&&(i.set(l,d),n(d,l,o,a,i),i.delete(l));sr(r,e,d);}(r,t,i,e,vr,o,n);else{var c=o?o(S(r,i),a,i+"",r,t,n):void 0;void 0===c&&(c=a),sr(r,i,c);}},Fr);}function wr(r,t){return Mr(function(r,t,e){return t=Z(void 0===t?r.length-1:t,0),function(){for(var o=arguments,n=-1,a=Z(o.length-t,0),i=Array(a);++n<a;)i[n]=o[t+n];n=-1;for(var c=Array(t+1);++n<t;)c[n]=o[n];return c[t]=e(i),function(r,t,e){switch(e.length){case 0:return r.call(t);case 1:return r.call(t,e[0]);case 2:return r.call(t,e[0],e[1]);case 3:return r.call(t,e[0],e[1],e[2])}return r.apply(t,e)}(r,this,c)}}(r,t,Br),r+"")}function yr(r,t){var e,o,n=r.__data__;return ("string"==(o=typeof(e=t))||"number"==o||"symbol"==o||"boolean"==o?"__proto__"!==e:null===e)?n["string"==typeof t?"string":"hash"]:n.map}function xr(r,t){var e=function(r,t){return null==r?void 0:r[t]}(r,t);return fr(e)?e:void 0}function kr(r,t){var e=typeof r;return !!(t=null==t?i:t)&&("number"==e||"symbol"!=e&&p.test(r))&&r>-1&&r%1==0&&r<t}function zr(r){var t=r&&r.constructor;return r===("function"==typeof t&&t.prototype||P)}var Mr=function(r){var t=0,e=0;return function(){var o=rr(),i=a-(o-e);if(e=o,i>0){if(++t>=n)return arguments[0]}else t=0;return r.apply(void 0,arguments)}}(K?function(r,t){return K(r,"toString",{configurable:!0,enumerable:!1,value:(e=t,function(){return e}),writable:!0});var e;}:Br);function _r(r,t){return r===t||r!=r&&t!=t}var jr=pr(function(){return arguments}())?pr:function(r){return Pr(r)&&I.call(r,"callee")&&!J.call(r,"callee")},Sr=Array.isArray;function Er(r){return null!=r&&Cr(r.length)&&!Ur(r)}var Or=Q||function(){return !1};function Ur(r){if(!Ar(r))return !1;var t=hr(r);return t==s||t==d||t==l||t==$}function Cr(r){return "number"==typeof r&&r>-1&&r%1==0&&r<=i}function Ar(r){var t=typeof r;return null!=r&&("object"==t||"function"==t)}function Pr(r){return null!=r&&"object"==typeof r}var Nr=j?function(r){return function(t){return r(t)}}(j):function(r){return Pr(r)&&Cr(r.length)&&!!f[hr(r)]};function Fr(r){return Er(r)?lr(r,!0):mr(r)}var Ir,Tr=(Ir=function(r,t,e){vr(r,t,e);},wr(function(r,t){var e=-1,o=t.length,n=o>1?t[o-1]:void 0,a=o>2?t[2]:void 0;for(n=Ir.length>3&&"function"==typeof n?(o--,n):void 0,a&&function(r,t,e){if(!Ar(e))return !1;var o=typeof t;return !!("number"==o?Er(e)&&kr(t,e.length):"string"==o&&t in e)&&_r(e[t],r)}(t[0],t[1],a)&&(n=o<3?void 0:n,o=1),r=Object(r);++e<o;){var i=t[e];i&&Ir(r,i,e,n);}return r}));function Br(r){return r}r.exports=Tr;}),B=function(r){return function(t){return T({},r,t)}};function q(r){return function(t){return function(r,t){for(var e,o=[].concat(r),n=t;e=o.pop();)n=e(n);return n}(r,t)}}function L(r){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:I({},r,{});if(void 0===r||"string"!=typeof r)return console.warn("You may have forgotten to set the scope name in the makeScopedTheme function.");var e=I({},r,{})[r],o=t[r]||{};return Object.keys(t).forEach(function(r){e[r]=o[r]||t[r];}),I({},r,function(r){for(var t=1;t<arguments.length;t++){var e=null!=arguments[t]?arguments[t]:{},o=Object.keys(e);"function"==typeof Object.getOwnPropertySymbols&&(o=o.concat(Object.getOwnPropertySymbols(e).filter(function(r){return Object.getOwnPropertyDescriptor(e,r).enumerable}))),o.forEach(function(t){I(r,t,e[t]);});}return r}({},t,e))}var R=j(function(r,t){Object.defineProperty(t,"__esModule",{value:!0}),t.getGlobalStyles=o,t.getGlobalStyleNoBootstrapProvider=n,t.html=a,t.boxSizing=i,t.ie10FixViewport=c,t.body=l,t.bodyUtils=s,t.tabIndex=d,t.svg=u,t.ie10FixHidden=g,t.webkitFileUploadButton=$,t.default=t.defaultProps=void 0;var e={"$font-family-base":'-apple-system, system-ui, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif',"$font-size-base":"1rem","$font-weight-base":"1.5","$line-height-base":"1.5","$body-color":"#292b2c","$body-bg":"#fff"};function o(){return "\n    html {\n      ".concat("\n    box-sizing: border-box;\n    font-family: sans-serif;\n    line-height: 1.15;\n    -ms-text-size-adjust: 100%;\n    -webkit-text-size-adjust: 100%;\n    -ms-overflow-style: scrollbar;\n    -webkit-tap-highlight-color: rgba(0,0,0,0);\n  ","\n    }\n    *,\n    *::before,\n    *::after {\n      ").concat("\n    box-sizing: inherit;\n  ","\n    }\n    @-ms-viewport { \n      ").concat("\n    width: device-width;\n  "," \n    }\n    body {\n      ").concat("\n    &.overflow {\n      overflow: hidden;\n    }\n  ","\n    }\n  ")}function n(){var r=arguments.length>0&&void 0!==arguments[0]?arguments[0]:e["$font-family-base"],t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:e["$font-size-base"],n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:e["$font-weight-base"],a=arguments.length>3&&void 0!==arguments[3]?arguments[3]:e["$line-height-base"],i=arguments.length>4&&void 0!==arguments[4]?arguments[4]:e["$body-color"],c=arguments.length>5&&void 0!==arguments[5]?arguments[5]:e["$body-bg"];return "\n  ".concat(o(),"\n  body {\n  ").concat(l(r,t,n,a,i,c)," \n}")}function a(){return "\n    box-sizing: border-box;\n    font-family: sans-serif;\n    line-height: 1.15;\n    -ms-text-size-adjust: 100%;\n    -webkit-text-size-adjust: 100%;\n    -ms-overflow-style: scrollbar;\n    -webkit-tap-highlight-color: rgba(0,0,0,0);\n  "}function i(){return "\n    box-sizing: inherit;\n  "}function c(){return "\n    width: device-width;\n  "}function l(){var r=arguments.length>0&&void 0!==arguments[0]?arguments[0]:e["$font-family-base"],t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:e["$font-size-base"],o=arguments.length>2&&void 0!==arguments[2]?arguments[2]:e["$font-weight-base"],n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:e["$line-height-base"],a=arguments.length>4&&void 0!==arguments[4]?arguments[4]:e["$body-color"],i=arguments.length>5&&void 0!==arguments[5]?arguments[5]:e["$body-bg"];return "\n    margin: 0;\n    font-family: ".concat(r,";\n    font-size: ").concat(t,";\n    font-weight: ").concat(o,";\n    line-height: ").concat(n,";\n    color: ").concat(a,";\n    background-color: ").concat(i,";\n    \n    ").concat("\n    &.overflow {\n      overflow: hidden;\n    }\n  ",'\n    \n    [tabindex="-1"]:focus {\n      ').concat("\n    outline: none !important;\n  ","\n    }\n    svg:not(:root) {\n      ").concat("\n    overflow: hidden;\n  ","\n    }\n    [hidden] {\n      ").concat("\n    display: none !important;\n  ","\n    }\n    ::-webkit-file-upload-button {\n      ").concat("\n    font: inherit;\n    -webkit-appearance: button;\n  ","\n    }\n  ")}function s(){return "\n    &.overflow {\n      overflow: hidden;\n    }\n  "}function d(){return "\n    outline: none !important;\n  "}function u(){return "\n    overflow: hidden;\n  "}function g(){return "\n    display: none !important;\n  "}function $(){return "\n    font: inherit;\n    -webkit-appearance: button;\n  "}t.defaultProps=e;var b={html:a,boxSizing:i,ie10FixViewport:c,body:l,bodyUtils:s,tabIndex:d,svg:u,ie10FixHidden:g,getGlobalStyles:o,getGlobalStyleNoBootstrapProvider:n,webkitFileUploadButton:$};t.default=b;});_(R);var D=R.getGlobalStyles,G=R.getGlobalStyleNoBootstrapProvider;R.html,R.boxSizing,R.ie10FixViewport,R.body,R.bodyUtils,R.tabIndex,R.svg,R.ie10FixHidden,R.webkitFileUploadButton,R.defaultProps;

var bootstrapStyled_esm = /*#__PURE__*/Object.freeze({
  theme: F,
  makeTheme: N,
  createMakeTheme: q,
  makeScopedTheme: L,
  toMakeTheme: B,
  getGlobalStyles: D,
  getGlobalStyleNoBootstrapProvider: G
});

var conditional = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ifThen = ifThen;
exports.ifElse = ifElse;
exports.default = void 0;
function ifThen(conditions, returnTrue) {
  return ifElse(conditions, returnTrue, '');
}
function ifElse(conditions, returnTrue, returnFalse) {
  return conditions ? returnTrue : returnFalse;
}
var _default = {
  ifThen: ifThen,
  ifElse: ifElse
};
exports.default = _default;
});
unwrapExports(conditional);
var conditional_1 = conditional.ifThen;
var conditional_2 = conditional.ifElse;

var align = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAlignUtilities = getAlignUtilities;
exports.alignBaseline = alignBaseline;
exports.alignTop = alignTop;
exports.alignMiddle = alignMiddle;
exports.alignBottom = alignBottom;
exports.alignTextBottom = alignTextBottom;
exports.alignTextTop = alignTextTop;
exports.default = void 0;
function getAlignUtilities() {
  return "\n   ".concat(alignBaseline(), "\n   ").concat(alignTop(), "\n   ").concat(alignMiddle(), "\n   ").concat(alignBottom(), "\n   ").concat(alignTextBottom(), "\n   ").concat(alignTextTop(), "\n  ");
}
function alignBaseline() {
  return "\n    .align-baseline { vertical-align: baseline !important; } /* Browser default */\n  ";
}
function alignTop() {
  return "\n    .align-top { vertical-align: top !important; }\n  ";
}
function alignMiddle() {
  return "\n    .align-middle { vertical-align: middle !important; }\n  ";
}
function alignBottom() {
  return "\n    .align-bottom { vertical-align: bottom !important; }\n  ";
}
function alignTextBottom() {
  return "\n    .align-text-bottom { vertical-align: text-bottom !important; }\n  ";
}
function alignTextTop() {
  return "\n    .align-text-top { vertical-align: text-top !important; }\n  ";
}
var _default = {
  getAlignUtilities: getAlignUtilities,
  alignBaseline: alignBaseline,
  alignTop: alignTop,
  alignMiddle: alignMiddle,
  alignBottom: alignBottom,
  alignTextBottom: alignTextBottom,
  alignTextTop: alignTextTop
};
exports.default = _default;
});
unwrapExports(align);
var align_1 = align.getAlignUtilities;
var align_2 = align.alignBaseline;
var align_3 = align.alignTop;
var align_4 = align.alignMiddle;
var align_5 = align.alignBottom;
var align_6 = align.alignTextBottom;
var align_7 = align.alignTextTop;

function _classCallCheck(r,e){if(!(r instanceof e))throw new TypeError("Cannot call a class as a function")}var classCallCheck=_classCallCheck;function _defineProperty(r,e,n){return e in r?Object.defineProperty(r,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):r[e]=n,r}var defineProperty=_defineProperty;function createCommonjsModule$1(r,e){return r(e={exports:{}},e.exports),e.exports}var colorName={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]},isArrayish=function(r){return !(!r||"string"==typeof r)&&(r instanceof Array||Array.isArray(r)||r.length>=0&&(r.splice instanceof Function||Object.getOwnPropertyDescriptor(r,r.length-1)&&"String"!==r.constructor.name))},simpleSwizzle=createCommonjsModule$1(function(r){var e=Array.prototype.concat,n=Array.prototype.slice,t=r.exports=function(r){for(var t=[],o=0,a=r.length;o<a;o++){var i=r[o];isArrayish(i)?t=e.call(t,n.call(i)):t.push(i);}return t};t.wrap=function(r){return function(){return r(t(arguments))}};}),colorString=createCommonjsModule$1(function(r){var e={};for(var n in colorName)colorName.hasOwnProperty(n)&&(e[colorName[n]]=n);var t=r.exports={to:{},get:{}};function o(r,e,n){return Math.min(Math.max(e,r),n)}function a(r){var e=r.toString(16).toUpperCase();return e.length<2?"0"+e:e}t.get=function(r){var e,n;switch(r.substring(0,3).toLowerCase()){case"hsl":e=t.get.hsl(r),n="hsl";break;case"hwb":e=t.get.hwb(r),n="hwb";break;default:e=t.get.rgb(r),n="rgb";}return e?{model:n,value:e}:null},t.get.rgb=function(r){if(!r)return null;var e,n,t,a=[0,0,0,1];if(e=r.match(/^#([a-f0-9]{6})([a-f0-9]{2})?$/i)){for(t=e[2],e=e[1],n=0;n<3;n++){var i=2*n;a[n]=parseInt(e.slice(i,i+2),16);}t&&(a[3]=Math.round(parseInt(t,16)/255*100)/100);}else if(e=r.match(/^#([a-f0-9]{3,4})$/i)){for(t=(e=e[1])[3],n=0;n<3;n++)a[n]=parseInt(e[n]+e[n],16);t&&(a[3]=Math.round(parseInt(t+t,16)/255*100)/100);}else if(e=r.match(/^rgba?\(\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*,\s*([+-]?\d+)\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/)){for(n=0;n<3;n++)a[n]=parseInt(e[n+1],0);e[4]&&(a[3]=parseFloat(e[4]));}else{if(!(e=r.match(/^rgba?\(\s*([+-]?[\d\.]+)\%\s*,\s*([+-]?[\d\.]+)\%\s*,\s*([+-]?[\d\.]+)\%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/)))return (e=r.match(/(\D+)/))?"transparent"===e[1]?[0,0,0,0]:(a=colorName[e[1]])?(a[3]=1,a):null:null;for(n=0;n<3;n++)a[n]=Math.round(2.55*parseFloat(e[n+1]));e[4]&&(a[3]=parseFloat(e[4]));}for(n=0;n<3;n++)a[n]=o(a[n],0,255);return a[3]=o(a[3],0,1),a},t.get.hsl=function(r){if(!r)return null;var e=r.match(/^hsla?\(\s*([+-]?(?:\d*\.)?\d+)(?:deg)?\s*,\s*([+-]?[\d\.]+)%\s*,\s*([+-]?[\d\.]+)%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/);if(e){var n=parseFloat(e[4]);return [(parseFloat(e[1])+360)%360,o(parseFloat(e[2]),0,100),o(parseFloat(e[3]),0,100),o(isNaN(n)?1:n,0,1)]}return null},t.get.hwb=function(r){if(!r)return null;var e=r.match(/^hwb\(\s*([+-]?\d*[\.]?\d+)(?:deg)?\s*,\s*([+-]?[\d\.]+)%\s*,\s*([+-]?[\d\.]+)%\s*(?:,\s*([+-]?[\d\.]+)\s*)?\)$/);if(e){var n=parseFloat(e[4]);return [(parseFloat(e[1])%360+360)%360,o(parseFloat(e[2]),0,100),o(parseFloat(e[3]),0,100),o(isNaN(n)?1:n,0,1)]}return null},t.to.hex=function(){var r=simpleSwizzle(arguments);return "#"+a(r[0])+a(r[1])+a(r[2])+(r[3]<1?a(Math.round(255*r[3])):"")},t.to.rgb=function(){var r=simpleSwizzle(arguments);return r.length<4||1===r[3]?"rgb("+Math.round(r[0])+", "+Math.round(r[1])+", "+Math.round(r[2])+")":"rgba("+Math.round(r[0])+", "+Math.round(r[1])+", "+Math.round(r[2])+", "+r[3]+")"},t.to.rgb.percent=function(){var r=simpleSwizzle(arguments),e=Math.round(r[0]/255*100),n=Math.round(r[1]/255*100),t=Math.round(r[2]/255*100);return r.length<4||1===r[3]?"rgb("+e+"%, "+n+"%, "+t+"%)":"rgba("+e+"%, "+n+"%, "+t+"%, "+r[3]+")"},t.to.hsl=function(){var r=simpleSwizzle(arguments);return r.length<4||1===r[3]?"hsl("+r[0]+", "+r[1]+"%, "+r[2]+"%)":"hsla("+r[0]+", "+r[1]+"%, "+r[2]+"%, "+r[3]+")"},t.to.hwb=function(){var r=simpleSwizzle(arguments),e="";return r.length>=4&&1!==r[3]&&(e=", "+r[3]),"hwb("+r[0]+", "+r[1]+"%, "+r[2]+"%"+e+")"},t.to.keyword=function(r){return e[r.slice(0,3)]};}),colorString_1=colorString.to,colorString_2=colorString.get,conversions=createCommonjsModule$1(function(r){var e={};for(var n in colorName)colorName.hasOwnProperty(n)&&(e[colorName[n]]=n);var t=r.exports={rgb:{channels:3,labels:"rgb"},hsl:{channels:3,labels:"hsl"},hsv:{channels:3,labels:"hsv"},hwb:{channels:3,labels:"hwb"},cmyk:{channels:4,labels:"cmyk"},xyz:{channels:3,labels:"xyz"},lab:{channels:3,labels:"lab"},lch:{channels:3,labels:"lch"},hex:{channels:1,labels:["hex"]},keyword:{channels:1,labels:["keyword"]},ansi16:{channels:1,labels:["ansi16"]},ansi256:{channels:1,labels:["ansi256"]},hcg:{channels:3,labels:["h","c","g"]},apple:{channels:3,labels:["r16","g16","b16"]},gray:{channels:1,labels:["gray"]}};for(var o in t)if(t.hasOwnProperty(o)){if(!("channels"in t[o]))throw new Error("missing channels property: "+o);if(!("labels"in t[o]))throw new Error("missing channel labels property: "+o);if(t[o].labels.length!==t[o].channels)throw new Error("channel and label counts mismatch: "+o);var a=t[o].channels,i=t[o].labels;delete t[o].channels,delete t[o].labels,Object.defineProperty(t[o],"channels",{value:a}),Object.defineProperty(t[o],"labels",{value:i});}t.rgb.hsl=function(r){var e,n,t=r[0]/255,o=r[1]/255,a=r[2]/255,i=Math.min(t,o,a),s=Math.max(t,o,a),l=s-i;return s===i?e=0:t===s?e=(o-a)/l:o===s?e=2+(a-t)/l:a===s&&(e=4+(t-o)/l),(e=Math.min(60*e,360))<0&&(e+=360),n=(i+s)/2,[e,100*(s===i?0:n<=.5?l/(s+i):l/(2-s-i)),100*n]},t.rgb.hsv=function(r){var e,n,t,o,a,i=r[0]/255,s=r[1]/255,l=r[2]/255,c=Math.max(i,s,l),h=c-Math.min(i,s,l),u=function(r){return (c-r)/6/h+.5};return 0===h?o=a=0:(a=h/c,e=u(i),n=u(s),t=u(l),i===c?o=t-n:s===c?o=1/3+e-t:l===c&&(o=2/3+n-e),o<0?o+=1:o>1&&(o-=1)),[360*o,100*a,100*c]},t.rgb.hwb=function(r){var e=r[0],n=r[1],o=r[2];return [t.rgb.hsl(r)[0],100*(1/255*Math.min(e,Math.min(n,o))),100*(o=1-1/255*Math.max(e,Math.max(n,o)))]},t.rgb.cmyk=function(r){var e,n=r[0]/255,t=r[1]/255,o=r[2]/255;return [100*((1-n-(e=Math.min(1-n,1-t,1-o)))/(1-e)||0),100*((1-t-e)/(1-e)||0),100*((1-o-e)/(1-e)||0),100*e]},t.rgb.keyword=function(r){var n=e[r];if(n)return n;var t,o,a,i=1/0;for(var s in colorName)if(colorName.hasOwnProperty(s)){var l=colorName[s],c=(o=r,a=l,Math.pow(o[0]-a[0],2)+Math.pow(o[1]-a[1],2)+Math.pow(o[2]-a[2],2));c<i&&(i=c,t=s);}return t},t.keyword.rgb=function(r){return colorName[r]},t.rgb.xyz=function(r){var e=r[0]/255,n=r[1]/255,t=r[2]/255;return [100*(.4124*(e=e>.04045?Math.pow((e+.055)/1.055,2.4):e/12.92)+.3576*(n=n>.04045?Math.pow((n+.055)/1.055,2.4):n/12.92)+.1805*(t=t>.04045?Math.pow((t+.055)/1.055,2.4):t/12.92)),100*(.2126*e+.7152*n+.0722*t),100*(.0193*e+.1192*n+.9505*t)]},t.rgb.lab=function(r){var e=t.rgb.xyz(r),n=e[0],o=e[1],a=e[2];return o/=100,a/=108.883,n=(n/=95.047)>.008856?Math.pow(n,1/3):7.787*n+16/116,[116*(o=o>.008856?Math.pow(o,1/3):7.787*o+16/116)-16,500*(n-o),200*(o-(a=a>.008856?Math.pow(a,1/3):7.787*a+16/116))]},t.hsl.rgb=function(r){var e,n,t,o,a,i=r[0]/360,s=r[1]/100,l=r[2]/100;if(0===s)return [a=255*l,a,a];e=2*l-(n=l<.5?l*(1+s):l+s-l*s),o=[0,0,0];for(var c=0;c<3;c++)(t=i+1/3*-(c-1))<0&&t++,t>1&&t--,a=6*t<1?e+6*(n-e)*t:2*t<1?n:3*t<2?e+(n-e)*(2/3-t)*6:e,o[c]=255*a;return o},t.hsl.hsv=function(r){var e=r[0],n=r[1]/100,t=r[2]/100,o=n,a=Math.max(t,.01);return n*=(t*=2)<=1?t:2-t,o*=a<=1?a:2-a,[e,100*(0===t?2*o/(a+o):2*n/(t+n)),100*((t+n)/2)]},t.hsv.rgb=function(r){var e=r[0]/60,n=r[1]/100,t=r[2]/100,o=Math.floor(e)%6,a=e-Math.floor(e),i=255*t*(1-n),s=255*t*(1-n*a),l=255*t*(1-n*(1-a));switch(t*=255,o){case 0:return [t,l,i];case 1:return [s,t,i];case 2:return [i,t,l];case 3:return [i,s,t];case 4:return [l,i,t];case 5:return [t,i,s]}},t.hsv.hsl=function(r){var e,n,t,o=r[0],a=r[1]/100,i=r[2]/100,s=Math.max(i,.01);return t=(2-a)*i,n=a*s,[o,100*(n=(n/=(e=(2-a)*s)<=1?e:2-e)||0),100*(t/=2)]},t.hwb.rgb=function(r){var e,n,t,o,a,i,s,l=r[0]/360,c=r[1]/100,h=r[2]/100,u=c+h;switch(u>1&&(c/=u,h/=u),t=6*l-(e=Math.floor(6*l)),0!=(1&e)&&(t=1-t),o=c+t*((n=1-h)-c),e){default:case 6:case 0:a=n,i=o,s=c;break;case 1:a=o,i=n,s=c;break;case 2:a=c,i=n,s=o;break;case 3:a=c,i=o,s=n;break;case 4:a=o,i=c,s=n;break;case 5:a=n,i=c,s=o;}return [255*a,255*i,255*s]},t.cmyk.rgb=function(r){var e=r[0]/100,n=r[1]/100,t=r[2]/100,o=r[3]/100;return [255*(1-Math.min(1,e*(1-o)+o)),255*(1-Math.min(1,n*(1-o)+o)),255*(1-Math.min(1,t*(1-o)+o))]},t.xyz.rgb=function(r){var e,n,t,o=r[0]/100,a=r[1]/100,i=r[2]/100;return n=-.9689*o+1.8758*a+.0415*i,t=.0557*o+-.204*a+1.057*i,e=(e=3.2406*o+-1.5372*a+-.4986*i)>.0031308?1.055*Math.pow(e,1/2.4)-.055:12.92*e,n=n>.0031308?1.055*Math.pow(n,1/2.4)-.055:12.92*n,t=t>.0031308?1.055*Math.pow(t,1/2.4)-.055:12.92*t,[255*(e=Math.min(Math.max(0,e),1)),255*(n=Math.min(Math.max(0,n),1)),255*(t=Math.min(Math.max(0,t),1))]},t.xyz.lab=function(r){var e=r[0],n=r[1],t=r[2];return n/=100,t/=108.883,e=(e/=95.047)>.008856?Math.pow(e,1/3):7.787*e+16/116,[116*(n=n>.008856?Math.pow(n,1/3):7.787*n+16/116)-16,500*(e-n),200*(n-(t=t>.008856?Math.pow(t,1/3):7.787*t+16/116))]},t.lab.xyz=function(r){var e,n,t,o=r[0];e=r[1]/500+(n=(o+16)/116),t=n-r[2]/200;var a=Math.pow(n,3),i=Math.pow(e,3),s=Math.pow(t,3);return n=a>.008856?a:(n-16/116)/7.787,e=i>.008856?i:(e-16/116)/7.787,t=s>.008856?s:(t-16/116)/7.787,[e*=95.047,n*=100,t*=108.883]},t.lab.lch=function(r){var e,n=r[0],t=r[1],o=r[2];return (e=360*Math.atan2(o,t)/2/Math.PI)<0&&(e+=360),[n,Math.sqrt(t*t+o*o),e]},t.lch.lab=function(r){var e,n=r[0],t=r[1];return e=r[2]/360*2*Math.PI,[n,t*Math.cos(e),t*Math.sin(e)]},t.rgb.ansi16=function(r){var e=r[0],n=r[1],o=r[2],a=1 in arguments?arguments[1]:t.rgb.hsv(r)[2];if(0===(a=Math.round(a/50)))return 30;var i=30+(Math.round(o/255)<<2|Math.round(n/255)<<1|Math.round(e/255));return 2===a&&(i+=60),i},t.hsv.ansi16=function(r){return t.rgb.ansi16(t.hsv.rgb(r),r[2])},t.rgb.ansi256=function(r){var e=r[0],n=r[1],t=r[2];return e===n&&n===t?e<8?16:e>248?231:Math.round((e-8)/247*24)+232:16+36*Math.round(e/255*5)+6*Math.round(n/255*5)+Math.round(t/255*5)},t.ansi16.rgb=function(r){var e=r%10;if(0===e||7===e)return r>50&&(e+=3.5),[e=e/10.5*255,e,e];var n=.5*(1+~~(r>50));return [(1&e)*n*255,(e>>1&1)*n*255,(e>>2&1)*n*255]},t.ansi256.rgb=function(r){if(r>=232){var e=10*(r-232)+8;return [e,e,e]}var n;return r-=16,[Math.floor(r/36)/5*255,Math.floor((n=r%36)/6)/5*255,n%6/5*255]},t.rgb.hex=function(r){var e=(((255&Math.round(r[0]))<<16)+((255&Math.round(r[1]))<<8)+(255&Math.round(r[2]))).toString(16).toUpperCase();return "000000".substring(e.length)+e},t.hex.rgb=function(r){var e=r.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);if(!e)return [0,0,0];var n=e[0];3===e[0].length&&(n=n.split("").map(function(r){return r+r}).join(""));var t=parseInt(n,16);return [t>>16&255,t>>8&255,255&t]},t.rgb.hcg=function(r){var e,n=r[0]/255,t=r[1]/255,o=r[2]/255,a=Math.max(Math.max(n,t),o),i=Math.min(Math.min(n,t),o),s=a-i;return e=s<=0?0:a===n?(t-o)/s%6:a===t?2+(o-n)/s:4+(n-t)/s+4,e/=6,[360*(e%=1),100*s,100*(s<1?i/(1-s):0)]},t.hsl.hcg=function(r){var e=r[1]/100,n=r[2]/100,t=1,o=0;return (t=n<.5?2*e*n:2*e*(1-n))<1&&(o=(n-.5*t)/(1-t)),[r[0],100*t,100*o]},t.hsv.hcg=function(r){var e=r[1]/100,n=r[2]/100,t=e*n,o=0;return t<1&&(o=(n-t)/(1-t)),[r[0],100*t,100*o]},t.hcg.rgb=function(r){var e=r[0]/360,n=r[1]/100,t=r[2]/100;if(0===n)return [255*t,255*t,255*t];var o,a=[0,0,0],i=e%1*6,s=i%1,l=1-s;switch(Math.floor(i)){case 0:a[0]=1,a[1]=s,a[2]=0;break;case 1:a[0]=l,a[1]=1,a[2]=0;break;case 2:a[0]=0,a[1]=1,a[2]=s;break;case 3:a[0]=0,a[1]=l,a[2]=1;break;case 4:a[0]=s,a[1]=0,a[2]=1;break;default:a[0]=1,a[1]=0,a[2]=l;}return o=(1-n)*t,[255*(n*a[0]+o),255*(n*a[1]+o),255*(n*a[2]+o)]},t.hcg.hsv=function(r){var e=r[1]/100,n=e+r[2]/100*(1-e),t=0;return n>0&&(t=e/n),[r[0],100*t,100*n]},t.hcg.hsl=function(r){var e=r[1]/100,n=r[2]/100*(1-e)+.5*e,t=0;return n>0&&n<.5?t=e/(2*n):n>=.5&&n<1&&(t=e/(2*(1-n))),[r[0],100*t,100*n]},t.hcg.hwb=function(r){var e=r[1]/100,n=e+r[2]/100*(1-e);return [r[0],100*(n-e),100*(1-n)]},t.hwb.hcg=function(r){var e=r[1]/100,n=1-r[2]/100,t=n-e,o=0;return t<1&&(o=(n-t)/(1-t)),[r[0],100*t,100*o]},t.apple.rgb=function(r){return [r[0]/65535*255,r[1]/65535*255,r[2]/65535*255]},t.rgb.apple=function(r){return [r[0]/255*65535,r[1]/255*65535,r[2]/255*65535]},t.gray.rgb=function(r){return [r[0]/100*255,r[0]/100*255,r[0]/100*255]},t.gray.hsl=t.gray.hsv=function(r){return [0,0,r[0]]},t.gray.hwb=function(r){return [0,100,r[0]]},t.gray.cmyk=function(r){return [0,0,0,r[0]]},t.gray.lab=function(r){return [r[0],0,0]},t.gray.hex=function(r){var e=255&Math.round(r[0]/100*255),n=((e<<16)+(e<<8)+e).toString(16).toUpperCase();return "000000".substring(n.length)+n},t.rgb.gray=function(r){return [(r[0]+r[1]+r[2])/3/255*100]};}),conversions_1=conversions.rgb,conversions_2=conversions.hsl,conversions_3=conversions.hsv,conversions_4=conversions.hwb,conversions_5=conversions.cmyk,conversions_6=conversions.xyz,conversions_7=conversions.lab,conversions_8=conversions.lch,conversions_9=conversions.hex,conversions_10=conversions.keyword,conversions_11=conversions.ansi16,conversions_12=conversions.ansi256,conversions_13=conversions.hcg,conversions_14=conversions.apple,conversions_15=conversions.gray;function buildGraph(){for(var r={},e=Object.keys(conversions),n=e.length,t=0;t<n;t++)r[e[t]]={distance:-1,parent:null};return r}function deriveBFS(r){var e=buildGraph(),n=[r];for(e[r].distance=0;n.length;)for(var t=n.pop(),o=Object.keys(conversions[t]),a=o.length,i=0;i<a;i++){var s=o[i],l=e[s];-1===l.distance&&(l.distance=e[t].distance+1,l.parent=t,n.unshift(s));}return e}function link(r,e){return function(n){return e(r(n))}}function wrapConversion(r,e){for(var n=[e[r].parent,r],t=conversions[e[r].parent][r],o=e[r].parent;e[o].parent;)n.unshift(e[o].parent),t=link(conversions[e[o].parent][o],t),o=e[o].parent;return t.conversion=n,t}var route=function(r){for(var e=deriveBFS(r),n={},t=Object.keys(e),o=t.length,a=0;a<o;a++){var i=t[a];null!==e[i].parent&&(n[i]=wrapConversion(i,e));}return n},convert={},models=Object.keys(conversions);function wrapRaw(r){var e=function(e){return null==e?e:(arguments.length>1&&(e=Array.prototype.slice.call(arguments)),r(e))};return "conversion"in r&&(e.conversion=r.conversion),e}function wrapRounded(r){var e=function(e){if(null==e)return e;arguments.length>1&&(e=Array.prototype.slice.call(arguments));var n=r(e);if("object"==typeof n)for(var t=n.length,o=0;o<t;o++)n[o]=Math.round(n[o]);return n};return "conversion"in r&&(e.conversion=r.conversion),e}models.forEach(function(r){convert[r]={},Object.defineProperty(convert[r],"channels",{value:conversions[r].channels}),Object.defineProperty(convert[r],"labels",{value:conversions[r].labels});var e=route(r);Object.keys(e).forEach(function(n){var t=e[n];convert[r][n]=wrapRounded(t),convert[r][n].raw=wrapRaw(t);});});var colorConvert=convert,_slice=[].slice,skippedModels=["keyword","gray","hex"],hashedModelKeys={};Object.keys(colorConvert).forEach(function(r){hashedModelKeys[_slice.call(colorConvert[r].labels).sort().join("")]=r;});var limiters={};function Color(r,e){if(!(this instanceof Color))return new Color(r,e);if(e&&e in skippedModels&&(e=null),e&&!(e in colorConvert))throw new Error("Unknown model: "+e);var n,t;if(void 0===r)this.model="rgb",this.color=[0,0,0],this.valpha=1;else if(r instanceof Color)this.model=r.model,this.color=r.color.slice(),this.valpha=r.valpha;else if("string"==typeof r){var o=colorString.get(r);if(null===o)throw new Error("Unable to parse color from string: "+r);this.model=o.model,t=colorConvert[this.model].channels,this.color=o.value.slice(0,t),this.valpha="number"==typeof o.value[t]?o.value[t]:1;}else if(r.length){this.model=e||"rgb",t=colorConvert[this.model].channels;var a=_slice.call(r,0,t);this.color=zeroArray(a,t),this.valpha="number"==typeof r[t]?r[t]:1;}else if("number"==typeof r)r&=16777215,this.model="rgb",this.color=[r>>16&255,r>>8&255,255&r],this.valpha=1;else{this.valpha=1;var i=Object.keys(r);"alpha"in r&&(i.splice(i.indexOf("alpha"),1),this.valpha="number"==typeof r.alpha?r.alpha:0);var s=i.sort().join("");if(!(s in hashedModelKeys))throw new Error("Unable to parse color from object: "+JSON.stringify(r));this.model=hashedModelKeys[s];var l=colorConvert[this.model].labels,c=[];for(n=0;n<l.length;n++)c.push(r[l[n]]);this.color=zeroArray(c);}if(limiters[this.model])for(t=colorConvert[this.model].channels,n=0;n<t;n++){var h=limiters[this.model][n];h&&(this.color[n]=h(this.color[n]));}this.valpha=Math.max(0,Math.min(1,this.valpha)),Object.freeze&&Object.freeze(this);}function roundTo(r,e){return Number(r.toFixed(e))}function roundToPlace(r){return function(e){return roundTo(e,r)}}function getset(r,e,n){return (r=Array.isArray(r)?r:[r]).forEach(function(r){(limiters[r]||(limiters[r]=[]))[e]=n;}),r=r[0],function(t){var o;return arguments.length?(n&&(t=n(t)),(o=this[r]()).color[e]=t,o):(o=this[r]().color[e],n&&(o=n(o)),o)}}function maxfn(r){return function(e){return Math.max(0,Math.min(r,e))}}function assertArray(r){return Array.isArray(r)?r:[r]}function zeroArray(r,e){for(var n=0;n<e;n++)"number"!=typeof r[n]&&(r[n]=0);return r}Color.prototype={toString:function(){return this.string()},toJSON:function(){return this[this.model]()},string:function(r){var e=this.model in colorString.to?this:this.rgb(),n=1===(e=e.round("number"==typeof r?r:1)).valpha?e.color:e.color.concat(this.valpha);return colorString.to[e.model](n)},percentString:function(r){var e=this.rgb().round("number"==typeof r?r:1),n=1===e.valpha?e.color:e.color.concat(this.valpha);return colorString.to.rgb.percent(n)},array:function(){return 1===this.valpha?this.color.slice():this.color.concat(this.valpha)},object:function(){for(var r={},e=colorConvert[this.model].channels,n=colorConvert[this.model].labels,t=0;t<e;t++)r[n[t]]=this.color[t];return 1!==this.valpha&&(r.alpha=this.valpha),r},unitArray:function(){var r=this.rgb().color;return r[0]/=255,r[1]/=255,r[2]/=255,1!==this.valpha&&r.push(this.valpha),r},unitObject:function(){var r=this.rgb().object();return r.r/=255,r.g/=255,r.b/=255,1!==this.valpha&&(r.alpha=this.valpha),r},round:function(r){return r=Math.max(r||0,0),new Color(this.color.map(roundToPlace(r)).concat(this.valpha),this.model)},alpha:function(r){return arguments.length?new Color(this.color.concat(Math.max(0,Math.min(1,r))),this.model):this.valpha},red:getset("rgb",0,maxfn(255)),green:getset("rgb",1,maxfn(255)),blue:getset("rgb",2,maxfn(255)),hue:getset(["hsl","hsv","hsl","hwb","hcg"],0,function(r){return (r%360+360)%360}),saturationl:getset("hsl",1,maxfn(100)),lightness:getset("hsl",2,maxfn(100)),saturationv:getset("hsv",1,maxfn(100)),value:getset("hsv",2,maxfn(100)),chroma:getset("hcg",1,maxfn(100)),gray:getset("hcg",2,maxfn(100)),white:getset("hwb",1,maxfn(100)),wblack:getset("hwb",2,maxfn(100)),cyan:getset("cmyk",0,maxfn(100)),magenta:getset("cmyk",1,maxfn(100)),yellow:getset("cmyk",2,maxfn(100)),black:getset("cmyk",3,maxfn(100)),x:getset("xyz",0,maxfn(100)),y:getset("xyz",1,maxfn(100)),z:getset("xyz",2,maxfn(100)),l:getset("lab",0,maxfn(100)),a:getset("lab",1),b:getset("lab",2),keyword:function(r){return arguments.length?new Color(r):colorConvert[this.model].keyword(this.color)},hex:function(r){return arguments.length?new Color(r):colorString.to.hex(this.rgb().round().color)},rgbNumber:function(){var r=this.rgb().color;return (255&r[0])<<16|(255&r[1])<<8|255&r[2]},luminosity:function(){for(var r=this.rgb().color,e=[],n=0;n<r.length;n++){var t=r[n]/255;e[n]=t<=.03928?t/12.92:Math.pow((t+.055)/1.055,2.4);}return .2126*e[0]+.7152*e[1]+.0722*e[2]},contrast:function(r){var e=this.luminosity(),n=r.luminosity();return e>n?(e+.05)/(n+.05):(n+.05)/(e+.05)},level:function(r){var e=this.contrast(r);return e>=7.1?"AAA":e>=4.5?"AA":""},isDark:function(){var r=this.rgb().color;return (299*r[0]+587*r[1]+114*r[2])/1e3<128},isLight:function(){return !this.isDark()},negate:function(){for(var r=this.rgb(),e=0;e<3;e++)r.color[e]=255-r.color[e];return r},lighten:function(r){var e=this.hsl();return e.color[2]+=e.color[2]*r,e},darken:function(r){var e=this.hsl();return e.color[2]-=e.color[2]*r,e},saturate:function(r){var e=this.hsl();return e.color[1]+=e.color[1]*r,e},desaturate:function(r){var e=this.hsl();return e.color[1]-=e.color[1]*r,e},whiten:function(r){var e=this.hwb();return e.color[1]+=e.color[1]*r,e},blacken:function(r){var e=this.hwb();return e.color[2]+=e.color[2]*r,e},grayscale:function(){var r=this.rgb().color,e=.3*r[0]+.59*r[1]+.11*r[2];return Color.rgb(e,e,e)},fade:function(r){return this.alpha(this.valpha-this.valpha*r)},opaquer:function(r){return this.alpha(this.valpha+this.valpha*r)},rotate:function(r){var e=this.hsl(),n=e.color[0];return n=(n=(n+r)%360)<0?360+n:n,e.color[0]=n,e},mix:function(r,e){var n=r.rgb(),t=this.rgb(),o=void 0===e?.5:e,a=2*o-1,i=n.alpha()-t.alpha(),s=((a*i==-1?a:(a+i)/(1+a*i))+1)/2,l=1-s;return Color.rgb(s*n.red()+l*t.red(),s*n.green()+l*t.green(),s*n.blue()+l*t.blue(),n.alpha()*o+t.alpha()*(1-o))}},Object.keys(colorConvert).forEach(function(r){if(-1===skippedModels.indexOf(r)){var e=colorConvert[r].channels;Color.prototype[r]=function(){if(this.model===r)return new Color(this);if(arguments.length)return new Color(arguments,r);var n="number"==typeof arguments[e]?e:this.valpha;return new Color(assertArray(colorConvert[this.model][r].raw(this.color)).concat(n),r)},Color[r]=function(n){return "number"==typeof n&&(n=zeroArray(_slice.call(arguments),e)),new Color(n,r)};}});var color=Color,ColorMock=function r(e){var n=this;classCallCheck(this,r),defineProperty(this,"hsl",function(){return n}),defineProperty(this,"isLight",function(){return !1}),defineProperty(this,"isDark",function(){return !1}),defineProperty(this,"negate",function(){return n}),defineProperty(this,"lighten",function(){return n}),defineProperty(this,"darken",function(){return n}),defineProperty(this,"alpha",function(){return n}),defineProperty(this,"saturate",function(){return n}),defineProperty(this,"desaturate",function(){return n}),defineProperty(this,"grayscale",function(){return n}),defineProperty(this,"whiten",function(){return n}),defineProperty(this,"blacken",function(){return n}),defineProperty(this,"fade",function(){return n}),defineProperty(this,"opaquer",function(){return n}),defineProperty(this,"rotate",function(){return n}),defineProperty(this,"contrast",function(){return 10}),defineProperty(this,"luminosity",function(){return .5}),defineProperty(this,"mix",function(){return n}),defineProperty(this,"blue",function(){return n.toString()}),defineProperty(this,"green",function(){return n.toString()}),defineProperty(this,"red",function(){return n.toString()}),defineProperty(this,"hex",function(){return n.toString()}),defineProperty(this,"rgbNumber",function(){return n.toString()}),defineProperty(this,"rgb",function(){return n.toString()}),defineProperty(this,"toString",function(){return n.color}),this.color=e;};function ColorWrapper(r){return "string"==typeof r&&-1!==r.indexOf("linear-gradient")?new ColorMock(r):color(r)}

var MixinError_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _wrapNativeSuper(Class) { var _cache = typeof Map === "function" ? new Map() : undefined; _wrapNativeSuper = function _wrapNativeSuper(Class) { if (Class === null || !_isNativeFunction(Class)) return Class; if (typeof Class !== "function") { throw new TypeError("Super expression must either be null or a function"); } if (typeof _cache !== "undefined") { if (_cache.has(Class)) return _cache.get(Class); _cache.set(Class, Wrapper); } function Wrapper() { return _construct(Class, arguments, _getPrototypeOf(this).constructor); } Wrapper.prototype = Object.create(Class.prototype, { constructor: { value: Wrapper, enumerable: false, writable: true, configurable: true } }); return _setPrototypeOf(Wrapper, Class); }; return _wrapNativeSuper(Class); }
function isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
function _construct(Parent, args, Class) { if (isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }
function _isNativeFunction(fn) { return Function.toString.call(fn).indexOf("[native code]") !== -1; }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
var MixinError =
function (_Error) {
  _inherits(MixinError, _Error);
  function MixinError(args) {
    var _this;
    _classCallCheck(this, MixinError);
    _this = _possibleConstructorReturn(this, _getPrototypeOf(MixinError).call(this, args));
    Error.captureStackTrace(_assertThisInitialized(_assertThisInitialized(_this)), MixinError);
    return _this;
  }
  return MixinError;
}(_wrapNativeSuper(Error));
exports.default = MixinError;
module.exports = exports.default;
});
unwrapExports(MixinError_1);

var hover_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.hover = hover;
exports.hoverFocus = hoverFocus;
exports.plainHoverFocus = plainHoverFocus;
exports.hoverFocusActive = hoverFocusActive;
exports.default = exports.defaultProps = void 0;
var _MixinError = _interopRequireDefault(MixinError_1);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var defaultProps = {
  '$enable-hover-media-query': false
};
exports.defaultProps = defaultProps;
function hover(content) {
  if (!content) throw new _MixinError.default('content is required');
  return "&:hover, &.hover { ".concat(content, " }");
}
function hoverFocus() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var content = arguments.length > 1 ? arguments[1] : undefined;
  if (enableHoverMediaQuery) {
    return " \n      &:focus, &.focus { ".concat(content, " }\n      ").concat(hover(content), "\n    ");
  }
  return "\n    &:focus,\n    &.focus,\n    &:hover,\n    &.hover {\n      ".concat(content, "\n    }\n  ");
}
function plainHoverFocus() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var content = arguments.length > 1 ? arguments[1] : undefined;
  if (enableHoverMediaQuery) {
    return "\n      &, \n      &:focus, \n      &.focus {\n        ".concat(content, "\n      }\n      ").concat(hover(content), "\n    ");
  }
  return " \n    &, \n    &:focus, \n    &.focus, \n    &:hover, \n    &.hover {\n      ".concat(content, "\n    }\n  ");
}
function hoverFocusActive() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var content = arguments.length > 1 ? arguments[1] : undefined;
  if (enableHoverMediaQuery) {
    return "\n      &:focus,\n      &.focus,\n      &:active,\n      &.active {\n        ".concat(content, "\n      }\n      ").concat(hover(content), "\n    ");
  }
  return "\n    &:focus, \n    &.focus, \n    &:active, \n    &.active,\n    &:hover,\n    &.hover {\n     ".concat(content, "\n    }\n  ");
}
hover.focus = hoverFocus;
hover.plainFocus = plainHoverFocus;
hover.activeFocus = hoverFocusActive;
var _default = {
  defaultProps: defaultProps,
  hover: hover,
  hoverFocus: hoverFocus,
  plainHoverFocus: plainHoverFocus,
  hoverFocusActive: hoverFocusActive
};
exports.default = _default;
});
unwrapExports(hover_1);
var hover_2 = hover_1.hover;
var hover_3 = hover_1.hoverFocus;
var hover_4 = hover_1.plainHoverFocus;
var hover_5 = hover_1.hoverFocusActive;
var hover_6 = hover_1.defaultProps;

var backgroundVariant = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.bgVariant = bgVariant;
exports.default = exports.defaultProps = void 0;
var _color = _interopRequireDefault(ColorWrapper);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var defaultProps = {
  '$enable-hover-media-query': false
};
exports.defaultProps = defaultProps;
function bgVariant() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var selector = arguments.length > 1 ? arguments[1] : undefined;
  var bgColor = arguments.length > 2 ? arguments[2] : undefined;
  return "\n    ".concat(selector, " {\n      background-color: ").concat(bgColor, " !important;\n    }\n    a").concat(selector, " {\n      ").concat((0, hover_1.hoverFocus)(enableHoverMediaQuery, "background-color: ".concat((0, _color.default)(bgColor).darken(0.2).rgb(), " !important;")), "\n    }\n  ");
}
var _default = {
  bgVariant: bgVariant
};
exports.default = _default;
});
unwrapExports(backgroundVariant);
var backgroundVariant_1 = backgroundVariant.bgVariant;
var backgroundVariant_2 = backgroundVariant.defaultProps;

var background = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBackgroundUtilities = getBackgroundUtilities;
exports.default = exports.bgFaded = exports.bgInverse = exports.bgDanger = exports.bgWarning = exports.bgInfo = exports.bgSuccess = exports.bgPrimary = exports.defaultProps = void 0;
var defaultProps = {
  '$enable-hover-media-query': false,
  '$brand-primary': '#0275d8',
  '$brand-success': '#5cb85c',
  '$brand-info': '#5bc0de',
  '$brand-warning': '#f0ad4e',
  '$brand-danger': '#d9543f',
  '$brand-inverse': '#373a3c',
  '$gray-lightest': '#f7f7f9'
};
exports.defaultProps = defaultProps;
function getBackgroundUtilities() {
  var $enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var $brandPrimary = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-primary'];
  var $brandSuccess = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$brand-success'];
  var $brandInfo = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$brand-info'];
  var $brandWarning = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$brand-warning'];
  var $brandDanger = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$brand-danger'];
  var $brandInverse = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : defaultProps['$brand-inverse'];
  var $grayLightest = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : defaultProps['$gray-lightest'];
  return "\n    ".concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-primary', $brandPrimary), "\n    ").concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-success', $brandSuccess), "\n    ").concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-info', $brandInfo), "\n    ").concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-warning', $brandWarning), "\n    ").concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-danger', $brandDanger), "\n    ").concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-inverse', $brandInverse), "\n    ").concat((0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-faded', $grayLightest), "\n  ");
}
var bgPrimary = function bgPrimary($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-primary'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-primary', bgColor);
};
exports.bgPrimary = bgPrimary;
var bgSuccess = function bgSuccess($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-success'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-success', bgColor);
};
exports.bgSuccess = bgSuccess;
var bgInfo = function bgInfo($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-info'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-info', bgColor);
};
exports.bgInfo = bgInfo;
var bgWarning = function bgWarning($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-warning'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-warning', bgColor);
};
exports.bgWarning = bgWarning;
var bgDanger = function bgDanger($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-danger'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-danger', bgColor);
};
exports.bgDanger = bgDanger;
var bgInverse = function bgInverse($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$brand-inverse'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-inverse', bgColor);
};
exports.bgInverse = bgInverse;
var bgFaded = function bgFaded($enableHoverMediaQuery) {
  var bgColor = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$gray-lightest'];
  return (0, backgroundVariant.bgVariant)($enableHoverMediaQuery, '.bg-faded', bgColor);
};
exports.bgFaded = bgFaded;
var _default = {
  defaultProps: defaultProps,
  getBackgroundUtilities: getBackgroundUtilities,
  bgFaded: bgFaded,
  bgPrimary: bgPrimary,
  bgSuccess: bgSuccess,
  bgInfo: bgInfo,
  bgWarning: bgWarning,
  bgDanger: bgDanger,
  bgInverse: bgInverse
};
exports.default = _default;
});
unwrapExports(background);
var background_1 = background.getBackgroundUtilities;
var background_2 = background.bgFaded;
var background_3 = background.bgInverse;
var background_4 = background.bgDanger;
var background_5 = background.bgWarning;
var background_6 = background.bgInfo;
var background_7 = background.bgSuccess;
var background_8 = background.bgPrimary;
var background_9 = background.defaultProps;

var borderRadius_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.borderRadius = borderRadius;
exports.borderTopRadius = borderTopRadius;
exports.borderRightRadius = borderRightRadius;
exports.borderBottomRadius = borderBottomRadius;
exports.borderLeftRadius = borderLeftRadius;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$border-radius': '.25rem',
  '$enable-rounded': true
};
exports.defaultProps = defaultProps;
function borderRadius() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  if (enableRounded) {
    return "\n      border-radius: ".concat(radius, ";\n    ");
  }
  return '';
}
function borderTopRadius() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  if (enableRounded) {
    return "\n      border-top-right-radius: ".concat(radius, ";\n      border-top-left-radius: ").concat(radius, ";\n    ");
  }
  return '';
}
function borderRightRadius() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  if (enableRounded) {
    return "\n      border-bottom-right-radius: ".concat(radius, ";\n      border-top-right-radius: ").concat(radius, ";\n    ");
  }
  return '';
}
function borderBottomRadius() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  if (enableRounded) {
    return "\n      border-bottom-right-radius: ".concat(radius, ";\n      border-bottom-left-radius: ").concat(radius, ";\n    ");
  }
  return '';
}
function borderLeftRadius() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  if (enableRounded) {
    return "\n      border-bottom-left-radius: ".concat(radius, ";\n      border-top-left-radius: ").concat(radius, ";\n    ");
  }
  return '';
}
var _default = {
  defaultProps: defaultProps,
  all: borderRadius,
  top: borderTopRadius,
  right: borderRightRadius,
  bottom: borderBottomRadius,
  left: borderLeftRadius
};
exports.default = _default;
});
unwrapExports(borderRadius_1);
var borderRadius_2 = borderRadius_1.borderRadius;
var borderRadius_3 = borderRadius_1.borderTopRadius;
var borderRadius_4 = borderRadius_1.borderRightRadius;
var borderRadius_5 = borderRadius_1.borderBottomRadius;
var borderRadius_6 = borderRadius_1.borderLeftRadius;
var borderRadius_7 = borderRadius_1.defaultProps;

var borders = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBordersUtilities = getBordersUtilities;
exports.rounded = rounded;
exports.roundedTop = roundedTop;
exports.roundedRight = roundedRight;
exports.roundedBottom = roundedBottom;
exports.roundedLeft = roundedLeft;
exports.roundedCircle = roundedCircle;
exports.resetBorder = resetBorder;
exports.resetBorderTop = resetBorderTop;
exports.resetBorderRight = resetBorderRight;
exports.resetBorderBottom = resetBorderBottom;
exports.resetBorderLeft = resetBorderLeft;
exports.resetRounded = resetRounded;
exports.resetRoundedTop = resetRoundedTop;
exports.resetRoundedBottom = resetRoundedBottom;
exports.resetRoundedLeft = resetRoundedLeft;
exports.resetRoundedRight = resetRoundedRight;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$border-radius': '.25rem',
  '$enable-rounded': true
};
exports.defaultProps = defaultProps;
function getBordersUtilities() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  return "\n    ".concat(rounded(enableRounded, radius), "\n    ").concat(roundedTop(enableRounded, radius), "\n    ").concat(roundedRight(enableRounded, radius), "\n    ").concat(roundedBottom(enableRounded, radius), "\n    ").concat(roundedLeft(enableRounded, radius), "\n    ").concat(roundedCircle(), "\n    ").concat(resetRounded(), "\n    ").concat(resetRoundedTop(), "\n    ").concat(resetRoundedRight(), "\n    ").concat(resetRoundedLeft(), "\n    ").concat(resetRoundedBottom(), "\n    ").concat(resetBorder(), "\n    ").concat(resetBorderTop(), "\n    ").concat(resetBorderRight(), "\n    ").concat(resetBorderLeft(), "\n    ").concat(resetBorderBottom(), "\n  ");
}
function rounded() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  return "\n    .rounded {\n      ".concat((0, borderRadius_1.borderRadius)(enableRounded, radius), "\n    }\n  ");
}
function roundedTop() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  return "\n    .rounded-top {\n      ".concat((0, borderRadius_1.borderTopRadius)(enableRounded, radius), "\n    }\n  ");
}
function roundedRight() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  return "\n    .rounded-right {\n      ".concat((0, borderRadius_1.borderRightRadius)(enableRounded, radius), "\n    }\n  ");
}
function roundedBottom() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  return "\n    .rounded-bottom {\n      ".concat((0, borderRadius_1.borderBottomRadius)(enableRounded, radius), "\n    }\n  ");
}
function roundedLeft() {
  var enableRounded = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-rounded'];
  var radius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$border-radius'];
  return "\n    .rounded-left {\n      ".concat((0, borderRadius_1.borderLeftRadius)(enableRounded, radius), "\n    }\n  ");
}
function roundedCircle() {
  return "\n    .rounded-circle {\n      border-radius: 50%;\n    }\n  ";
}
function resetBorder() {
  return "\n    .border-0 {\n      border: 0 !important;\n    }\n  ";
}
function resetBorderTop() {
  return "\n    .border-top-0 {\n      border-top: 0 !important;\n    }\n  ";
}
function resetBorderRight() {
  return "\n    .border-right-0 {\n      border-right: 0 !important;\n    }\n  ";
}
function resetBorderBottom() {
  return "\n    .border-bottom-0 {\n      border-bottom: 0 !important;\n    }\n  ";
}
function resetBorderLeft() {
  return "\n    .border-left-0 {\n      border-left: 0 !important;\n    }\n  ";
}
function resetRounded() {
  return "\n    .rounded-0 {\n      border-radius: 0 !important;\n    }\n  ";
}
function resetRoundedTop() {
  return "\n    .rounded-top-0 {\n      border-top-left-radius: 0 !important;\n      border-top-right-radius: 0 !important;\n    }\n  ";
}
function resetRoundedBottom() {
  return "\n    .rounded-bottom-0 {\n      border-bottom-left-radius: 0 !important;\n      border-bottom-right-radius: 0 !important;\n    }\n  ";
}
function resetRoundedLeft() {
  return "\n    .rounded-left-0 {\n      border-bottom-left-radius: 0 !important;\n      border-top-left-radius: 0 !important;\n    }\n  ";
}
function resetRoundedRight() {
  return "\n    .rounded-right-0 {\n      border-bottom-right-radius: 0 !important;\n      border-top-right-radius: 0 !important;\n    }\n  ";
}
var _default = {
  defaultProps: defaultProps,
  getBordersUtilities: getBordersUtilities,
  rounded: rounded,
  roundedTop: roundedTop,
  roundedRight: roundedRight,
  roundedBottom: roundedBottom,
  roundedLeft: roundedLeft,
  roundedCircle: roundedCircle
};
exports.default = _default;
});
unwrapExports(borders);
var borders_1 = borders.getBordersUtilities;
var borders_2 = borders.rounded;
var borders_3 = borders.roundedTop;
var borders_4 = borders.roundedRight;
var borders_5 = borders.roundedBottom;
var borders_6 = borders.roundedLeft;
var borders_7 = borders.roundedCircle;
var borders_8 = borders.resetBorder;
var borders_9 = borders.resetBorderTop;
var borders_10 = borders.resetBorderRight;
var borders_11 = borders.resetBorderBottom;
var borders_12 = borders.resetBorderLeft;
var borders_13 = borders.resetRounded;
var borders_14 = borders.resetRoundedTop;
var borders_15 = borders.resetRoundedBottom;
var borders_16 = borders.resetRoundedLeft;
var borders_17 = borders.resetRoundedRight;
var borders_18 = borders.defaultProps;

var clearfix_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.clearfix = clearfix;
exports.default = void 0;
function clearfix() {
  return "\n    &::after {\n      content: \"\";\n      display: table;\n      clear: both;\n    }\n  ";
}
var _default = {
  clearfix: clearfix
};
exports.default = _default;
});
unwrapExports(clearfix_1);
var clearfix_2 = clearfix_1.clearfix;

var clearfix$1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getClearfixUtilities = getClearfixUtilities;
exports.getClearfix = getClearfix;
exports.default = void 0;
function getClearfixUtilities() {
  return "\n   ".concat(getClearfix(), "\n  ");
}
function getClearfix() {
  return "\n    .clearfix {\n      ".concat((0, clearfix_1.clearfix)(), "\n    }\n  ");
}
var _default = {
  getClearfixUtilities: getClearfixUtilities,
  getClearfix: getClearfix
};
exports.default = _default;
});
unwrapExports(clearfix$1);
var clearfix_1$1 = clearfix$1.getClearfixUtilities;
var clearfix_2$1 = clearfix$1.getClearfix;

var cursor = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCursorUtilities = getCursorUtilities;
exports.default = void 0;
function getCursorUtilities() {
  return "\n    .cursor-alias {\n      cursor: alias;\n    }\n    \n    .cursor-all-scroll {\n      cursor: all-scroll;\n    }\n    \n    .cursor-auto {\n      cursor: auto;\n    }\n    \n    .cursor-cell {\n      cursor: cell;\n    }\n    \n    .cursor-context-menu {\n      cursor: context-menu;\n    }\n    \n    .cursor-col-resize {\n      cursor: col-resize;\n    }\n    \n    .cursor-copy {\n      cursor: copy;\n    }\n    \n    .cursor-crosshair {\n      cursor: crosshair;\n    }\n    \n    .cursor-default {\n      cursor: default;\n    }\n    \n    .cursor-e-resize {\n      cursor: e-resize;\n    }\n    \n    .cursor-ew-resize {\n      cursor: ew-resize;\n    }\n    \n    .cursor-grab {\n      cursor: grab;\n    }\n    \n    .cursor-grabbing {\n      cursor: grabbing;\n    }\n    \n    .cursor-help {\n      cursor: help;\n    }\n    \n    .cursor-move {\n      cursor: move;\n    }\n    \n    .cursor-n-resize {\n      cursor: n-resize;\n    }\n    \n    .cursor-ne-resize {\n      cursor: ne-resize;\n    }\n    \n    .cursor-nesw-resize {\n      cursor: nesw-resize;\n    }\n    \n    .cursor-ns-resize {\n      cursor: ns-resize;\n    }\n    \n    .cursor-nw-resize {\n      cursor: nw-resize;\n    }\n    \n    .cursor-nwse-resize {\n      cursor: nwse-resize;\n    }\n    \n    .cursor-no-drop {\n      cursor: no-drop;\n    }\n    \n    .cursor-none {\n      cursor: none;\n    }\n    \n    .cursor-not-allowed {\n      cursor: not-allowed;\n    }\n    \n    .cursor-pointer {\n      cursor: pointer;\n    }\n    \n    .cursor-progress {\n      cursor: progress;\n    }\n    \n    .cursor-row-resize {\n      cursor: row-resize;\n    }\n    \n    .cursor-s-resize {\n      cursor: s-resize;\n    }\n    \n    .cursor-se-resize {\n      cursor: se-resize;\n    }\n    \n    .cursor-sw-resize {\n      cursor: sw-resize;\n    }\n    \n    .cursor-text {\n      cursor: text;\n    }\n    \n    .cursor-vertical-text {\n      cursor: vertical-text;\n    }\n    \n    .cursor-w-resize {\n      cursor: w-resize;\n    }\n    \n    .cursor-wait {\n      cursor: wait;\n    }\n    \n    .cursor-zoom-in {\n      cursor: zoom-in;\n    }\n    \n    .cursor-zoom-out {\n      cursor: zoom-out;\n    }\n    \n    .cursor-initial {\n      cursor: initial;\n    }\n  ";
}
var _default = {
  getCursorUtilities: getCursorUtilities
};
exports.default = _default;
});
unwrapExports(cursor);
var cursor_1 = cursor.getCursorUtilities;

var unitUtils = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
var UnitUtils = function UnitUtils() {
  var _this = this;
  _classCallCheck(this, UnitUtils);
  this.UNIT = {
    EM: 'em',
    REM: 'rem',
    PX: 'px',
    PERCENT: '%'
  };
  this.math = {
    addition: function addition(a, b) {
      var unit = this.detectUnit(a) || this.detectUnit(b);
      return this.rmUnit(a) + this.rmUnit(b) + unit;
    }.bind(this),
    subtract: function subtract(a, b) {
      var unit = this.detectUnit(a) || this.detectUnit(b);
      return this.rmUnit(a) - this.rmUnit(b) + unit;
    }.bind(this),
    multiply: function multiply(a, b) {
      var unit = this.detectUnit(a) || this.detectUnit(b);
      return this.rmUnit(a) * this.rmUnit(b) + unit;
    }.bind(this),
    divide: function divide(a, b) {
      var unit = this.detectUnit(a) || this.detectUnit(b);
      return this.rmUnit(a) / this.rmUnit(b) + unit;
    }.bind(this)
  };
  this.detectUnit = function (value) {
    var ext;
    var valueStr = value.toString();
    if (valueStr.match(_this.UNIT.PX)) {
      ext = _this.UNIT.PX;
    } else if (valueStr.match(_this.UNIT.REM)) {
      ext = _this.UNIT.REM;
    } else if (valueStr.match(_this.UNIT.EM)) {
      ext = _this.UNIT.EM;
    } else if (valueStr.match(_this.UNIT.PERCENT)) {
      ext = _this.UNIT.PERCENT;
    } else if (!isNaN(value)) {
      return null;
    } else {
      throw new Error("detectUnit can't find unit for ".concat(value));
    }
    return ext;
  };
  this.rmUnit = function (value, unit) {
    var valueStr = value.toString();
    var ext = unit || _this.detectUnit(valueStr);
    var number = valueStr.replace(ext, '');
    return parseFloat(number);
  };
  this.toPercent = function (value) {
    var total = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 100;
    var decimal = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 2;
    return "".concat(Math.floor(value / total * 100 * Math.pow(10, decimal)) / Math.pow(10, decimal)).concat(_this.UNIT.PERCENT);
  };
};
var _default = new UnitUtils();
exports.default = _default;
module.exports = exports.default;
});
unwrapExports(unitUtils);

var breakpoints = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.breakpointNext = breakpointNext;
exports.breakpointMin = breakpointMin;
exports.breakpointMax = breakpointMax;
exports.breakpointInfix = breakpointInfix;
exports.mediaBreakpointUp = mediaBreakpointUp;
exports.mediaBreakpointDown = mediaBreakpointDown;
exports.mediaBreakpointBetween = mediaBreakpointBetween;
exports.mediaBreakpointOnly = mediaBreakpointOnly;
exports.default = exports.defaultProps = void 0;
var _unitUtils = _interopRequireDefault(unitUtils);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  }
};
exports.defaultProps = defaultProps;
function breakpointNext(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var breakpointNames = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : Object.keys(breakpoints);
  var n = breakpointNames.indexOf(name);
  if (n !== -1 && n + 1 < breakpointNames.length) {
    return breakpointNames[n + 1];
  }
  return null;
}
function breakpointMin(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var min = breakpoints[name];
  return min !== '0' ? min : null;
}
function breakpointMax(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var next = breakpointNext(name, breakpoints);
  if (next) {
    var min = _unitUtils.default.rmUnit(breakpointMin(next, breakpoints), _unitUtils.default.UNIT.PX);
    return (min - 1).toString() + _unitUtils.default.UNIT.PX;
  }
  return null;
}
function breakpointInfix(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  return !name || breakpointMin(name, breakpoints) === null ? '' : "-".concat(name);
}
function mediaBreakpointUp(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var content = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
  var min = breakpointMin(name, breakpoints);
  if (min) {
    return "\n      @media (min-width: ".concat(min, ") {\n        ").concat(content, "\n      }\n    ");
  }
  return content;
}
function mediaBreakpointDown(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var content = arguments.length > 2 ? arguments[2] : undefined;
  var max = breakpointMax(name, breakpoints);
  if (max) {
    return "\n      @media (max-width: ".concat(max, ") {\n        ").concat(content, "\n      }\n    ");
  }
  return content;
}
function mediaBreakpointBetween(lower, upper) {
  var breakpoints = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$grid-breakpoints'];
  var content = arguments.length > 3 ? arguments[3] : undefined;
  var min = breakpointMin(lower, breakpoints);
  var max = breakpointMax(upper, breakpoints);
  if (min && max) {
    return "\n      @media (min-width: ".concat(min, ") and (max-width: ").concat(max, ") {\n        ").concat(content, "\n      }\n    ");
  } else if (min) {
    return "\n      @media (min-width: ".concat(min, ") {\n        ").concat(content, "\n      }\n    ");
  } else if (max) {
    return "\n      @media (max-width: ".concat(max, ") {\n        ").concat(content, "\n      }\n    ");
  }
  return content;
}
function mediaBreakpointOnly(name) {
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var content = arguments.length > 2 ? arguments[2] : undefined;
  return mediaBreakpointBetween(name, name, breakpoints, content);
}
var _default = {
  defaultProps: defaultProps,
  up: mediaBreakpointUp,
  down: mediaBreakpointDown,
  between: mediaBreakpointBetween,
  only: mediaBreakpointOnly
};
exports.default = _default;
});
unwrapExports(breakpoints);
var breakpoints_1 = breakpoints.breakpointNext;
var breakpoints_2 = breakpoints.breakpointMin;
var breakpoints_3 = breakpoints.breakpointMax;
var breakpoints_4 = breakpoints.breakpointInfix;
var breakpoints_5 = breakpoints.mediaBreakpointUp;
var breakpoints_6 = breakpoints.mediaBreakpointDown;
var breakpoints_7 = breakpoints.mediaBreakpointBetween;
var breakpoints_8 = breakpoints.mediaBreakpointOnly;
var breakpoints_9 = breakpoints.defaultProps;

var display = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDisplayUtilities = getDisplayUtilities;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  }
};
exports.defaultProps = defaultProps;
function getDisplayUtilities() {
  var gridBreakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-breakpoints'];
  var utilityList = [];
  Object.keys(gridBreakpoints).forEach(function (breakpoint) {
    var infix = (0, breakpoints.breakpointInfix)(breakpoint, gridBreakpoints);
    utilityList.push("\n      ".concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .d".concat(infix, "-none { display: none !important; }\n        .d").concat(infix, "-inline { display: inline !important; }\n        .d").concat(infix, "-inline-block { display: inline-block !important; }\n        .d").concat(infix, "-block { display: block !important; }\n        .d").concat(infix, "-table { display: table !important; }\n        .d").concat(infix, "-table-cell { display: table-cell !important; }\n        .d").concat(infix, "-flex { display: flex !important; }\n        .d").concat(infix, "-inline-flex { display: inline-flex !important; }\n      ")), "\n    "));
  });
  utilityList.push("\n    .d-print-block {\n      display: none !important;\n    \n      @media print {\n        display: block !important;\n      }\n    }\n    \n    .d-print-inline {\n      display: none !important;\n    \n      @media print {\n        display: inline !important;\n      }\n    }\n    \n    .d-print-inline-block {\n      display: none !important;\n    \n      @media print {\n        display: inline-block !important;\n      }\n    }\n    \n    .d-print-none {\n      @media print {\n        display: none !important;\n      }\n    }\n  ");
  return utilityList.join('\n');
}
var _default = {
  defaultProps: defaultProps,
  getDisplayUtilities: getDisplayUtilities
};
exports.default = _default;
});
unwrapExports(display);
var display_1 = display.getDisplayUtilities;
var display_2 = display.defaultProps;

var flex = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFlexUtilities = getFlexUtilities;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  }
};
exports.defaultProps = defaultProps;
function getFlexUtilities() {
  var gridBreakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-breakpoints'];
  var flexUtilityList = [];
  Object.keys(gridBreakpoints).forEach(function (breakpoint) {
    var infix = (0, breakpoints.breakpointInfix)(breakpoint, gridBreakpoints);
    flexUtilityList.push("\n      /* Flex column reordering */\n      ".concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .flex".concat(infix, "-first { order: -1; }\n        .flex").concat(infix, "-last { order: 1; }\n        .flex").concat(infix, "-unordered { order: 0; }\n      ")), "\n  \n      /* Flex direction */ \n      ").concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .flex".concat(infix, "-row            { flex-direction: row !important; }\n        .flex").concat(infix, "-column         { flex-direction: column !important; }\n        .flex").concat(infix, "-row-reverse    { flex-direction: row-reverse !important; }\n        .flex").concat(infix, "-column-reverse { flex-direction: column-reverse !important; }\n      ")), "\n      \n      /* Flex wrap */ \n      ").concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .flex".concat(infix, "-wrap         { flex-wrap: wrap !important; }\n        .flex").concat(infix, "-nowrap       { flex-wrap: nowrap !important; }\n        .flex").concat(infix, "-wrap-reverse { flex-wrap: wrap-reverse !important; }\n      ")), "\n      /* Flex justify-content */ \n      ").concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .justify-content".concat(infix, "-start   { justify-content: flex-start !important; }\n        .justify-content").concat(infix, "-end     { justify-content: flex-end !important; }\n        .justify-content").concat(infix, "-center  { justify-content: center !important; }\n        .justify-content").concat(infix, "-between { justify-content: space-between !important; }\n        .justify-content").concat(infix, "-around  { justify-content: space-around !important; }\n        .justify-content").concat(infix, "-evenly  { justify-content: space-evenly !important; }\n      ")), "\n      /* Flex align-items */ \n      ").concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .align-items".concat(infix, "-start    { align-items: flex-start !important; }\n        .align-items").concat(infix, "-end      { align-items: flex-end !important; }\n        .align-items").concat(infix, "-center   { align-items: center !important; }\n        .align-items").concat(infix, "-baseline { align-items: baseline !important; }\n        .align-items").concat(infix, "-stretch  { align-items: stretch !important; }\n      ")), "\n      /* Flex align-content */ \n      ").concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .align-content".concat(infix, "-start   { align-content: flex-start !important; }\n        .align-content").concat(infix, "-end     { align-content: flex-end !important; }\n        .align-content").concat(infix, "-center  { align-content: center !important; }\n        .align-content").concat(infix, "-between { align-content: space-between !important; }\n        .align-content").concat(infix, "-around  { align-content: space-around !important; }\n        .align-content").concat(infix, "-stretch { align-content: stretch !important; }\n      ")), "\n      /* Flex align-self */ \n      ").concat((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        .align-self".concat(infix, "-auto     { align-self: auto !important; }\n        .align-self").concat(infix, "-start    { align-self: flex-start !important; }\n        .align-self").concat(infix, "-end      { align-self: flex-end !important; }\n        .align-self").concat(infix, "-center   { align-self: center !important; }\n        .align-self").concat(infix, "-baseline { align-self: baseline !important; }\n        .align-self").concat(infix, "-stretch  { align-self: stretch !important; }\n      ")), " \n    "));
  });
  return flexUtilityList.join('\n');
}
var _default = {
  defaultProps: defaultProps,
  getFlexUtilities: getFlexUtilities
};
exports.default = _default;
});
unwrapExports(flex);
var flex_1 = flex.getFlexUtilities;
var flex_2 = flex.defaultProps;

var float_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.floatLeft = floatLeft;
exports.floatRight = floatRight;
exports.floatNone = floatNone;
exports.default = void 0;
function floatLeft() {
  return "\n    float: left !important;\n  ";
}
function floatRight() {
  return "\n    float: right !important;\n  ";
}
function floatNone() {
  return "\n    float: none !important;\n  ";
}
var _default = {
  floatLeft: floatLeft,
  floatRight: floatRight,
  floatNone: floatNone
};
exports.default = _default;
});
unwrapExports(float_1);
var float_2 = float_1.floatLeft;
var float_3 = float_1.floatRight;
var float_4 = float_1.floatNone;

var float_1$1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFloatUtilities = getFloatUtilities;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  }
};
exports.defaultProps = defaultProps;
function getFloatUtilities() {
  var gridBreakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-breakpoints'];
  var floatUtilityList = [];
  Object.keys(gridBreakpoints).forEach(function (breakpoint) {
    var infix = (0, breakpoints.breakpointInfix)(breakpoint, gridBreakpoints);
    var floatUtility = (0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n      .float".concat(infix, "-left {\n        ").concat((0, float_1.floatLeft)(), "\n      }\n      .float").concat(infix, "-right {\n        ").concat((0, float_1.floatRight)(), "\n      }\n      .float").concat(infix, "-none {\n        ").concat((0, float_1.floatNone)(), "\n      }\n    "));
    floatUtilityList.push(floatUtility);
  });
  return floatUtilityList.join('\n');
}
var _default = {
  defaultProps: defaultProps,
  getFloatUtilities: getFloatUtilities
};
exports.default = _default;
});
unwrapExports(float_1$1);
var float_2$1 = float_1$1.getFloatUtilities;
var float_3$1 = float_1$1.defaultProps;

var position = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPositionUtilities = getPositionUtilities;
exports.fixedTop = fixedTop;
exports.fixedBottom = fixedBottom;
exports.stickTop = stickTop;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$zindex-fixed': '1030',
  '$zindex-sticky': '1030'
};
exports.defaultProps = defaultProps;
function getPositionUtilities() {
  var zindexFixed = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$zindex-fixed'];
  var zindexSticky = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$zindex-sticky'];
  return "\n    ".concat(fixedTop(zindexFixed), "\n    ").concat(fixedBottom(zindexFixed), "\n    ").concat(stickTop(zindexSticky), "\n  ");
}
function fixedTop() {
  var zindexFixed = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$zindex-fixed'];
  return "\n  .fixed-top {\n    position: fixed !important;\n    top: 0;\n    right: 0;\n    left: 0;\n    z-index: ".concat(zindexFixed, ";\n  }\n  ");
}
function fixedBottom() {
  var zindexFixed = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$zindex-fixed'];
  return "\n    .fixed-bottom {\n      position: fixed !important;\n      right: 0;\n      bottom: 0;\n      left: 0;\n      z-index: ".concat(zindexFixed, ";\n    }\n  ");
}
function stickTop() {
  var zindexSticky = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$zindex-sticky'];
  return "\n    .sticky-top {\n      position: sticky !important;\n      top: 0;\n      z-index: ".concat(zindexSticky, ";\n    }\n  ");
}
var _default = {
  defaultProps: defaultProps,
  getPositionUtilities: getPositionUtilities,
  fixedTop: fixedTop,
  fixedBottom: fixedBottom,
  stickTop: stickTop
};
exports.default = _default;
});
unwrapExports(position);
var position_1 = position.getPositionUtilities;
var position_2 = position.fixedTop;
var position_3 = position.fixedBottom;
var position_4 = position.stickTop;
var position_5 = position.defaultProps;

var reboot = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getGlobalStyles = getGlobalStyles;
exports.getGlobalStyleNoBootstrapProvider = getGlobalStyleNoBootstrapProvider;
exports.html = html;
exports.boxSizing = boxSizing;
exports.ie10FixViewport = ie10FixViewport;
exports.body = body;
exports.bodyUtils = bodyUtils;
exports.tabIndex = tabIndex;
exports.svg = svg;
exports.ie10FixHidden = ie10FixHidden;
exports.webkitFileUploadButton = webkitFileUploadButton;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$font-family-base': '-apple-system, system-ui, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif',
  '$font-size-base': '1rem',
  '$font-weight-base': '1.5',
  '$line-height-base': '1.5',
  '$body-color': '#292b2c',
  '$body-bg': '#fff'
};
exports.defaultProps = defaultProps;
function getGlobalStyles() {
  return "\n    html {\n      ".concat(html(), "\n    }\n    *,\n    *::before,\n    *::after {\n      ").concat(boxSizing(), "\n    }\n    @-ms-viewport { \n      ").concat(ie10FixViewport(), " \n    }\n    body {\n      ").concat(bodyUtils(), "\n    }\n  ");
}
function getGlobalStyleNoBootstrapProvider() {
  var fontFamilyBase = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$font-family-base'];
  var fontSizeBase = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$font-size-base'];
  var fontWeightBase = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$font-weight-base'];
  var lineHeightBase = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$line-height-base'];
  var bodyColor = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$body-color'];
  var bodyBg = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$body-bg'];
  return "\n  ".concat(getGlobalStyles(), "\n  body {\n  ").concat(body(fontFamilyBase, fontSizeBase, fontWeightBase, lineHeightBase, bodyColor, bodyBg), " \n}");
}
function html() {
  return "\n    box-sizing: border-box;\n    font-family: sans-serif;\n    line-height: 1.15;\n    -ms-text-size-adjust: 100%;\n    -webkit-text-size-adjust: 100%;\n    -ms-overflow-style: scrollbar;\n    -webkit-tap-highlight-color: rgba(0,0,0,0);\n  ";
}
function boxSizing() {
  return "\n    box-sizing: inherit;\n  ";
}
function ie10FixViewport() {
  return "\n    width: device-width;\n  ";
}
function body() {
  var fontFamilyBase = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$font-family-base'];
  var fontSizeBase = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$font-size-base'];
  var fontWeightBase = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$font-weight-base'];
  var lineHeightBase = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$line-height-base'];
  var bodyColor = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$body-color'];
  var bodyBg = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$body-bg'];
  return "\n    margin: 0;\n    font-family: ".concat(fontFamilyBase, ";\n    font-size: ").concat(fontSizeBase, ";\n    font-weight: ").concat(fontWeightBase, ";\n    line-height: ").concat(lineHeightBase, ";\n    color: ").concat(bodyColor, ";\n    background-color: ").concat(bodyBg, ";\n    \n    ").concat(bodyUtils(), "\n    \n    [tabindex=\"-1\"]:focus {\n      ").concat(tabIndex(), "\n    }\n    svg:not(:root) {\n      ").concat(svg(), "\n    }\n    [hidden] {\n      ").concat(ie10FixHidden(), "\n    }\n    ::-webkit-file-upload-button {\n      ").concat(webkitFileUploadButton(), "\n    }\n  ");
}
function bodyUtils() {
  return "\n    &.overflow {\n      overflow: hidden;\n    }\n  ";
}
function tabIndex() {
  return "\n    outline: none !important;\n  ";
}
function svg() {
  return "\n    overflow: hidden;\n  ";
}
function ie10FixHidden() {
  return "\n    display: none !important;\n  ";
}
function webkitFileUploadButton() {
  return "\n    font: inherit;\n    -webkit-appearance: button;\n  ";
}
var _default = {
  html: html,
  boxSizing: boxSizing,
  ie10FixViewport: ie10FixViewport,
  body: body,
  bodyUtils: bodyUtils,
  tabIndex: tabIndex,
  svg: svg,
  ie10FixHidden: ie10FixHidden,
  getGlobalStyles: getGlobalStyles,
  getGlobalStyleNoBootstrapProvider: getGlobalStyleNoBootstrapProvider,
  webkitFileUploadButton: webkitFileUploadButton
};
exports.default = _default;
});
unwrapExports(reboot);
var reboot_1 = reboot.getGlobalStyles;
var reboot_2 = reboot.getGlobalStyleNoBootstrapProvider;
var reboot_3 = reboot.html;
var reboot_4 = reboot.boxSizing;
var reboot_5 = reboot.ie10FixViewport;
var reboot_6 = reboot.body;
var reboot_7 = reboot.bodyUtils;
var reboot_8 = reboot.tabIndex;
var reboot_9 = reboot.svg;
var reboot_10 = reboot.ie10FixHidden;
var reboot_11 = reboot.webkitFileUploadButton;
var reboot_12 = reboot.defaultProps;

var screenReader = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.srOnly = srOnly;
exports.srOnlyFocusable = srOnlyFocusable;
exports.default = void 0;
function srOnly() {
  return "\n    position: absolute !important;\n    width: 1px;\n    height: 1px;\n    padding: 0;\n    margin: -1px;\n    overflow: hidden;\n    clip: rect(0,0,0,0);\n    border: 0;\n  ";
}
function srOnlyFocusable() {
  return "\n    &:active,\n    &:focus {\n      position: static;\n      width: auto;\n      height: auto;\n      margin: 0;\n      overflow: visible;\n      clip: auto;\n    }\n  ";
}
var _default = {
  srOnly: srOnly,
  srOnlyFocusable: srOnlyFocusable
};
exports.default = _default;
});
unwrapExports(screenReader);
var screenReader_1 = screenReader.srOnly;
var screenReader_2 = screenReader.srOnlyFocusable;

var screenreaders = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getScreenReadersUtilities = getScreenReadersUtilities;
exports.default = void 0;
function getScreenReadersUtilities() {
  return "\n    .sr-only {\n      ".concat((0, screenReader.srOnly)(), "\n    }\n    \n    .sr-only-focusable {\n      ").concat((0, screenReader.srOnlyFocusable)(), "\n    }\n  ");
}
var _default = {
  getScreenReadersUtilities: getScreenReadersUtilities
};
exports.default = _default;
});
unwrapExports(screenreaders);
var screenreaders_1 = screenreaders.getScreenReadersUtilities;

var sizing = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSizingUtilities = getSizingUtilities;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  $sizes: {
    25: '25%',
    50: '50%',
    75: '75%',
    100: '100%'
  }
};
exports.defaultProps = defaultProps;
function getSizingUtilities() {
  var sizes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$sizes'];
  var abbrev = {
    width: 'w',
    height: 'h'
  };
  var sizingList = [];
  Object.keys(abbrev).forEach(function (cssProp) {
    Object.keys(sizes).forEach(function (size) {
      sizingList.push("\n        .".concat(abbrev[cssProp], "-").concat(size, " { ").concat(cssProp, ": ").concat(sizes[size], " !important; }\n      "));
    });
  });
  return "\n    ".concat(sizingList.join('\n'), "\n    .mw-100 { max-width: 100% !important; }\n    .mh-100 { max-height: 100% !important; }\n  ");
}
var _default = {
  defaultProps: defaultProps,
  getSizingUtilities: getSizingUtilities
};
exports.default = _default;
});
unwrapExports(sizing);
var sizing_1 = sizing.getSizingUtilities;
var sizing_2 = sizing.defaultProps;

var spacing = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSpacingUtilities = getSpacingUtilities;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  },
  '$spacers': {
    0: {
      x: 0,
      y: 0
    },
    1: {
      x: '0.25rem',
      y: '0.25rem'
    },
    2: {
      x: '0.5rem',
      y: '0.5rem'
    },
    3: {
      x: '1rem',
      y: '1rem'
    },
    4: {
      x: '1.5rem',
      y: '1.5rem'
    },
    5: {
      x: '3rem',
      y: '3rem'
    }
  }
};
exports.defaultProps = defaultProps;
function getSpacingUtilities()
{
  var gridBreakpoints = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-breakpoints'];
  var spacers = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$spacers'];
  var abbrevs = {
    margin: 'm',
    padding: 'p'
  };
  var spacingUtilityList = [];
  var infixList = [];
  Object.keys(gridBreakpoints).forEach(function (breakpoint) {
    var infix = (0, breakpoints.breakpointInfix)(breakpoint, gridBreakpoints);
    infixList.push(infix);
    Object.keys(abbrevs).forEach(function (prop) {
      var abbrev = abbrevs[prop];
      Object.keys(spacers).forEach(function (size) {
        var lengths = spacers[size];
        spacingUtilityList.push((0, breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n          .".concat(abbrev).concat(infix, "-").concat(size, " { ").concat(prop, ":        ").concat(lengths.y, " ").concat(lengths.x, " !important; } /* a = All sides */\n          .").concat(abbrev, "t").concat(infix, "-").concat(size, " { ").concat(prop, "-top:    ").concat(lengths.y, " !important; }\n          .").concat(abbrev, "r").concat(infix, "-").concat(size, " { ").concat(prop, "-right:  ").concat(lengths.x, " !important; }\n          .").concat(abbrev, "b").concat(infix, "-").concat(size, " { ").concat(prop, "-bottom: ").concat(lengths.y, " !important; }\n          .").concat(abbrev, "l").concat(infix, "-").concat(size, " { ").concat(prop, "-left:   ").concat(lengths.x, " !important; }\n          .").concat(abbrev, "x").concat(infix, "-").concat(size, " {\n            ").concat(prop, "-right:  ").concat(lengths.x, " !important;\n            ").concat(prop, "-left:   ").concat(lengths.x, " !important;\n          }\n          .").concat(abbrev, "y").concat(infix, "-").concat(size, " {\n            ").concat(prop, "-top:    ").concat(lengths.y, " !important;\n            ").concat(prop, "-bottom: ").concat(lengths.y, " !important;\n          }\n        ")));
      });
    });
  });
  var infixUtilityList = infixList.map(function (infix) {
    return "\n    .m".concat(infix, "-auto  { margin:        auto !important; }\n    .mt").concat(infix, "-auto { margin-top:    auto !important; }\n    .mr").concat(infix, "-auto { margin-right:  auto !important; }\n    .mb").concat(infix, "-auto { margin-bottom: auto !important; }\n    .ml").concat(infix, "-auto { margin-left:   auto !important; }\n    .mx").concat(infix, "-auto {\n      margin-right: auto !important;\n      margin-left:  auto !important;\n    }\n    .my").concat(infix, "-auto {\n      margin-top:    auto !important;\n      margin-bottom: auto !important;\n    }\n  ");
  });
  return "\n    ".concat(infixUtilityList.join('\n'), "\n    ").concat(spacingUtilityList.join('\n'), "\n  ");
}
var _default = {
  defaultProps: defaultProps,
  getSpacingUtilities: getSpacingUtilities
};
exports.default = _default;
});
unwrapExports(spacing);
var spacing_1 = spacing.getSpacingUtilities;
var spacing_2 = spacing.defaultProps;

var textTruncate_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.textTruncate = textTruncate;
exports.default = void 0;
function textTruncate() {
  return "\n    overflow: hidden;\n    text-overflow: ellipsis;\n    white-space: nowrap;\n  ";
}
var _default = {
  textTruncate: textTruncate
};
exports.default = _default;
});
unwrapExports(textTruncate_1);
var textTruncate_2 = textTruncate_1.textTruncate;

var textHide_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.textHide = textHide;
exports.default = void 0;
function textHide() {
  return "\n    font: 0/0 a;\n    color: transparent;\n    text-shadow: none;\n    background-color: transparent;\n    border: 0;\n  ";
}
var _default = {
  textHide: textHide
};
exports.default = _default;
});
unwrapExports(textHide_1);
var textHide_2 = textHide_1.textHide;

var textEmphasis = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.textEmphasisVariant = textEmphasisVariant;
exports.default = exports.defaultProps = void 0;
var _color = _interopRequireDefault(ColorWrapper);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var defaultProps = {
  '$enable-hover-media-query': false
};
exports.defaultProps = defaultProps;
function textEmphasisVariant() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var parent = arguments.length > 1 ? arguments[1] : undefined;
  var textColor = arguments.length > 2 ? arguments[2] : undefined;
  return "\n  ".concat(parent, " {\n    color: ").concat(textColor, " !important;\n  }\n  a").concat(parent, " {\n  ").concat((0, hover_1.hoverFocus)(enableHoverMediaQuery, "color: ".concat((0, _color.default)(textColor).darken(0.20).rgb(), " !important;")), "\n  }\n");
}
var _default = {
  defaultProps: defaultProps,
  textEmphasisVariant: textEmphasisVariant
};
exports.default = _default;
});
unwrapExports(textEmphasis);
var textEmphasis_1 = textEmphasis.textEmphasisVariant;
var textEmphasis_2 = textEmphasis.defaultProps;

var text = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTextUtilities = getTextUtilities;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  },
  '$enable-hover-media-query': false,
  '$font-weight-normal': 'normal',
  '$font-weight-bold': 'bold',
  '$text-muted': '#818a91',
  '$brand-primary': '#0275d8',
  '$brand-success': '#5cb85c',
  '$brand-info': '#5bc0de',
  '$brand-warning': '#f0ad4e',
  '$brand-danger': '#d9534f',
  '$gray-dark': '#373a3c'
};
exports.defaultProps = defaultProps;
function getTextUtilities() {
  var enableHoverMediaQuery = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-hover-media-query'];
  var gridBreakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var fontWeightNormal = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$font-weight-normal'];
  var fontWeightBold = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultProps['$font-weight-bold'];
  var textMuted = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : defaultProps['$text-muted'];
  var brandPrimary = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : defaultProps['$brand-primary'];
  var brandSuccess = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : defaultProps['$brand-success'];
  var brandInfo = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : defaultProps['$brand-info'];
  var brandWarning = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : defaultProps['$brand-warning'];
  var brandDanger = arguments.length > 9 && arguments[9] !== undefined ? arguments[9] : defaultProps['$brand-danger'];
  var grayDark = arguments.length > 10 && arguments[10] !== undefined ? arguments[10] : defaultProps['$gray-dark'];
  var responseAlignmentList = [];
  Object.keys(gridBreakpoints).forEach(function (bp) {
    var infix = (0, breakpoints.breakpointInfix)(bp, gridBreakpoints);
    var responsiveAlignement = (0, breakpoints.mediaBreakpointUp)(bp, gridBreakpoints, "\n      .text".concat(infix, "-left { text-align: left !important; }\n      .text").concat(infix, "-right  { text-align: right !important; }\n      .text").concat(infix, "-center { text-align: center !important; }\n    "));
    responseAlignmentList.push(responsiveAlignement);
  });
  return "\n    /* Text */\n\n    /* Alignment */\n\n    .text-justify        { text-align: justify !important; }\n    .text-nowrap         { white-space: nowrap !important; }\n    .text-truncate       { ".concat((0, textTruncate_1.textTruncate)(), " }\n\n    /* Responsive alignment */\n\n    ").concat(responseAlignmentList.join('\n'), "\n\n    /* Transformation */\n\n    .text-lowercase      { text-transform: lowercase !important; }\n    .text-uppercase      { text-transform: uppercase !important; }\n    .text-capitalize     { text-transform: capitalize !important; }\n\n    /* Weight and italics */\n\n    .font-weight-normal  { font-weight: ").concat(fontWeightNormal, "; }\n    .font-weight-bold    { font-weight: ").concat(fontWeightBold, "; }\n    .font-italic         { font-style: italic; }\n\n    /* Contextual colors */\n\n    .text-white {\n      color: #fff !important;\n    }\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-muted', textMuted), "\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-primary', brandPrimary), "\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-success', brandSuccess), "\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-info', brandInfo), "\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-warning', brandWarning), "\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-danger', brandDanger), "\n\n    /* Font color */\n\n    ").concat((0, textEmphasis.textEmphasisVariant)(enableHoverMediaQuery, '.text-gray-dark', grayDark), "\n\n    /* Misc */\n\n    .text-hide {\n      ").concat((0, textHide_1.textHide)(), "\n    }\n\n  ");
}
var _default = {
  defaultProps: defaultProps,
  getTextUtilities: getTextUtilities
};
exports.default = _default;
});
unwrapExports(text);
var text_1 = text.getTextUtilities;
var text_2 = text.defaultProps;

var parseTransition_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var parseTransition = function parseTransition(transitions) {
  if (!transitions) {
    return [];
  }
  var sample = transitions;
  var RULE_DELIMITER = ',';
  var PROPERTY_DELIMITER = ' ';
  var MS_UNIT = 'ms';
  var TMP_STR = 'TMP';
  var DEFAULT_PROPERTY = 'all';
  var DEFAULT_DURATION = 0;
  var DEFAULT_TIMING_FUNCTION = 'ease';
  var DEFAULT_DELAY = 0;
  var BEZIER_REGEX = /cubic-bezier\([^\)]+\)/gi;
  var cubicBezierList = transitions.match(BEZIER_REGEX);
  if (cubicBezierList) {
    sample = sample.replace(BEZIER_REGEX, TMP_STR);
  }
  var transitionList = sample.split(RULE_DELIMITER).map(function (rule) {
    var properties = rule.trim().split(PROPERTY_DELIMITER);
    return {
      property: properties[0] || DEFAULT_PROPERTY,
      duration: properties[1] && !(properties[1].indexOf(MS_UNIT) !== -1) ? parseFloat(properties[1]) * 1000 : parseFloat(properties[1]) || DEFAULT_DURATION,
      timingFunction: properties[2] && properties[2] !== TMP_STR ? properties[2] : cubicBezierList ? cubicBezierList.shift() : DEFAULT_TIMING_FUNCTION,
      delay: properties[3] && !(properties[3].indexOf(MS_UNIT) !== -1) ? parseFloat(properties[3]) * 1000 : parseFloat(properties[3]) || DEFAULT_DELAY
    };
  });
  return transitionList;
};
var _default = parseTransition;
exports.default = _default;
module.exports = exports.default;
});
unwrapExports(parseTransition_1);

var transition_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.transition = transition;
exports.default = exports.defaultProps = void 0;
var defaultProps = {
  '$enable-transitions': true
};
exports.defaultProps = defaultProps;
function transition() {
  var enableTransitions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-transitions'];
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }
  if (enableTransitions && args.length) {
    return "\n      transition: ".concat(args.join(' '), ";\n    ");
  }
  return '';
}
var _default = {
  transition: transition
};
exports.default = _default;
});
unwrapExports(transition_1);
var transition_2 = transition_1.transition;
var transition_3 = transition_1.defaultProps;

var transition$1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTransitionUtilities = getTransitionUtilities;
exports.fade = fade;
exports.collapse = collapse;
exports.getReactTransition = getReactTransition;
exports.default = exports.defaultProps = void 0;
var _parseTransition = _interopRequireDefault(parseTransition_1);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var defaultProps = {
  '$enable-transitions': true,
  '$transition-fade': 'opacity .15s linear',
  '$transition-collapse': 'height .35s ease'
};
exports.defaultProps = defaultProps;
function getTransitionUtilities() {
  var enableTransitions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-transitions'];
  var transitionFade = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$transition-fade'];
  var transitionCollapse = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$transition-collapse'];
  return "\n    ".concat(fade(enableTransitions, transitionFade), "\n    ").concat(collapse(enableTransitions, transitionCollapse), "\n  ");
}
function fade() {
  var enableTransitions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-transitions'];
  var transitionFade = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$transition-fade'];
  return "\n    .fade,\n     &.fade {\n      opacity: 0;\n      ".concat((0, transition_1.transition)(enableTransitions, transitionFade), "\n    \n      &.show {\n        opacity: 1;\n      }\n    }\n  ");
}
function collapse() {
  var enableTransitions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-transitions'];
  var transitionCollapse = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$transition-collapse'];
  return "\n    .collapse {\n      display: none;\n      &.show {\n        display: block;\n      }\n    }\n    \n    tr {\n      &.collapse.show {\n        display: table-row;\n      }\n    }\n    \n    tbody {\n      &.collapse.show {\n        display: table-row-group;\n      }\n    }\n    \n    .collapsing {\n      position: relative;\n      height: 0;\n      overflow: hidden;\n      ".concat((0, transition_1.transition)(enableTransitions, transitionCollapse), "\n    }\n  ");
}
function getReactTransition(enableTransition, transition) {
  var transitionList = (0, _parseTransition.default)(transition);
  var _transitionList$ = transitionList[0],
      property = _transitionList$.property,
      duration = _transitionList$.duration,
      timingFunction = _transitionList$.timingFunction,
      delay = _transitionList$.delay;
  return (0, transition_1.transition)(enableTransition, "".concat(property, " ").concat(duration, "ms ").concat(timingFunction, " ").concat(delay, "ms"));
}
var _default = {
  defaultProps: defaultProps,
  getTransitionUtilities: getTransitionUtilities,
  getReactTransition: getReactTransition,
  fade: fade,
  collapse: collapse
};
exports.default = _default;
});
unwrapExports(transition$1);
var transition_1$1 = transition$1.getTransitionUtilities;
var transition_2$1 = transition$1.fade;
var transition_3$1 = transition$1.collapse;
var transition_4 = transition$1.getReactTransition;
var transition_5 = transition$1.defaultProps;

var visibility = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.invisible = invisible;
exports.default = void 0;
function invisible(visibility) {
  return "\n    visibility: ".concat(visibility, " !important;\n  ");
}
var _default = {
  invisible: invisible
};
exports.default = _default;
});
unwrapExports(visibility);
var visibility_1 = visibility.invisible;

var visibility$2 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getVisibilityUtilities = getVisibilityUtilities;
exports.default = void 0;
function getVisibilityUtilities() {
  return "\n    .visible {\n      ".concat((0, visibility.invisible)('visible'), "\n    }\n    \n    .invisible {\n      ").concat((0, visibility.invisible)('hidden'), "\n    }\n   \n  ");
}
var _default = {
  getVisibilityUtilities: getVisibilityUtilities
};
exports.default = _default;
});
unwrapExports(visibility$2);
var visibility_1$1 = visibility$2.getVisibilityUtilities;

var utils = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.allowFalseValue = allowFalseValue;
exports.assertAscending = assertAscending;
exports.assertStartAtZero = assertStartAtZero;
exports.comparable = comparable;
exports.default = void 0;
var _unitUtils = _interopRequireDefault(unitUtils);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function allowFalseValue(userValue, defaultValue) {
  return userValue === false ? userValue : userValue || defaultValue;
}
function assertAscending(map, mapName) {
  var prevKey;
  var prevNum;
  var asserted = true;
  Object.keys(map).forEach(function (key) {
    var num = map[key];
    if (prevNum == null) ; else if (!comparable(_unitUtils.default.rmUnit(prevNum), _unitUtils.default.rmUnit(num))) {
      {
        console.warn("Potentially invalid value for ".concat(mapName, ": This map must be in ascending order, but key '").concat(key, "' has value ").concat(num, " whose unit makes it incomparable to ").concat(prevNum, ", the value of the previous key '").concat(prevKey, "' !"));
      }
      asserted = false;
    } else if (_unitUtils.default.rmUnit(prevNum) >= _unitUtils.default.rmUnit(num)) {
      {
        console.warn("Invalid value for ".concat(mapName, ": This map must be in ascending order, but key '").concat(key, "' has value ").concat(num, " which isn't greater than ").concat(prevNum, ", the value of the previous key '").concat(prevKey, "' !"));
      }
      asserted = false;
    }
    prevKey = key;
    prevNum = num;
  });
  return asserted;
}
function assertStartAtZero(map) {
  var values = Object.keys(map).map(function (key) {
    return map[key];
  });
  var firstValue = _unitUtils.default.rmUnit(values[0]);
  var asserted = true;
  if (firstValue !== 0) {
    {
      console.warn("First breakpoint in $grid-breakpoints must start at 0, but starts at ".concat(firstValue, "."));
    }
    asserted = false;
  }
  return asserted;
}
function comparable(a, b) {
  return !isNaN(a + b);
}
var _default = {
  assertAscending: assertAscending,
  assertStartAtZero: assertStartAtZero,
  comparable: comparable
};
exports.default = _default;
});
unwrapExports(utils);
var utils_1 = utils.allowFalseValue;
var utils_2 = utils.assertAscending;
var utils_3 = utils.assertStartAtZero;
var utils_4 = utils.comparable;

var regex = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.linearGradientRe = void 0;
var linearGradientRe = /#[0-9a-fA-F]{3,6}|rgb ?\([ 0-9.%,]+?\)/g;
exports.linearGradientRe = linearGradientRe;
});
unwrapExports(regex);
var regex_1 = regex.linearGradientRe;

var theme = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.makeTheme = void 0;
var _color = _interopRequireDefault(ColorWrapper);
var _unitUtils = _interopRequireDefault(unitUtils);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var detectUnit = _unitUtils.default.detectUnit,
    rmUnit = _unitUtils.default.rmUnit;
function makeOriginal() {
  var userTheme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var v = {};
  var u = userTheme;
  var detectedUnit;
  v._name = u._name || 'bootstrap-styled';
  v['$white'] = u['$white'] || '#fff';
  v['$black'] = u['$black'] || '#000';
  v['$red'] = u['$red'] || '#d9534f';
  v['$orange'] = u['$orange'] || '#f0ad4e';
  v['$yellow'] = u['$yellow'] || '#ffd500';
  v['$green'] = u['$green'] || '#5cb85c';
  v['$blue'] = u['$blue'] || '#0275d8';
  v['$teal'] = u['$teal'] || '#5bc0de';
  v['$pink'] = u['$pink'] || '#ff5b77';
  v['$purple'] = u['$purple'] || '#613d7c';
  v['$gray-dark'] = u['$gray-dark'] || '#292b2c';
  v['$gray'] = u['$gray'] || '#464a4c';
  v['$gray-light'] = u['$gray-light'] || '#636c72';
  v['$gray-lighter'] = u['$gray-lighter'] || '#eceeef';
  v['$gray-lightest'] = u['$gray-lightest'] || '#f7f7f9';
  v['$brand-primary'] = u['$brand-primary'] || v['$blue'];
  v['$brand-success'] = u['$brand-success'] || v['$green'];
  v['$brand-info'] = u['$brand-info'] || v['$teal'];
  v['$brand-warning'] = u['$brand-warning'] || v['$orange'];
  v['$brand-danger'] = u['$brand-danger'] || v['$red'];
  v['$brand-inverse'] = u['$brand-inverse'] || v['$gray-dark'];
  v['$enable-rounded'] = (0, utils.allowFalseValue)(u['$enable-rounded'], true);
  v['$enable-shadows'] = (0, utils.allowFalseValue)(u['$enable-shadows'], false);
  v['$enable-gradients'] = (0, utils.allowFalseValue)(u['$enable-gradients'], false);
  v['$enable-transitions'] = (0, utils.allowFalseValue)(u['$enable-transitions'], true);
  v['$enable-hover-media-query'] = (0, utils.allowFalseValue)(u['$enable-hover-media-query'], false);
  v['$enable-grid-classes'] = (0, utils.allowFalseValue)(u['$enable-grid-classes'], true);
  v['$enable-print-styles'] = (0, utils.allowFalseValue)(u['$enable-print-styles'], true);
  v['$spacer'] = u['$spacer'] || '1rem';
  detectedUnit = detectUnit(v['$spacer']);
  v['$spacer-halved'] = u['$spacer-halved'] || rmUnit(v['$spacer'], detectedUnit) / 2 + detectedUnit;
  v['$spacer-x'] = u['$spacer-x'] || v['$spacer'];
  v['$spacer-y'] = u['$spacer-y'] || v['$spacer'];
  v['$spacers'] = u['$spacers'] || {
    0: {
      x: 0,
      y: 0
    },
    1: {
      x: rmUnit(v['$spacer-x']) * 0.25 + detectedUnit,
      y: rmUnit(v['$spacer-y']) * 0.25 + detectedUnit
    },
    2: {
      x: rmUnit(v['$spacer-x']) * 0.5 + detectedUnit,
      y: rmUnit(v['$spacer-y']) * 0.5 + detectedUnit
    },
    3: {
      x: v['$spacer-x'],
      y: v['$spacer-y']
    },
    4: {
      x: rmUnit(v['$spacer-x']) * 1.5 + detectedUnit,
      y: rmUnit(v['$spacer-y']) * 1.5 + detectedUnit
    },
    5: {
      x: rmUnit(v['$spacer-x']) * 3 + detectedUnit,
      y: rmUnit(v['$spacer-y']) * 3 + detectedUnit
    }
  };
  v['$border-width'] = u['$border-width'] || '1px';
  v['$sizes'] = u['$sizes'] || {
    25: '25%',
    50: '50%',
    75: '75%',
    100: '100%'
  };
  v['$body-bg'] = u['$body-bg'] || v['$white'];
  v['$body-color'] = u['$body-color'] || v['$gray-dark'];
  v['$link-color'] = u['$link-color'] || v['$brand-primary'];
  v['$link-decoration'] = u['$link-decoration'] || 'none';
  v['$link-hover-color'] = u['$link-hover-color'] || (0, _color.default)(v['$link-color']).darken(0.35).toString();
  v['$link-hover-decoration'] = u['$link-hover-decoration'] || 'underline';
  v['$grid-breakpoints'] = u['$grid-breakpoints'] || {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px',
    xxl: '1452px'
  };
  (0, utils.assertAscending)(v['$grid-breakpoints'], '$grid-breakpoints');
  (0, utils.assertStartAtZero)(v['$grid-breakpoints']);
  v['$container-max-widths'] = u['$container-max-widths'] || {
    sm: '540px',
    md: '720px',
    lg: '960px',
    xl: '1140px'
  };
  (0, utils.assertAscending)(v['$container-max-widths'], '$container-max-widths');
  v['$grid-columns'] = u['$grid-columns'] || '12';
  v['$grid-gutter-width'] = u['$grid-gutter-width'] || '30px';
  v['$font-family-sans-serif'] = u['$font-family-sans-serif'] || '-apple-system, system-ui, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, sans-serif';
  v['$font-family-monospace'] = u['$font-family-monospace'] || 'Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace';
  v['$font-family-base'] = u['$font-family-base'] || v['$font-family-sans-serif'];
  v['$font-size-base'] = u['$font-size-base'] || '1rem';
  v['$font-size-lg'] = u['$font-size-lg'] || '1.25rem';
  v['$font-size-sm'] = u['$font-size-sm'] || '.875rem';
  v['$font-size-xs'] = u['$font-size-xs'] || '.75rem';
  v['$font-weight-normal'] = u['$font-weight-normal'] || 'normal';
  v['$font-weight-bold'] = u['$font-weight-bold'] || 'bold';
  v['$font-weight-base'] = u['$font-weight-base'] || v['$font-weight-normal'];
  v['$line-height-base'] = u['$line-height-base'] || '1.5';
  v['$font-size-h1'] = u['$font-size-h1'] || '2.5rem';
  v['$font-size-h2'] = u['$font-size-h2'] || '2rem';
  v['$font-size-h3'] = u['$font-size-h3'] || '1.75rem';
  v['$font-size-h4'] = u['$font-size-h4'] || '1.5rem';
  v['$font-size-h5'] = u['$font-size-h5'] || '1.25rem';
  v['$font-size-h6'] = u['$font-size-h6'] || '1rem';
  detectedUnit = detectUnit(v['$spacer']);
  v['$headings-margin-bottom'] = u['$headings-margin-bottom'] || rmUnit(v['$spacer'], detectedUnit) / 2 + detectedUnit;
  v['$headings-font-family'] = u['$headings-font-family'] || 'inherit';
  v['$headings-font-weight'] = u['$headings-font-weight'] || '500';
  v['$headings-line-height'] = u['$headings-line-height'] || '1.1';
  v['$headings-color'] = u['$headings-color'] || 'inherit';
  v['$display1-size'] = u['$display1-size'] || '6rem';
  v['$display2-size'] = u['$display2-size'] || '5.5rem';
  v['$display3-size'] = u['$display3-size'] || '4.5rem';
  v['$display4-size'] = u['$display4-size'] || '3.5rem';
  v['$display1-weight'] = u['$display1-weight'] || '300';
  v['$display2-weight'] = u['$display2-weight'] || '300';
  v['$display3-weight'] = u['$display3-weight'] || '300';
  v['$display4-weight'] = u['$display4-weight'] || '300';
  v['$display-line-height'] = u['$display-line-height'] || v['$headings-line-height'];
  v['$lead-font-size'] = u['$lead-font-size'] || '1.25rem';
  v['$lead-font-weight'] = u['$lead-font-weight'] || '300';
  v['$small-font-size'] = u['$small-font-size'] || '80%';
  v['$text-muted'] = u['$text-muted'] || v['$gray-light'];
  v['$blockquote-small-color'] = u['$blockquote-small-color'] || v['$gray-light'];
  detectedUnit = detectUnit(v['$font-size-base']);
  v['$blockquote-font-size'] = u['$blockquote-font-size'] || rmUnit(v['$font-size-base'], detectedUnit) * 1.25 + detectedUnit;
  v['$blockquote-border-color'] = u['$blockquote-border-color'] || v['$gray-lighter'];
  v['$blockquote-border-width'] = u['$blockquote-border-width'] || '.25rem';
  v['$hr-border-color'] = u['$hr-border-color'] || (0, _color.default)(v['$black']).alpha(0.1).toString();
  v['$hr-border-width'] = u['$hr-border-width'] || v['$border-width'];
  v['$mark-padding'] = u['$mark-padding'] || '.2em';
  v['$dt-font-weight'] = u['$dt-font-weight'] || v['$font-weight-bold'];
  v['$list-inline-padding'] = u['$list-inline-padding'] || '5px';
  v['$line-height-lg'] = u['$line-height-lg'] || '1.6';
  v['$line-height-sm'] = u['$line-height-sm'] || '1.3';
  v['$border-radius'] = u['$border-radius'] || '.25rem';
  v['$border-radius-lg'] = u['$border-radius-lg'] || '.3rem';
  v['$border-radius-sm'] = u['$border-radius-sm'] || '.2rem';
  v['$component-active-color'] = u['$component-active-color'] || v['$white'];
  v['$component-active-bg'] = u['$component-active-bg'] || v['$brand-primary'];
  v['$caret-width'] = u['$caret-width'] || '.3em';
  v['$transition-base'] = u['$transition-base'] || 'all .2s ease-in-out';
  v['$transition-fade'] = u['$transition-fade'] || 'opacity .15s linear';
  v['$transition-collapse'] = u['$transition-collapse'] || 'height .35s ease';
  v['$table-cell-padding'] = u['$table-cell-padding'] || '.75rem';
  v['$table-sm-cell-padding'] = u['$table-sm-cell-padding'] || '.3rem';
  v['$table-bg'] = u['$table-bg'] || 'transparent';
  v['$table-inverse-bg'] = u['$table-inverse-bg'] || v['$gray-dark'];
  v['$table-inverse-bg-accent'] = u['$table-inverse-bg-accent'] || (0, _color.default)(v['$white']).alpha(0.05).toString();
  v['$table-inverse-bg-hover'] = u['$table-inverse-bg-hover'] || (0, _color.default)(v['$white']).alpha(0.075).toString();
  v['$table-inverse-color'] = u['$table-inverse-color'] || v['$body-bg'];
  v['$table-inverse-border'] = u['$table-inverse-border'] || (0, _color.default)(v['$gray-dark']).lighten(0.075).toString();
  v['$table-bg-accent'] = u['$table-bg-accent'] || (0, _color.default)(v['$black']).alpha(0.05).toString();
  v['$table-bg-hover'] = u['$table-bg-hover'] || (0, _color.default)(v['$black']).alpha(0.075).toString();
  v['$table-bg-active'] = u['$table-bg-active'] || v['$table-bg-hover'];
  v['$table-head-bg'] = u['$table-head-bg'] || v['$gray-lighter'];
  v['$table-head-color'] = u['$table-head-color'] || v['$gray'];
  v['$table-border-width'] = u['$table-border-width'] || v['$border-width'];
  v['$table-border-color'] = u['$table-border-color'] || v['$gray-lighter'];
  v['$btn-padding-x'] = u['$btn-padding-x'] || '1rem';
  v['$btn-padding-y'] = u['$btn-padding-y'] || '.5rem';
  v['$btn-line-height'] = u['$btn-line-height'] || '1.25';
  v['$btn-font-weight'] = u['$btn-font-weight'] || v['$font-weight-normal'];
  v['$btn-box-shadow'] = u['$btn-box-shadow'] || "inset 0 1px 0 ".concat((0, _color.default)(v['$white']).alpha(0.15).toString(), ", 0 1px 1px ").concat((0, _color.default)(v['$black']).alpha(0.075).toString());
  v['$btn-focus-box-shadow'] = u['$btn-focus-box-shadow'] || "0 0 0 2px ".concat((0, _color.default)(v['$brand-primary']).alpha(0.25).toString());
  v['$btn-disabled-opacity'] = u['$btn-disabled-opacity'] || '.65';
  v['$btn-active-box-shadow'] = u['$btn-active-box-shadow'] || "inset 0 3px 5px ".concat((0, _color.default)(v['$black']).alpha(0.125).toString());
  v['$btn-primary-color'] = u['$btn-primary-color'] || v['$white'];
  v['$btn-primary-bg'] = u['$btn-primary-bg'] || v['$brand-primary'];
  v['$btn-secondary-color'] = u['$btn-secondary-color'] || v['$gray-dark'];
  v['$btn-secondary-bg'] = u['$btn-secondary-bg'] || v['$white'];
  v['$btn-info-color'] = u['$btn-info-color'] || v['$white'];
  v['$btn-info-bg'] = u['$btn-info-bg'] || v['$brand-info'];
  v['$btn-success-color'] = u['$btn-success-color'] || v['$white'];
  v['$btn-success-bg'] = u['$btn-success-bg'] || v['$brand-success'];
  v['$btn-warning-color'] = u['$btn-warning-color'] || v['$white'];
  v['$btn-warning-bg'] = u['$btn-warning-bg'] || v['$brand-warning'];
  v['$btn-danger-color'] = u['$btn-danger-color'] || v['$white'];
  v['$btn-danger-bg'] = u['$btn-danger-bg'] || v['$brand-danger'];
  ['primary', 'secondary', 'info', 'success', 'warning', 'danger'].forEach(function (type) {
    if (v["$btn-".concat(type, "-bg")].includes('linear-gradient')) {
      v["$btn-".concat(type, "-border")] = v["$btn-".concat(type, "-bg")].match(regex.linearGradientRe)[1];
    } else if (type === 'secondary') {
      v['$btn-secondary-border'] = u['$btn-secondary-border'] || '#ccc';
    } else {
      v["$btn-".concat(type, "-border")] = u["$btn-".concat(type, "-border")] || v["$btn-".concat(type, "-bg")];
    }
  });
  v['$btn-link-disabled-color'] = u['$btn-link-disabled-color'] || v['$gray-light'];
  v['$btn-padding-x-sm'] = u['$btn-padding-x-sm'] || '.5rem';
  v['$btn-padding-y-sm'] = u['$btn-padding-y-sm'] || '.25rem';
  v['$btn-padding-x-lg'] = u['$btn-padding-x-lg'] || '1.5rem';
  v['$btn-padding-y-lg'] = u['$btn-padding-y-lg'] || '.75rem';
  v['$btn-block-spacing-y'] = u['$btn-block-spacing-y'] || '.5rem';
  v['$btn-border-radius'] = u['$btn-border-radius'] || v['$border-radius'];
  v['$btn-border-radius-lg'] = u['$btn-border-radius-lg'] || v['$border-radius-lg'];
  v['$btn-border-radius-sm'] = u['$btn-border-radius-sm'] || v['$border-radius-sm'];
  v['$btn-transition'] = u['$btn-transition'] || v['$transition-base'];
  v['$input-padding-x'] = u['$input-padding-x'] || '.75rem';
  v['$input-padding-y'] = u['$input-padding-y'] || '.5rem';
  v['$input-line-height'] = u['$input-line-height'] || '1.25';
  v['$input-bg'] = u['$input-bg'] || v['$white'];
  v['$input-bg-disabled'] = u['$input-bg-disabled'] || v['$gray-lighter'];
  v['$input-color'] = u['$input-color'] || v['$gray'];
  v['$input-border-color'] = u['$input-border-color'] || (0, _color.default)(v['$black']).alpha(0.15).toString();
  v['$input-btn-border-width'] = u['$input-btn-border-width'] || v['$border-width'];
  v['$input-box-shadow'] = u['$input-box-shadow'] || "inset 0 1px 1px ".concat((0, _color.default)(v['$black']).alpha(0.075).toString());
  v['$input-border-radius'] = u['$input-border-radius'] || v['$border-radius'];
  v['$input-border-radius-lg'] = u['$input-border-radius-lg'] || v['$border-radius-lg'];
  v['$input-border-radius-sm'] = u['$input-border-radius-sm'] || v['$border-radius-sm'];
  v['$input-bg-focus'] = u['$input-bg-focus'] || v['$input-bg'];
  v['$input-border-focus'] = u['$input-border-focus'] || (0, _color.default)(v['$brand-primary']).lighten(0.25).toString();
  v['$input-box-shadow-focus'] = u['$input-box-shadow-focus'] || "".concat(v['$input-box-shadow'], ", 0 0 8px rgba(").concat(v['$input-border-focus'], ",.6)");
  v['$input-color-focus'] = u['$input-color-focus'] || v['$input-color'];
  v['$input-color-placeholder'] = u['$input-color-placeholder'] || v['$gray-light'];
  v['$input-padding-x-sm'] = u['$input-padding-x-sm'] || '.5rem';
  v['$input-padding-y-sm'] = u['$input-padding-y-sm'] || '.25rem';
  v['$input-padding-x-lg'] = u['$input-padding-x-lg'] || '1.5rem';
  v['$input-padding-y-lg'] = u['$input-padding-y-lg'] || '.75rem';
  detectedUnit = detectUnit(v['$font-size-base']);
  v['$input-height'] = u['$input-height'] || rmUnit(v['$font-size-base'], detectedUnit) * v['$line-height-base'] + rmUnit(v['$input-padding-y'], detectedUnit) * 2 + detectedUnit;
  v['$input-height-sm'] = u['$input-height-sm'] || rmUnit(v['$font-size-sm'], detectedUnit) * v['$line-height-sm'] + rmUnit(v['$input-padding-y-sm'], detectedUnit) * 2 + detectedUnit;
  v['$input-height-lg'] = u['$input-height-lg'] || rmUnit(v['$font-size-lg'], detectedUnit) * v['$line-height-lg'] + rmUnit(v['$input-padding-y-lg'], detectedUnit) * 2 + detectedUnit;
  v['$input-transition'] = u['$input-transition'] || 'border-color ease-in-out .15s, box-shadow ease-in-out .15s';
  v['$label-margin-bottom'] = u['$label-margin-bottom'] || '.5rem';
  v['$form-text-margin-top'] = u['$form-text-margin-top'] || '.25rem';
  v['$form-feedback-margin-top'] = u['$form-feedback-margin-top'] || v['$form-text-margin-top'];
  v['$form-check-margin-bottom'] = u['$form-check-margin-bottom'] || '.5rem';
  v['$form-check-input-gutter'] = u['$form-check-input-gutter'] || '1.25rem';
  v['$form-check-input-margin-y'] = u['$form-check-input-margin-y'] || '.25rem';
  v['$form-check-input-margin-x'] = u['$form-check-input-margin-x'] || '.25rem';
  v['$form-check-inline-margin-x'] = u['$form-check-inline-margin-x'] || '.75rem';
  v['$form-group-margin-bottom'] = u['$form-group-margin-bottom'] || v['$spacer-y'];
  v['$input-group-addon-bg'] = u['$input-group-addon-bg'] || v['$gray-lighter'];
  v['$input-group-addon-border-color'] = u['$input-group-addon-border-color'] || v['$input-border-color'];
  v['$cursor-disabled'] = u['$cursor-disabled'] || 'not-allowed';
  v['$custom-control-gutter'] = u['$custom-control-gutter'] || '1.5rem';
  v['$custom-control-spacer-x'] = u['$custom-control-spacer-x'] || '1rem';
  v['$custom-control-spacer-y'] = u['$custom-control-spacer-y'] || '.25rem';
  v['$custom-control-indicator-size'] = u['$custom-control-indicator-size'] || '1rem';
  v['$custom-control-indicator-bg'] = u['$custom-control-indicator-bg'] || '#ddd';
  v['$custom-control-indicator-bg-size'] = u['$custom-control-indicator-bg-size'] || '50% 50%';
  v['$custom-control-indicator-box-shadow'] = u['$custom-control-indicator-box-shadow'] || "inset 0 .25rem .25rem ".concat((0, _color.default)(v['$black']).alpha(0.1).toString());
  v['$custom-control-disabled-cursor'] = u['$custom-control-disabled-cursor'] || v['$cursor-disabled'];
  v['$custom-control-disabled-indicator-bg'] = u['$custom-control-disabled-indicator-bg'] || v['$gray-lighter'];
  v['$custom-control-disabled-description-color'] = u['$custom-control-disabled-description-color'] || v['$gray-light'];
  v['$custom-control-checked-indicator-color'] = u['$custom-control-checked-indicator-color'] || v['$white'];
  v['$custom-control-checked-indicator-bg'] = u['$custom-control-checked-indicator-bg'] || v['$brand-primary'];
  v['$custom-control-checked-indicator-box-shadow'] = u['$custom-control-checked-indicator-box-shadow'] || 'none';
  v['$custom-control-focus-indicator-box-shadow'] = u['$custom-control-focus-indicator-box-shadow'] || "0 0 0 1px ".concat(v['$body-bg'], ", 0 0 0 3px ").concat(v['$brand-primary']);
  v['$custom-control-active-indicator-color'] = u['$custom-control-active-indicator-color'] || v['$white'];
  v['$custom-control-active-indicator-bg'] = u['$custom-control-active-indicator-bg'] || (0, _color.default)(v['$brand-primary']).lighten(0.35).toString();
  v['$custom-control-active-indicator-box-shadow'] = u['$custom-control-active-indicator-box-shadow'] || 'none';
  v['$custom-checkbox-radius'] = u['$custom-checkbox-radius'] || v['$border-radius'];
  v['$custom-checkbox-checked-icon'] = u['$custom-checkbox-checked-icon'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 8 8\"%3E%3Cpath fill=\"".concat(v['$custom-control-checked-indicator-color'], "\" d=\"M6.564.75l-3.59 3.612-1.538-1.55L0 4.26 2.974 7.25 8 2.193z\"/%3E%3C/svg%3E')");
  v['$custom-checkbox-indeterminate-bg'] = u['$custom-checkbox-indeterminate-bg'] || v['$brand-primary'];
  v['$custom-checkbox-indeterminate-indicator-color'] = u['$custom-checkbox-indeterminate-indicator-color'] || v['$custom-control-checked-indicator-color'];
  v['$custom-checkbox-indeterminate-icon'] = u['$custom-checkbox-indeterminate-icon'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 4 4\"%3E%3Cpath stroke=\"".concat(v['$custom-checkbox-indeterminate-indicator-color'], "\" d=\"M0 2h4\"/%3E%3C/svg%3E')");
  v['$custom-checkbox-indeterminate-box-shadow'] = u['$custom-checkbox-indeterminate-box-shadow'] || 'none';
  v['$custom-radio-radius'] = u['$custom-radio-radius'] || '50%';
  v['$custom-radio-checked-icon'] = u['$custom-radio-checked-icon'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"-4 -4 8 8\"%3E%3Ccircle r=\"3\" fill=\"".concat(v['$custom-control-checked-indicator-color'], "\"/%3E%3C/svg%3E')");
  v['$custom-select-padding-x'] = u['$custom-select-padding-x'] || '.75rem ';
  v['$custom-select-padding-y'] = u['$custom-select-padding-y'] || '.375rem';
  v['$custom-select-indicator-padding'] = u['$custom-select-indicator-padding'] || '1rem';
  v['$custom-select-line-height'] = u['$custom-select-line-height'] || v['$input-line-height'];
  v['$custom-select-color'] = u['$custom-select-color'] || v['$input-color'];
  v['$custom-select-disabled-color'] = u['$custom-select-disabled-color'] || v['$gray-light'];
  v['$custom-select-bg'] = u['$custom-select-bg'] || v['$white'];
  v['$custom-select-disabled-bg'] = u['$custom-select-disabled-bg'] || v['$gray-lighter'];
  v['$custom-select-bg-size'] = u['$custom-select-bg-size'] || '8px 10px';
  v['$custom-select-indicator-color'] = u['$custom-select-indicator-color'] || '#333';
  v['$custom-select-indicator'] = u['$custom-select-indicator'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 4 5\"%3E%3Cpath fill=\"".concat(v['$custom-select-indicator-color'], "\" d=\"M2 0L0 2h4zm0 5L0 3h4z\"/%3E%3C/svg%3E')");
  v['$custom-select-border-width'] = u['$custom-select-border-width'] || v['$input-btn-border-width'];
  v['$custom-select-border-color'] = u['$custom-select-border-color'] || v['$input-border-color'];
  v['$custom-select-border-radius'] = u['$custom-select-border-radius'] || v['$border-radius'];
  v['$custom-select-focus-border-color'] = u['$custom-select-focus-border-color'] || (0, _color.default)(v['$brand-primary']).lighten(0.25).toString();
  v['$custom-select-focus-box-shadow'] = u['$custom-select-focus-box-shadow'] || "inset 0 1px 2px ".concat((0, _color.default)(v['$black']).alpha(0.75).toString(), ", 0 0 5px rgba(").concat(v['$custom-select-focus-border-color'], ", .5)");
  v['$custom-select-sm-font-size'] = u['$custom-select-sm-font-size'] || '75%';
  v['$custom-file-height'] = u['$custom-file-height'] || '2.5rem';
  v['$custom-file-width'] = u['$custom-file-width'] || '14rem';
  v['$custom-file-focus-box-shadow'] = u['$custom-file-focus-box-shadow'] || "0 0 0 .075rem ".concat(v['$white'], ", 0 0 0 .2rem ").concat(v['$brand-primary']);
  v['$custom-file-padding-x'] = u['$custom-file-padding-x'] || '.5rem';
  v['$custom-file-padding-y'] = u['$custom-file-padding-y'] || '1rem';
  v['$custom-file-line-height'] = u['$custom-file-line-height'] || '1.5';
  v['$custom-file-color'] = u['$custom-file-color'] || v['$gray'];
  v['$custom-file-bg'] = u['$custom-file-bg'] || v['$white'];
  v['$custom-file-border-width'] = u['$custom-file-border-width'] || v['$border-width'];
  v['$custom-file-border-color'] = u['$custom-file-border-color'] || v['$input-border-color'];
  v['$custom-file-border-radius'] = u['$custom-file-border-radius'] || v['$border-radius'];
  v['$custom-file-box-shadow'] = u['$custom-file-box-shadow'] || "inset 0 .2rem .4rem ".concat((0, _color.default)(v['$black']).alpha(0.05).toString());
  v['$custom-file-button-color'] = u['$custom-file-button-color'] || v['$custom-file-color'];
  v['$custom-file-button-bg'] = u['$custom-file-button-bg'] || v['$gray-lighter'];
  v['$custom-file-text'] = u['$custom-file-text'] || {
    placeholder: {
      en: 'Choose file...'
    },
    'button-label': {
      en: 'Browse'
    }
  };
  v['$form-icon-success-color'] = u['$form-icon-success-color'] || v['$brand-success'];
  v['$form-icon-success'] = u['$form-icon-success'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 8 8\"%3E%3Cpath fill=\"".concat(v['$form-icon-success-color'], "\" d=\"M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z\"/%3E%3C/svg%3E')");
  v['$form-icon-warning-color'] = u['$form-icon-warning-color'] || v['$brand-warning'];
  v['$form-icon-warning'] = u['$form-icon-warning'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 8 8\"%3E%3Cpath fill=\"".concat(v['$form-icon-warning-color'], "\" d=\"M4.4 5.324h-.8v-2.46h.8zm0 1.42h-.8V5.89h.8zM3.76.63L.04 7.075c-.115.2.016.425.26.426h7.397c.242 0 .372-.226.258-.426C6.726 4.924 5.47 2.79 4.253.63c-.113-.174-.39-.174-.494 0z\"/%3E%3C/svg%3E')");
  v['$form-icon-danger-color'] = u['$form-icon-danger-color'] || v['$brand-danger'];
  v['$form-icon-danger'] = u['$form-icon-danger'] || "url('data:image/svg+xml;charset=utf8,%3Csvg xmlns=\"http://www.w3.org/2000/svg\" fill=\"".concat(v['$form-icon-danger-color'], "\" viewBox=\"-2 -2 7 7\"%3E%3Cpath stroke=\"%23d9534f\" d=\"M0 0l3 3m0-3L0 3\"/%3E%3Ccircle r=\".5\"/%3E%3Ccircle cx=\"3\" r=\".5\"/%3E%3Ccircle cy=\"3\" r=\".5\"/%3E%3Ccircle cx=\"3\" cy=\"3\" r=\".5\"/%3E%3C/svg%3E')");
  v['$dropdown-min-width'] = u['$dropdown-min-width'] || '10rem';
  v['$dropdown-padding-y'] = u['$dropdown-padding-y'] || '.5rem';
  v['$dropdown-margin-top'] = u['$dropdown-margin-top'] || '.125rem';
  v['$dropdown-bg'] = u['$dropdown-bg'] || v['$white'];
  v['$dropdown-border-color'] = u['$dropdown-border-color'] || (0, _color.default)(v['$black']).alpha(0.15).toString();
  v['$dropdown-border-width'] = u['$dropdown-border-width'] || v['$border-width'];
  v['$dropdown-divider-bg'] = u['$dropdown-divider-bg'] || v['$gray-lighter'];
  v['$dropdown-box-shadow'] = u['$dropdown-box-shadow'] || "0 .5rem 1rem rgba(".concat(v['$black'], ",.175)");
  v['$dropdown-link-color'] = u['$dropdown-link-color'] || v['$gray-dark'];
  v['$dropdown-link-hover-color'] = u['$dropdown-link-hover-color'] || (0, _color.default)(v['$gray-dark']).darken(0.05).toString();
  v['$dropdown-link-hover-bg'] = u['$dropdown-link-hover-bg'] || v['$gray-lightest'];
  v['$dropdown-link-active-color'] = u['$dropdown-link-active-color'] || v['$component-active-color'];
  v['$dropdown-link-active-bg'] = u['$dropdown-link-active-bg'] || v['$component-active-bg'];
  v['$dropdown-link-disabled-color'] = u['$dropdown-link-disabled-color'] || v['$gray-light'];
  v['$dropdown-item-padding-x'] = u['$dropdown-item-padding-x'] || '1.5rem';
  v['$dropdown-header-color'] = u['$dropdown-header-color'] || v['$gray-light'];
  v['$zindex-dropdown-backdrop'] = u['$zindex-dropdown-backdrop'] || '990';
  v['$zindex-dropdown'] = u['$zindex-dropdown'] || '1000';
  v['$zindex-modal-backdrop'] = u['$zindex-modal-backdrop'] || '2040';
  v['$zindex-modal'] = u['$zindex-modal'] || '2050';
  v['$zindex-popover'] = u['$zindex-popover'] || '1060';
  v['$zindex-tooltip'] = u['$zindex-tooltip'] || '1070';
  v['$zindex-navbar'] = u['$zindex-navbar'] || '1000';
  v['$zindex-navbar-fixed'] = u['$zindex-navbar-fixed'] || '1030';
  v['$zindex-navbar-sticky'] = u['$zindex-navbar-sticky'] || '1030';
  v['$navbar-padding-x'] = u['$navbar-padding-x'] || v['$spacer'];
  v['$navbar-padding-y'] = u['$navbar-padding-y'] || v['$spacer-halved'];
  v['$navbar-brand-padding-y'] = u['$navbar-brand-padding-y'] || '.25rem';
  v['$navbar-divider-padding-y'] = u['$navbar-divider-padding-y'] || '.425rem';
  v['$navbar-toggler-padding-x'] = u['$navbar-toggler-padding-x'] || '.75rem';
  v['$navbar-toggler-padding-y'] = u['$navbar-toggler-padding-y'] || '.25rem';
  v['$navbar-toggler-font-size'] = u['$navbar-toggler-font-size'] || v['$font-size-lg'];
  v['$navbar-toggler-border-radius'] = u['$navbar-toggler-border-radius'] || v['$btn-border-radius'];
  v['$navbar-inverse-color'] = u['$navbar-inverse-color'] || (0, _color.default)(v['$white']).alpha(0.5).toString();
  v['$navbar-inverse-hover-color'] = u['$navbar-inverse-hover-color'] || (0, _color.default)(v['$white']).alpha(0.75).toString();
  v['$navbar-inverse-active-color'] = u['$navbar-inverse-active-color'] || (0, _color.default)(v['$white']).alpha(1).toString();
  v['$navbar-inverse-disabled-color'] = u['$navbar-inverse-disabled-color'] || (0, _color.default)(v['$white']).alpha(0.25).toString();
  v['$navbar-inverse-toggler-bg'] = u['$navbar-inverse-toggler-bg'] || "url('data:image/svg+xml;charset=utf8,%3Csvg viewBox=\"0 0 30 30\" xmlns=\"http://www.w3.org/2000/svg\"%3E%3Cpath stroke=\"".concat(v['$navbar-inverse-color'], "\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-miterlimit=\"10\" d=\"M4 7h22M4 15h22M4 23h22\"/%3E%3C/svg%3E')");
  v['$navbar-inverse-toggler-border'] = u['$navbar-inverse-toggler-border'] || (0, _color.default)(v['$white']).alpha(0.1).toString();
  v['$navbar-light-color'] = u['$navbar-light-color'] || (0, _color.default)(v['$black']).alpha(0.5).toString();
  v['$navbar-light-hover-color'] = u['$navbar-light-hover-color'] || (0, _color.default)(v['$black']).alpha(0.7).toString();
  v['$navbar-light-active-color'] = u['$navbar-light-active-color'] || (0, _color.default)(v['$black']).alpha(0.9).toString();
  v['$navbar-light-disabled-color'] = u['$navbar-light-disabled-color'] || (0, _color.default)(v['$black']).alpha(0.3).toString();
  v['$navbar-light-toggler-bg'] = u['$navbar-light-toggler-bg'] || "url('data:image/svg+xml;charset=utf8,%3Csvg viewBox=\"0 0 30 30\" xmlns=\"http://www.w3.org/2000/svg\"%3E%3Cpath stroke=\"".concat(v['$navbar-light-color'], "\" stroke-width=\"2\" stroke-linecap=\"round\" stroke-miterlimit=\"10\" d=\"M4 7h22M4 15h22M4 23h22\"/%3E%3C/svg%3E')");
  v['$navbar-light-toggler-border'] = u['$navbar-light-toggler-border'] || (0, _color.default)(v['$black']).alpha(0.1).toString();
  v['$nav-link-padding'] = u['$nav-link-padding'] || '.5em 1em';
  v['$nav-disabled-link-color'] = u['$nav-disabled-link-color'] || v['$gray-light'];
  v['$nav-tabs-border-color'] = u['$nav-tabs-border-color'] || '#ddd';
  v['$nav-tabs-border-width'] = u['$nav-tabs-border-width'] || v['$border-width'];
  v['$nav-tabs-border-radius'] = u['$nav-tabs-border-radius'] || v['$border-radius'];
  v['$nav-tabs-link-hover-border-color'] = u['$nav-tabs-link-hover-border-color'] || v['$gray-lighter'];
  v['$nav-tabs-active-link-hover-color'] = u['$nav-tabs-active-link-hover-color'] || v['$gray'];
  v['$nav-tabs-active-link-hover-bg'] = u['$nav-tabs-active-link-hover-bg'] || v['$body-bg'];
  v['$nav-tabs-active-link-hover-border-color'] = u['$nav-tabs-active-link-hover-border-color'] || '#ddd';
  v['$nav-pills-border-radius'] = u['$nav-pills-border-radius'] || v['$border-radius'];
  v['$nav-pills-active-link-color'] = u['$nav-pills-active-link-color'] || v['$component-active-color'];
  v['$nav-pills-active-link-bg'] = u['$nav-pills-active-link-bg'] || v['$component-active-bg'];
  v['$pagination-padding-x'] = u['$pagination-padding-x'] || '.75rem';
  v['$pagination-padding-y'] = u['$pagination-padding-y'] || '.5rem';
  v['$pagination-padding-x-sm'] = u['$pagination-padding-x-sm'] || '.5rem';
  v['$pagination-padding-y-sm'] = u['$pagination-padding-y-sm'] || '.25rem';
  v['$pagination-padding-x-lg'] = u['$pagination-padding-x-lg'] || '1.5rem';
  v['$pagination-padding-y-lg'] = u['$pagination-padding-y-lg'] || '.75rem';
  v['$pagination-line-height'] = u['$pagination-line-height'] || '1.25';
  v['$pagination-color'] = u['$pagination-color'] || v['$link-color'];
  v['$pagination-bg'] = u['$pagination-bg'] || v['$white'];
  v['$pagination-border-width'] = u['$pagination-border-width'] || v['$border-width'];
  v['$pagination-border-color'] = u['$pagination-border-color'] || '#ddd';
  v['$pagination-hover-color'] = u['$pagination-hover-color'] || v['$link-hover-color'];
  v['$pagination-hover-bg'] = u['$pagination-hover-bg'] || v['$gray-lighter'];
  v['$pagination-hover-border'] = u['$pagination-hover-border'] || '#ddd';
  v['$pagination-active-color'] = u['$pagination-active-color'] || v['$white'];
  v['$pagination-active-bg'] = u['$pagination-active-bg'] || v['$brand-primary'];
  v['$pagination-active-border'] = u['$pagination-active-border'] || v['$brand-primary'];
  v['$pagination-disabled-color'] = u['$pagination-disabled-color'] || v['$gray-light'];
  v['$pagination-disabled-bg'] = u['$pagination-disabled-bg'] || v['$white'];
  v['$pagination-disabled-border'] = u['$pagination-disabled-border'] || '#ddd';
  v['$jumbotron-padding'] = u['$jumbotron-padding'] || '2rem';
  v['$jumbotron-bg'] = u['$jumbotron-bg'] || v['$gray-lighter'];
  v['$state-success-text'] = u['$state-success-text'] || '#3c763d';
  v['$state-success-bg'] = u['$state-success-bg'] || '#dff0d8';
  v['$state-success-border'] = u['$state-success-border'] || (0, _color.default)(v['$state-success-bg']).darken(0.05).toString();
  v['$state-info-text'] = u['$state-info-text'] || '#31708f';
  v['$state-info-bg'] = u['$state-info-bg'] || '#d9edf7';
  v['$state-info-border'] = u['$state-info-border'] || (0, _color.default)(v['$state-info-bg']).darken(0.07).toString();
  v['$state-warning-text'] = u['$state-warning-text'] || '#8a6d3b';
  v['$state-warning-bg'] = u['$state-warning-bg'] || '#fcf8e3';
  v['$state-warning-border'] = u['$state-warning-border'] || (0, _color.default)(v['$state-warning-bg']).darken(0.05).toString();
  v['$mark-bg'] = u['$mark-bg'] || v['$state-warning-bg'];
  v['$state-danger-text'] = u['$state-danger-text'] || '#a94442';
  v['$state-danger-bg'] = u['$state-danger-bg'] || '#f2dede';
  v['$state-danger-border'] = u['$state-danger-border'] || (0, _color.default)(v['$state-danger-bg']).darken(0.05).toString();
  v['$card-spacer-x'] = u['$card-spacer-x'] || '1.25rem';
  v['$card-spacer-y'] = u['$card-spacer-y'] || '.75rem';
  v['$card-border-width'] = u['$card-border-width'] || '1px';
  v['$card-border-radius'] = u['$card-border-radius'] || v['$border-radius'];
  v['$card-border-color'] = u['$card-border-color'] || (0, _color.default)(v['$black']).alpha(0.125).toString();
  v['$card-border-radius-inner'] = u['$card-border-radius-inner'] || "calc(".concat(v['$card-border-radius'], " - ").concat(v['$card-border-width'], ")");
  v['$card-cap-bg'] = u['$card-cap-bg'] || v['$gray-lightest'];
  v['$card-bg'] = u['$card-bg'] || v['$white'];
  v['$card-link-hover-color'] = u['$card-link-hover-color'] || v['$white'];
  v['$card-img-overlay-padding'] = u['$card-img-overlay-padding'] || '1.25rem';
  detectedUnit = detectUnit(v['$grid-gutter-width']);
  v['$card-group-margin'] = u['$card-group-margin'] || rmUnit(v['$grid-gutter-width'], detectedUnit) / 2 + detectedUnit;
  v['$card-deck-margin'] = u['$card-deck-margin'] || v['$card-group-margin'];
  v['$card-columns-count-md'] = u['$card-columns-count-md'] || '2';
  v['$card-columns-gap-md'] = u['$card-columns-gap-md'] || '1rem';
  v['$card-columns-margin-md'] = u['$card-columns-margin-md'] || v['$card-spacer-y'];
  v['$card-columns-count-lg'] = u['$card-columns-count-lg'] || '2';
  v['$card-columns-gap-lg'] = u['$card-columns-gap-lg'] || '1.15rem';
  v['$card-columns-margin-lg'] = u['$card-columns-margin-lg'] || v['$card-spacer-y'];
  v['$card-columns-count-xl'] = u['$card-columns-count-xl'] || '3';
  v['$card-columns-gap-xl'] = u['$card-columns-gap-xl'] || '1.25rem';
  v['$card-columns-margin-xl'] = u['$card-columns-margin-xl'] || v['$card-spacer-y'];
  v['$card-columns-count-xxl'] = u['$card-columns-count-xxl'] || '4';
  v['$card-columns-gap-xxl'] = u['$card-columns-gap-xxl'] || '1.25rem';
  v['$card-columns-margin-xxl'] = u['$card-columns-margin-xxl'] || v['$card-spacer-y'];
  v['$tooltip-max-width'] = u['$tooltip-max-width'] || '200px';
  v['$tooltip-color'] = u['$tooltip-color'] || v['$white'];
  v['$tooltip-bg'] = u['$tooltip-bg'] || v['$black'];
  v['$tooltip-opacity'] = u['$tooltip-opacity'] || '.9';
  v['$tooltip-padding-y'] = u['$tooltip-padding-y'] || '3px';
  v['$tooltip-padding-x'] = u['$tooltip-padding-x'] || '8px';
  v['$tooltip-margin'] = u['$tooltip-margin'] || '3px';
  v['$tooltip-arrow-width'] = u['$tooltip-arrow-width'] || '5px';
  v['$tooltip-arrow-color'] = u['$tooltip-arrow-color'] || v['$tooltip-bg'];
  v['$popover-inner-padding'] = u['$popover-inner-padding'] || '1px';
  v['$popover-bg'] = u['$popover-bg'] || v['$white'];
  v['$popover-max-width'] = u['$popover-max-width'] || '276px';
  v['$popover-border-width'] = u['$popover-border-width'] || v['$border-width'];
  v['$popover-border-color'] = u['$popover-border-color'] || (0, _color.default)(v['$black']).alpha(0.2).toString();
  v['$popover-box-shadow'] = u['$popover-box-shadow'] || "0 5px 10px ".concat((0, _color.default)(v['$black']).alpha(0.2).toString());
  v['$popover-title-bg'] = u['$popover-title-bg'] || (0, _color.default)(v['$popover-bg']).darken(0.03).toString();
  v['$popover-title-padding-x'] = u['$popover-title-padding-x'] || '14px';
  v['$popover-title-padding-y'] = u['$popover-title-padding-y'] || '8px';
  v['$popover-content-padding-x'] = u['$popover-content-padding-x'] || '14px';
  v['$popover-content-padding-y'] = u['$popover-content-padding-y'] || '9px';
  v['$popover-arrow-width'] = u['$popover-arrow-width'] || '10px';
  v['$popover-arrow-color'] = u['$popover-arrow-color'] || v['$popover-bg'];
  detectedUnit = detectUnit(v['$popover-arrow-width']);
  v['$popover-arrow-outer-width'] = u['$popover-arrow-outer-width'] || rmUnit(v['$popover-arrow-width'], detectedUnit) + 1 + detectedUnit;
  v['$popover-arrow-outer-color'] = u['$popover-arrow-outer-color'] || (0, _color.default)(v['$popover-border-color']).fade(0.5).toString();
  v['$badge-default-bg'] = u['$badge-default-bg'] || v['$gray-light'];
  v['$badge-primary-bg'] = u['$badge-primary-bg'] || v['$brand-primary'];
  v['$badge-success-bg'] = u['$badge-success-bg'] || v['$brand-success'];
  v['$badge-info-bg'] = u['$badge-info-bg'] || v['$brand-info'];
  v['$badge-warning-bg'] = u['$badge-warning-bg'] || v['$brand-warning'];
  v['$badge-danger-bg'] = u['$badge-danger-bg'] || v['$brand-danger'];
  v['$badge-color'] = u['$badge-color'] || v['$white'];
  v['$badge-link-hover-color'] = u['$badge-link-hover-color'] || v['$white'];
  v['$badge-font-size'] = u['$badge-font-size'] || '75%';
  v['$badge-font-weight'] = u['$badge-font-weight'] || v['$font-weight-bold'];
  v['$badge-padding-x'] = u['$badge-padding-x'] || '.4em';
  v['$badge-padding-y'] = u['$badge-padding-y'] || '.25em';
  v['$badge-pill-padding-x'] = u['$badge-pill-padding-x'] || '.6em';
  v['$badge-pill-border-radius'] = u['$badge-pill-border-radius'] || '10rem';
  v['$modal-inner-padding'] = u['$modal-inner-padding'] || '15px';
  v['$modal-dialog-margin'] = u['$modal-dialog-margin'] || '10px';
  v['$modal-dialog-sm-up-margin-y'] = u['$modal-dialog-sm-up-margin-y'] || '30px';
  v['$modal-title-line-height'] = u['$modal-title-line-height'] || v['$line-height-base'];
  v['$modal-content-bg'] = u['$modal-content-bg'] || v['$white'];
  v['$modal-content-border-color'] = u['$modal-content-border-color'] || (0, _color.default)(v['$black']).alpha(0.2).toString();
  v['$modal-content-border-width'] = u['$modal-content-border-width'] || v['$border-width'];
  v['$modal-content-xs-box-shadow'] = u['$modal-content-xs-box-shadow'] || "0 3px 9px ".concat((0, _color.default)(v['$black']).alpha(0.5).toString());
  v['$modal-content-sm-up-box-shadow'] = u['$modal-content-sm-up-box-shadow'] || "0 5px 15px ".concat((0, _color.default)(v['$black']).alpha(0.5).toString());
  v['$modal-backdrop-bg'] = u['$modal-backdrop-bg'] || v['$black'];
  v['$modal-backdrop-opacity'] = u['$modal-backdrop-opacity'] || '.5';
  v['$modal-header-border-color'] = u['$modal-header-border-color'] || v['$gray-lighter'];
  v['$modal-footer-border-color'] = u['$modal-footer-border-color'] || v['$modal-header-border-color'];
  v['$modal-header-border-width'] = u['$modal-header-border-width'] || v['$modal-content-border-width'];
  v['$modal-footer-border-width'] = u['$modal-footer-border-width'] || v['$modal-header-border-width'];
  v['$modal-header-padding'] = u['$modal-header-padding'] || '15px';
  v['$modal-lg'] = u['$modal-lg'] || '800px';
  v['$modal-md'] = u['$modal-md'] || '500px';
  v['$modal-sm'] = u['$modal-sm'] || '300px';
  v['$modal-transition'] = u['$modal-transition'] || 'transform .3s ease-out';
  v['$alert-padding-x'] = u['$alert-padding-x'] || '1.25rem';
  v['$alert-padding-y'] = u['$alert-padding-y'] || '.75rem';
  v['$alert-margin-bottom'] = u['$alert-margin-bottom'] || v['$spacer-y'];
  v['$alert-border-radius'] = u['$alert-border-radius'] || v['$border-radius'];
  v['$alert-link-font-weight'] = u['$alert-link-font-weight'] || v['$font-weight-bold'];
  v['$alert-border-width'] = u['$alert-border-width'] || v['$border-width'];
  v['$alert-success-bg'] = u['$alert-success-bg'] || v['$state-success-bg'];
  v['$alert-success-text'] = u['$alert-success-text'] || v['$state-success-text'];
  v['$alert-success-border'] = u['$alert-success-border'] || v['$state-success-border'];
  v['$alert-info-bg'] = u['$alert-info-bg'] || v['$state-info-bg'];
  v['$alert-info-text'] = u['$alert-info-text'] || v['$state-info-text'];
  v['$alert-info-border'] = u['$alert-info-border'] || v['$state-info-border'];
  v['$alert-warning-bg'] = u['$alert-warning-bg'] || v['$state-warning-bg'];
  v['$alert-warning-text'] = u['$alert-warning-text'] || v['$state-warning-text'];
  v['$alert-warning-border'] = u['$alert-warning-border'] || v['$state-warning-border'];
  v['$alert-danger-bg'] = u['$alert-danger-bg'] || v['$state-danger-bg'];
  v['$alert-danger-text'] = u['$alert-danger-text'] || v['$state-danger-text'];
  v['$alert-danger-border'] = u['$alert-danger-border'] || v['$state-danger-border'];
  v['$progress-height'] = u['$progress-height'] || '1rem';
  v['$progress-font-size'] = u['$progress-font-size'] || '.75rem';
  v['$progress-bg'] = u['$progress-bg'] || v['$gray-lighter'];
  v['$progress-border-radius'] = u['$progress-border-radius'] || v['$border-radius'];
  v['$progress-box-shadow'] = u['$progress-box-shadow'] || "inset 0 .1rem .1rem ".concat((0, _color.default)(v['$black']).alpha(0.1).toString());
  v['$progress-bar-color'] = u['$progress-bar-color'] || v['$white'];
  v['$progress-bar-bg'] = u['$progress-bar-bg'] || v['$brand-primary'];
  v['$progress-bar-animation-timing'] = u['$progress-bar-animation-timing'] || '1s linear infinite';
  v['$list-group-color'] = u['$list-group-color'] || v['$body-color'];
  v['$list-group-bg'] = u['$list-group-bg'] || v['$white'];
  v['$list-group-border-color'] = u['$list-group-border-color'] || (0, _color.default)(v['$black']).alpha(0.125).toString();
  v['$list-group-border-width'] = u['$list-group-border-width'] || v['$border-width'];
  v['$list-group-border-radius'] = u['$list-group-border-radius'] || v['$border-radius'];
  v['$list-group-item-padding-x'] = u['$list-group-item-padding-x'] || '1.25rem';
  v['$list-group-item-padding-y'] = u['$list-group-item-padding-y'] || '.75rem';
  v['$list-group-hover-bg'] = u['$list-group-hover-bg'] || v['$gray-lightest'];
  v['$list-group-active-color'] = u['$list-group-active-color'] || v['$component-active-color'];
  v['$list-group-active-bg'] = u['$list-group-active-bg'] || v['$component-active-bg'];
  v['$list-group-active-border'] = u['$list-group-active-border'] || v['$list-group-active-bg'];
  v['$list-group-disabled-color'] = u['$list-group-disabled-color'] || v['$gray-light'];
  v['$list-group-disabled-bg'] = u['$list-group-disabled-bg'] || v['$list-group-bg'];
  v['$list-group-link-color'] = u['$list-group-link-color'] || v['$gray'];
  v['$list-group-link-hover-color'] = u['$list-group-link-hover-color'] || v['$list-group-link-color'];
  v['$list-group-link-active-color'] = u['$list-group-link-active-color'] || v['$list-group-color'];
  v['$list-group-link-active-bg'] = u['$list-group-link-active-bg'] || v['$gray-lighter'];
  v['$thumbnail-padding'] = u['$thumbnail-padding'] || '.25rem';
  v['$thumbnail-bg'] = u['$thumbnail-bg'] || v['$body-bg'];
  v['$thumbnail-border-width'] = u['$thumbnail-border-width'] || v['$border-width'];
  v['$thumbnail-border-color'] = u['$thumbnail-border-color'] || '#ddd';
  v['$thumbnail-border-radius'] = u['$thumbnail-border-radius'] || v['$border-radius'];
  v['$thumbnail-box-shadow'] = u['$thumbnail-box-shadow'] || "0 1px 2px ".concat((0, _color.default)(v['$black']).alpha(0.75).toString());
  v['$thumbnail-transition'] = u['$thumbnail-transition'] || 'all .2s ease-in-out';
  v['$figure-caption-font-size'] = u['$figure-caption-font-size'] || '90%';
  v['$figure-caption-color'] = u['$figure-caption-color'] || v['$gray-light'];
  v['$breadcrumb-padding-y'] = u['$breadcrumb-padding-y'] || '.75rem';
  v['$breadcrumb-padding-x'] = u['$breadcrumb-padding-x'] || '1rem';
  v['$breadcrumb-item-padding'] = u['$breadcrumb-item-padding'] || '.5rem';
  v['$breadcrumb-bg'] = u['$breadcrumb-bg'] || v['$gray-lighter'];
  v['$breadcrumb-divider-color'] = u['$breadcrumb-divider-color'] || v['$gray-light'];
  v['$breadcrumb-active-color'] = u['$breadcrumb-active-color'] || v['$gray-light'];
  v['$breadcrumb-divider'] = u['$breadcrumb-divider'] || '"/"';
  v['$close-font-size'] = u['$close-font-size'] || rmUnit(v['$font-size-base']) * 1.5 + detectUnit(v['$font-size-base']);
  v['$close-font-weight'] = u['$close-font-weight'] || v['$font-weight-bold'];
  v['$close-color'] = u['$close-color'] || v['$black'];
  v['$close-text-shadow'] = u['$close-text-shadow'] || "0 1px 0 ".concat(v['$white']);
  v['$code-font-size'] = u['$code-font-size'] || '90%';
  v['$code-padding-x'] = u['$code-padding-x'] || '.4rem';
  v['$code-padding-y'] = u['$code-padding-y'] || '.2rem';
  v['$code-color'] = u['$code-color'] || '#bd4147';
  v['$code-bg'] = u['$code-bg'] || v['$gray-lightest'];
  v['$kbd-color'] = u['$kbd-color'] || v['$white'];
  v['$kbd-bg'] = u['$kbd-bg'] || v['$gray-dark'];
  v['$kbd-box-shadow'] = u['$kbd-box-shadow'] || "inset 0 -.1rem 0 ".concat((0, _color.default)(v['$black']).alpha(0.25).toString());
  v['$nested-kbd-font-weight'] = u['$nested-kbd-font-weight'] || v['$font-weight-bold'];
  v['$pre-color'] = u['$pre-color'] || v['$gray-dark'];
  v['$pre-scrollable-max-height'] = u['$pre-scrollable-max-height'] || '340px';
  return Object.assign({}, u, v);
}
var makeTheme = makeOriginal;
exports.makeTheme = makeTheme;
var _default = makeOriginal();
exports.default = _default;
});
unwrapExports(theme);
var theme_1 = theme.makeTheme;

var UtilityProvider_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.propTypes = exports.defaultProps = void 0;
var _propTypes = _interopRequireDefault(propTypes);
var _styledComponents = _interopRequireDefault(styledComponents);
var _align = _interopRequireDefault(align);
var _background = _interopRequireDefault(background);
var _borders = _interopRequireDefault(borders);
var _clearfix = _interopRequireDefault(clearfix$1);
var _cursor = _interopRequireDefault(cursor);
var _display = _interopRequireDefault(display);
var _flex = _interopRequireDefault(flex);
var _float = _interopRequireDefault(float_1$1);
var _position = _interopRequireDefault(position);
var _reboot = _interopRequireDefault(reboot);
var _screenreaders = _interopRequireDefault(screenreaders);
var _sizing = _interopRequireDefault(sizing);
var _spacing = _interopRequireDefault(spacing);
var _text = _interopRequireDefault(text);
var _transition = _interopRequireDefault(transition$1);
var _visibility = _interopRequireDefault(visibility$2);
var _theme = _interopRequireDefault(theme);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
var defaultProps = {
  theme: _theme.default,
  utils: {
    align: true,
    background: true,
    border: true,
    clearfix: true,
    cursor: true,
    display: true,
    flex: true,
    float: true,
    position: true,
    screenreaders: true,
    sizing: true,
    spacing: true,
    text: true,
    transition: true,
    visibility: true
  }
};
exports.defaultProps = defaultProps;
var propTypes$$1 = {
  children: _propTypes.default.node,
  theme: _propTypes.default.object,
  utils: _propTypes.default.shape({
    align: _propTypes.default.bool,
    background: _propTypes.default.bool,
    a: _propTypes.default.bool,
    border: _propTypes.default.bool,
    clearfix: _propTypes.default.bool,
    display: _propTypes.default.bool,
    flex: _propTypes.default.bool,
    float: _propTypes.default.bool,
    position: _propTypes.default.bool,
    screenreaders: _propTypes.default.bool,
    sizing: _propTypes.default.bool,
    spacing: _propTypes.default.bool,
    text: _propTypes.default.bool,
    transition: _propTypes.default.bool,
    visibility: _propTypes.default.bool
  })
};
exports.propTypes = propTypes$$1;
var UtilityProvider = _styledComponents.default.div.withConfig({
  displayName: "UtilityProvider",
  componentId: "wqw4uj-0"
})(["", ""], function (props) {
  return "\n    ".concat(_reboot.default.body(props.theme['$font-family-base'], props.theme['$font-size-base'], props.theme['$font-weight-base'], props.theme['$line-height-base'], props.theme['$body-color'], props.theme['$body-bg']), "\n    ").concat((0, conditional.ifThen)(props.utils.align, _align.default.getAlignUtilities()), "\n    ").concat((0, conditional.ifThen)(props.utils.background, _background.default.getBackgroundUtilities(props.theme['$enable-hover-media-query'], props.theme['$brand-primary'], props.theme['$brand-success'], props.theme['$brand-info'], props.theme['$brand-warning'], props.theme['$brand-danger'], props.theme['$brand-inverse'], props.theme['$gray-lightest'])), "\n    ").concat((0, conditional.ifThen)(props.utils.border, _borders.default.getBordersUtilities(props.theme['$enable-rounded'], props.theme['$border-radius'])), "\n      ").concat((0, conditional.ifThen)(props.utils.clearfix, _clearfix.default.getClearfixUtilities()), "\n      ").concat((0, conditional.ifThen)(props.utils.cursor, _cursor.default.getCursorUtilities()), "\n      ").concat((0, conditional.ifThen)(props.utils.display, _display.default.getDisplayUtilities(props.theme['$grid-breakpoints'])), "\n    ").concat((0, conditional.ifThen)(props.utils.flex, _flex.default.getFlexUtilities(props.theme['$grid-breakpoints'])), "\n    ").concat((0, conditional.ifThen)(props.utils.float, _float.default.getFloatUtilities(props.theme['$grid-breakpoints'])), "\n    ").concat((0, conditional.ifThen)(props.utils.screenreaders, _screenreaders.default.getScreenReadersUtilities()), "\n    ").concat((0, conditional.ifThen)(props.utils.spacing, _spacing.default.getSpacingUtilities(props.theme['$grid-breakpoints'], props.theme['$spacers']
  )), "\n    ").concat((0, conditional.ifThen)(props.utils.text, _text.default.getTextUtilities(props.theme['$enable-hover-media-query'], props.theme['$grid-breakpoints'], props.theme['$font-weight-normal'], props.theme['$font-weight-bold'], props.theme['$text-muted'], props.theme['$brand-primary'], props.theme['$brand-success'], props.theme['$brand-info'], props.theme['$brand-warning'], props.theme['$brand-danger'], props.theme['$gray-dark'])), "\n    ").concat((0, conditional.ifThen)(props.utils.transition, _transition.default.getTransitionUtilities(props.theme['$enable-transitions'], props.theme['$transition-fade'], props.theme['$transition-collapse'])), "\n    ").concat((0, conditional.ifThen)(props.utils.visibility, _visibility.default.getVisibilityUtilities(props.theme['$grid-breakpoints'])), "\n    ").concat((0, conditional.ifThen)(props.utils.position, _position.default.getPositionUtilities(props.theme['$zindex-fixed'], props.theme['$zindex-sticky'])), "\n    ").concat((0, conditional.ifThen)(props.utils.sizing, _sizing.default.getSizingUtilities(props.theme.$sizes)), " // eslint-disable-line dot-notation\n  ");
});
UtilityProvider.defaultProps = defaultProps;
UtilityProvider.propTypes = propTypes$$1;
var _default = UtilityProvider;
exports.default = _default;
});
unwrapExports(UtilityProvider_1);
var UtilityProvider_2 = UtilityProvider_1.propTypes;
var UtilityProvider_3 = UtilityProvider_1.defaultProps;

var reset = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _default = "\n/* http://meyerweb.com/eric/tools/css/reset/\n   v2.0 | 20110126\n   License: none (public domain)\n*/\n\nhtml, body, div, span, applet, object, iframe,\nh1, h2, h3, h4, h5, h6, p, blockquote, pre,\na, abbr, acronym, address, big, cite, code,\ndel, dfn, em, img, ins, kbd, q, s, samp,\nsmall, strike, strong, sub, sup, tt, var,\nb, u, i, center,\ndl, dt, dd, ol, ul, li,\nfieldset, form, label, legend,\ntable, caption, tbody, tfoot, thead, tr, th, td,\narticle, aside, canvas, details, embed,\nfigure, figcaption, footer, header, hgroup,\nmenu, nav, output, ruby, section, summary,\ntime, mark, audio, video {\n  margin: 0;\n  padding: 0;\n  border: 0;\n  font-size: 100%;\n  font: inherit;\n  vertical-align: baseline;\n}\n/* HTML5 display-role reset for older browsers */\narticle, aside, details, figcaption, figure,\nfooter, header, hgroup, menu, nav, section {\n  display: block;\n}\nbody {\n  line-height: 1;\n}\nol, ul {\n  list-style: none;\n}\nblockquote, q {\n  quotes: none;\n}\nblockquote:before, blockquote:after,\nq:before, q:after {\n  content: '';\n  content: none;\n}\ntable {\n  border-collapse: collapse;\n  border-spacing: 0;\n}\n";
exports.default = _default;
module.exports = exports.default;
});
unwrapExports(reset);

var GlobalStyle_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _theme = _interopRequireDefault(theme);
var _reset = _interopRequireDefault(reset);
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  ", "\n"]);
  _templateObject = function _templateObject() {
    return data;
  };
  return data;
}
function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }
var GlobalStyle = (0, styledComponents.createGlobalStyle)(_templateObject(), function (props) {
  return "\n    ".concat(props.reset ? _reset.default : '', "\n    ").concat(props.injectGlobal ? (0, reboot.getGlobalStyleNoBootstrapProvider)(props.theme['$font-family-base'] || _theme.default['$font-family-base'], props.theme['$font-size-base'] || _theme.default['$font-size-base'], props.theme['$font-weight-base'] || _theme.default['$font-weight-base'], props.theme['$line-height-base'] || _theme.default['$line-height-base'], props.theme['$body-color'] || _theme.default['$body-color'], props.theme['$body-bg'] || _theme.default['$body-bg']) : '', "\n  ");
});
var _default = GlobalStyle;
exports.default = _default;
module.exports = exports.default;
});
unwrapExports(GlobalStyle_1);

var BootstrapProvider_1 = createCommonjsModule(function (module, exports) {
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.propTypes = exports.defaultProps = void 0;
var _react = _interopRequireDefault(React);
var _propTypes = _interopRequireDefault(propTypes);
var _UtilityProvider = _interopRequireWildcard(UtilityProvider_1);
var _GlobalStyle = _interopRequireDefault(GlobalStyle_1);
function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
var defaultProps = {
  theme: bootstrapStyled_esm.theme,
  injectGlobal: false,
  reset: false,
  utils: _UtilityProvider.defaultProps.utils
};
exports.defaultProps = defaultProps;
var propTypes$$1 = {
  children: _propTypes.default.node.isRequired,
  injectGlobal: _propTypes.default.bool,
  reset: _propTypes.default.bool,
  theme: _propTypes.default.object,
  utils: _propTypes.default.shape({
    align: _propTypes.default.bool,
    background: _propTypes.default.bool,
    a: _propTypes.default.bool,
    border: _propTypes.default.bool,
    clearfix: _propTypes.default.bool,
    display: _propTypes.default.bool,
    flex: _propTypes.default.bool,
    float: _propTypes.default.bool,
    position: _propTypes.default.bool,
    screenreaders: _propTypes.default.bool,
    sizing: _propTypes.default.bool,
    spacing: _propTypes.default.bool,
    text: _propTypes.default.bool,
    transition: _propTypes.default.bool,
    visibility: _propTypes.default.bool
  })
};
exports.propTypes = propTypes$$1;
var BootstrapProvider =
function (_React$Component) {
  _inherits(BootstrapProvider, _React$Component);
  function BootstrapProvider() {
    var _getPrototypeOf2;
    var _this;
    _classCallCheck(this, BootstrapProvider);
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(BootstrapProvider)).call.apply(_getPrototypeOf2, [this].concat(args)));
    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "state", {
      theme: {},
      isWindowPhone8Fixed: null
    });
    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "setTheme", function (_ref, cb) {
      var userTheme = _ref.theme;
      var theme = _this.makeTheme({
        theme: userTheme
      });
      _this.setState({
        theme: theme
      }, cb);
    });
    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "makeTheme", function (_ref2) {
      var userTheme = _ref2.theme;
      var theme = (0, bootstrapStyled_esm.makeTheme)(userTheme);
      var metaKeyList = Object.keys(theme).filter(function (f) {
        return f[0] === '_';
      });
      metaKeyList.forEach(function (k) {
        delete theme[k];
      });
      return theme;
    });
    return _this;
  }
  _createClass(BootstrapProvider, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.setTheme(this.props, this.injectGlobal);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.windowPhone8Fix();
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (JSON.stringify(this.makeTheme(this.props)) !== JSON.stringify(nextProps.theme)) {
        this.setTheme(nextProps);
      }
    }
  }, {
    key: "windowPhone8Fix",
    value: function windowPhone8Fix() {
      if (navigator.userAgent.match(/IEMobile\/10\.0/)) {
        var msViewportStyle = document.createElement('style');
        msViewportStyle.appendChild(document.createTextNode('@-ms-viewport{width:auto!important}'));
        document.head.appendChild(msViewportStyle);
        this.setState({
          isWindowPhone8Fixed: true
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          utils = _this$props.utils,
          reset = _this$props.reset,
          injectGlobal = _this$props.injectGlobal;
      var theme = this.state.theme;
      return _react.default.createElement(styledComponents.ThemeProvider, {
        theme: theme
      }, _react.default.createElement(_UtilityProvider.default, {
        utils: utils
      }, (reset || injectGlobal) && _react.default.createElement(_GlobalStyle.default, {
        reset: reset,
        injectGlobal: injectGlobal
      }), children));
    }
  }]);
  return BootstrapProvider;
}(_react.default.Component);
_defineProperty(BootstrapProvider, "propTypes", propTypes$$1);
_defineProperty(BootstrapProvider, "defaultProps", defaultProps);
BootstrapProvider.defaultProps = defaultProps;
BootstrapProvider.propTypes = propTypes$$1;
var _default = BootstrapProvider;
exports.default = _default;
});
var BootstrapProvider = unwrapExports(BootstrapProvider_1);
var BootstrapProvider_2 = BootstrapProvider_1.propTypes;
var BootstrapProvider_3 = BootstrapProvider_1.defaultProps;

var REDUX_BS_KEY = 'bs.redux';

var selectBsRedux = function selectBsRedux(state) {
  return state[REDUX_BS_KEY];
};
var selectThemes = createSelector(selectBsRedux, function (bsReduxState) {
  return bsReduxState.themes;
});
var selectTheme = createSelector(selectBsRedux, function (bsReduxState) {
  return bsReduxState.theme;
});
var selectValue = createSelector(selectBsRedux, function (bsReduxState) {
  return bsReduxState.theme._name;
}
);
var selectValues = createSelector(selectBsRedux, function (bsReduxState) {
  return Object.keys(bsReduxState.themes).map(function (key) {
    return bsReduxState.themes[key]._name;
  });
}
);

var ConnectedBootstrapProvider = function ConnectedBootstrapProvider(props) {
  return React.createElement(BootstrapProvider, props);
};
var mapStateToProps = createStructuredSelector({
  theme: selectTheme
});
var withConnect = connect(mapStateToProps);
var index$3 = compose(withConnect)(ConnectedBootstrapProvider);

export default index$3;
export { REDUX_BS_KEY };
//# sourceMappingURL=redux.es.js.map
